#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1249
#define LARGE_STATE_COUNT 76
#define SYMBOL_COUNT 189
#define ALIAS_COUNT 1
#define TOKEN_COUNT 90
#define EXTERNAL_TOKEN_COUNT 14
#define FIELD_COUNT 10
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define PRODUCTION_ID_COUNT 25

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_SEMI = 2,
  anon_sym_COMMA = 3,
  anon_sym_LPAREN = 4,
  anon_sym_RPAREN = 5,
  anon_sym_PLUS = 6,
  anon_sym_DOT_PLUS = 7,
  anon_sym_DASH = 8,
  anon_sym_DOT_DASH = 9,
  anon_sym_STAR = 10,
  anon_sym_DOT_STAR = 11,
  anon_sym_SLASH = 12,
  anon_sym_DOT_SLASH = 13,
  anon_sym_BSLASH = 14,
  anon_sym_DOT_BSLASH = 15,
  anon_sym_CARET = 16,
  anon_sym_DOT_CARET = 17,
  anon_sym_PIPE = 18,
  anon_sym_AMP = 19,
  anon_sym_DOT = 20,
  anon_sym_TILDE = 21,
  anon_sym_QMARK = 22,
  anon_sym_AT = 23,
  anon_sym_LT = 24,
  anon_sym_LT_EQ = 25,
  anon_sym_EQ_EQ = 26,
  anon_sym_TILDE_EQ = 27,
  anon_sym_GT_EQ = 28,
  anon_sym_GT = 29,
  anon_sym_AMP_AMP = 30,
  anon_sym_PIPE_PIPE = 31,
  anon_sym_DOT_SQUOTE = 32,
  anon_sym_SQUOTE = 33,
  anon_sym_LBRACK = 34,
  aux_sym_matrix_token1 = 35,
  anon_sym_RBRACK = 36,
  anon_sym_LBRACE = 37,
  anon_sym_RBRACE = 38,
  anon_sym_EQ = 39,
  anon_sym_COLON = 40,
  sym_return_statement = 41,
  sym_continue_statement = 42,
  sym_break_statement = 43,
  anon_sym_elseif = 44,
  anon_sym_else = 45,
  anon_sym_if = 46,
  anon_sym_end = 47,
  anon_sym_for = 48,
  anon_sym_parfor = 49,
  anon_sym_while = 50,
  anon_sym_case = 51,
  anon_sym_otherwise = 52,
  anon_sym_switch = 53,
  anon_sym_global = 54,
  anon_sym_persistent = 55,
  anon_sym_arguments = 56,
  anon_sym_function = 57,
  anon_sym_get_DOT = 58,
  anon_sym_set_DOT = 59,
  anon_sym_endfunction = 60,
  anon_sym_vector = 61,
  anon_sym_matrix = 62,
  anon_sym_scalar = 63,
  anon_sym_properties = 64,
  anon_sym_methods = 65,
  anon_sym_events = 66,
  anon_sym_enumeration = 67,
  anon_sym_classdef = 68,
  anon_sym_catch = 69,
  anon_sym_try = 70,
  sym_number = 71,
  anon_sym_true = 72,
  anon_sym_false = 73,
  anon_sym_LF = 74,
  anon_sym_CR = 75,
  sym_comment = 76,
  sym_line_continuation = 77,
  sym_command_name = 78,
  sym_command_argument = 79,
  sym__single_quote_string_start = 80,
  sym__single_quote_string_end = 81,
  sym__double_quote_string_start = 82,
  sym__double_quote_string_end = 83,
  sym_formatting_sequence = 84,
  sym_escape_sequence = 85,
  sym_string_content = 86,
  sym__entry_delimiter = 87,
  sym__multioutput_variable_start = 88,
  sym_error_sentinel = 89,
  sym_source_file = 90,
  aux_sym__block = 91,
  sym_block = 92,
  sym__statement = 93,
  sym__expression = 94,
  sym_parenthesis = 95,
  sym__binary_expression = 96,
  sym_binary_operator = 97,
  sym_unary_operator = 98,
  sym_indirect_access = 99,
  sym_field_expression = 100,
  sym_not_operator = 101,
  sym_metaclass_operator = 102,
  sym_handle_operator = 103,
  sym_comparison_operator = 104,
  sym_boolean_operator = 105,
  sym_postfix_operator = 106,
  sym_string = 107,
  sym_row = 108,
  sym_matrix = 109,
  sym_cell = 110,
  sym_ignored_argument = 111,
  sym_assignment = 112,
  sym_multioutput_variable = 113,
  sym_spread_operator = 114,
  sym_arguments = 115,
  sym__args = 116,
  sym_function_call = 117,
  sym_command = 118,
  sym__range_element = 119,
  sym_range = 120,
  sym_elseif_clause = 121,
  sym_else_clause = 122,
  sym_if_statement = 123,
  sym_iterator = 124,
  sym_parfor_options = 125,
  sym_for_statement = 126,
  sym_while_statement = 127,
  sym_case_clause = 128,
  sym_otherwise_clause = 129,
  sym_switch_statement = 130,
  sym__lambda_arguments = 131,
  sym_lambda = 132,
  sym_global_operator = 133,
  sym_persistent_operator = 134,
  sym__argument_attributes = 135,
  sym_arguments_statement = 136,
  sym_function_output = 137,
  sym_function_arguments = 138,
  sym_function_definition = 139,
  sym__function_definition_with_end = 140,
  sym_attribute = 141,
  sym_attributes = 142,
  sym_superclasses = 143,
  sym_dimensions = 144,
  sym_validation_functions = 145,
  sym_default_value = 146,
  sym_property_name = 147,
  sym_property = 148,
  sym_properties = 149,
  sym_function_signature = 150,
  sym_methods = 151,
  sym_events = 152,
  sym__enum_value = 153,
  sym_enum = 154,
  sym_enumeration = 155,
  sym_class_definition = 156,
  sym_catch_clause = 157,
  sym_try_statement = 158,
  sym_boolean = 159,
  sym__end_of_line = 160,
  aux_sym_source_file_repeat1 = 161,
  aux_sym__block_repeat1 = 162,
  aux_sym_field_expression_repeat1 = 163,
  aux_sym_metaclass_operator_repeat1 = 164,
  aux_sym_string_repeat1 = 165,
  aux_sym_row_repeat1 = 166,
  aux_sym_matrix_repeat1 = 167,
  aux_sym_multioutput_variable_repeat1 = 168,
  aux_sym_arguments_repeat1 = 169,
  aux_sym_arguments_repeat2 = 170,
  aux_sym_command_repeat1 = 171,
  aux_sym_elseif_clause_repeat1 = 172,
  aux_sym_if_statement_repeat1 = 173,
  aux_sym_switch_statement_repeat1 = 174,
  aux_sym__lambda_arguments_repeat1 = 175,
  aux_sym_global_operator_repeat1 = 176,
  aux_sym__argument_attributes_repeat1 = 177,
  aux_sym_arguments_statement_repeat1 = 178,
  aux_sym_function_definition_repeat1 = 179,
  aux_sym_attributes_repeat1 = 180,
  aux_sym_superclasses_repeat1 = 181,
  aux_sym_dimensions_repeat1 = 182,
  aux_sym_validation_functions_repeat1 = 183,
  aux_sym_methods_repeat1 = 184,
  aux_sym_events_repeat1 = 185,
  aux_sym_enum_repeat1 = 186,
  aux_sym_enumeration_repeat1 = 187,
  aux_sym_class_definition_repeat1 = 188,
  alias_sym_superclass = 189,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_SEMI] = ";",
  [anon_sym_COMMA] = ",",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_PLUS] = "+",
  [anon_sym_DOT_PLUS] = ".+",
  [anon_sym_DASH] = "-",
  [anon_sym_DOT_DASH] = ".-",
  [anon_sym_STAR] = "*",
  [anon_sym_DOT_STAR] = ".*",
  [anon_sym_SLASH] = "/",
  [anon_sym_DOT_SLASH] = "./",
  [anon_sym_BSLASH] = "\\",
  [anon_sym_DOT_BSLASH] = ".\\",
  [anon_sym_CARET] = "^",
  [anon_sym_DOT_CARET] = ".^",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP] = "&",
  [anon_sym_DOT] = ".",
  [anon_sym_TILDE] = "~",
  [anon_sym_QMARK] = "\?",
  [anon_sym_AT] = "@",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_TILDE_EQ] = "~=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_GT] = ">",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_DOT_SQUOTE] = ".'",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_LBRACK] = "[",
  [aux_sym_matrix_token1] = "matrix_token1",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_EQ] = "=",
  [anon_sym_COLON] = ":",
  [sym_return_statement] = "return_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [anon_sym_elseif] = "elseif",
  [anon_sym_else] = "else",
  [anon_sym_if] = "if",
  [anon_sym_end] = "end",
  [anon_sym_for] = "for",
  [anon_sym_parfor] = "parfor",
  [anon_sym_while] = "while",
  [anon_sym_case] = "case",
  [anon_sym_otherwise] = "otherwise",
  [anon_sym_switch] = "switch",
  [anon_sym_global] = "global",
  [anon_sym_persistent] = "persistent",
  [anon_sym_arguments] = "arguments",
  [anon_sym_function] = "function",
  [anon_sym_get_DOT] = "get.",
  [anon_sym_set_DOT] = "set.",
  [anon_sym_endfunction] = "endfunction",
  [anon_sym_vector] = "identifier",
  [anon_sym_matrix] = "identifier",
  [anon_sym_scalar] = "identifier",
  [anon_sym_properties] = "properties",
  [anon_sym_methods] = "methods",
  [anon_sym_events] = "events",
  [anon_sym_enumeration] = "enumeration",
  [anon_sym_classdef] = "classdef",
  [anon_sym_catch] = "catch",
  [anon_sym_try] = "try",
  [sym_number] = "number",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_LF] = "\n",
  [anon_sym_CR] = "\r",
  [sym_comment] = "comment",
  [sym_line_continuation] = "line_continuation",
  [sym_command_name] = "command_name",
  [sym_command_argument] = "command_argument",
  [sym__single_quote_string_start] = "'",
  [sym__single_quote_string_end] = "'",
  [sym__double_quote_string_start] = "\"",
  [sym__double_quote_string_end] = "\"",
  [sym_formatting_sequence] = "formatting_sequence",
  [sym_escape_sequence] = "escape_sequence",
  [sym_string_content] = "string_content",
  [sym__entry_delimiter] = ";",
  [sym__multioutput_variable_start] = "[",
  [sym_error_sentinel] = "error_sentinel",
  [sym_source_file] = "source_file",
  [aux_sym__block] = "_block",
  [sym_block] = "block",
  [sym__statement] = "_statement",
  [sym__expression] = "_expression",
  [sym_parenthesis] = "parenthesis",
  [sym__binary_expression] = "_binary_expression",
  [sym_binary_operator] = "binary_operator",
  [sym_unary_operator] = "unary_operator",
  [sym_indirect_access] = "indirect_access",
  [sym_field_expression] = "field_expression",
  [sym_not_operator] = "not_operator",
  [sym_metaclass_operator] = "metaclass_operator",
  [sym_handle_operator] = "handle_operator",
  [sym_comparison_operator] = "comparison_operator",
  [sym_boolean_operator] = "boolean_operator",
  [sym_postfix_operator] = "postfix_operator",
  [sym_string] = "string",
  [sym_row] = "row",
  [sym_matrix] = "matrix",
  [sym_cell] = "cell",
  [sym_ignored_argument] = "ignored_argument",
  [sym_assignment] = "assignment",
  [sym_multioutput_variable] = "multioutput_variable",
  [sym_spread_operator] = "spread_operator",
  [sym_arguments] = "arguments",
  [sym__args] = "_args",
  [sym_function_call] = "function_call",
  [sym_command] = "command",
  [sym__range_element] = "_range_element",
  [sym_range] = "range",
  [sym_elseif_clause] = "elseif_clause",
  [sym_else_clause] = "else_clause",
  [sym_if_statement] = "if_statement",
  [sym_iterator] = "iterator",
  [sym_parfor_options] = "parfor_options",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_case_clause] = "case_clause",
  [sym_otherwise_clause] = "otherwise_clause",
  [sym_switch_statement] = "switch_statement",
  [sym__lambda_arguments] = "_lambda_arguments",
  [sym_lambda] = "lambda",
  [sym_global_operator] = "global_operator",
  [sym_persistent_operator] = "persistent_operator",
  [sym__argument_attributes] = "attributes",
  [sym_arguments_statement] = "arguments_statement",
  [sym_function_output] = "function_output",
  [sym_function_arguments] = "function_arguments",
  [sym_function_definition] = "function_definition",
  [sym__function_definition_with_end] = "function_definition",
  [sym_attribute] = "attribute",
  [sym_attributes] = "attributes",
  [sym_superclasses] = "superclasses",
  [sym_dimensions] = "dimensions",
  [sym_validation_functions] = "validation_functions",
  [sym_default_value] = "default_value",
  [sym_property_name] = "property_name",
  [sym_property] = "property",
  [sym_properties] = "properties",
  [sym_function_signature] = "function_signature",
  [sym_methods] = "methods",
  [sym_events] = "events",
  [sym__enum_value] = "_enum_value",
  [sym_enum] = "enum",
  [sym_enumeration] = "enumeration",
  [sym_class_definition] = "class_definition",
  [sym_catch_clause] = "catch_clause",
  [sym_try_statement] = "try_statement",
  [sym_boolean] = "boolean",
  [sym__end_of_line] = "_end_of_line",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym__block_repeat1] = "_block_repeat1",
  [aux_sym_field_expression_repeat1] = "field_expression_repeat1",
  [aux_sym_metaclass_operator_repeat1] = "metaclass_operator_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_row_repeat1] = "row_repeat1",
  [aux_sym_matrix_repeat1] = "matrix_repeat1",
  [aux_sym_multioutput_variable_repeat1] = "multioutput_variable_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_arguments_repeat2] = "arguments_repeat2",
  [aux_sym_command_repeat1] = "command_repeat1",
  [aux_sym_elseif_clause_repeat1] = "elseif_clause_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_switch_statement_repeat1] = "switch_statement_repeat1",
  [aux_sym__lambda_arguments_repeat1] = "_lambda_arguments_repeat1",
  [aux_sym_global_operator_repeat1] = "global_operator_repeat1",
  [aux_sym__argument_attributes_repeat1] = "_argument_attributes_repeat1",
  [aux_sym_arguments_statement_repeat1] = "arguments_statement_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_attributes_repeat1] = "attributes_repeat1",
  [aux_sym_superclasses_repeat1] = "superclasses_repeat1",
  [aux_sym_dimensions_repeat1] = "dimensions_repeat1",
  [aux_sym_validation_functions_repeat1] = "validation_functions_repeat1",
  [aux_sym_methods_repeat1] = "methods_repeat1",
  [aux_sym_events_repeat1] = "events_repeat1",
  [aux_sym_enum_repeat1] = "enum_repeat1",
  [aux_sym_enumeration_repeat1] = "enumeration_repeat1",
  [aux_sym_class_definition_repeat1] = "class_definition_repeat1",
  [alias_sym_superclass] = "superclass",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DOT_PLUS] = anon_sym_DOT_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_DOT_DASH] = anon_sym_DOT_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_DOT_STAR] = anon_sym_DOT_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_DOT_SLASH] = anon_sym_DOT_SLASH,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [anon_sym_DOT_BSLASH] = anon_sym_DOT_BSLASH,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_DOT_CARET] = anon_sym_DOT_CARET,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_TILDE_EQ] = anon_sym_TILDE_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_DOT_SQUOTE] = anon_sym_DOT_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [aux_sym_matrix_token1] = aux_sym_matrix_token1,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_COLON] = anon_sym_COLON,
  [sym_return_statement] = sym_return_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [anon_sym_elseif] = anon_sym_elseif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_parfor] = anon_sym_parfor,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_otherwise] = anon_sym_otherwise,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_persistent] = anon_sym_persistent,
  [anon_sym_arguments] = anon_sym_arguments,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_get_DOT] = anon_sym_get_DOT,
  [anon_sym_set_DOT] = anon_sym_set_DOT,
  [anon_sym_endfunction] = anon_sym_endfunction,
  [anon_sym_vector] = sym_identifier,
  [anon_sym_matrix] = sym_identifier,
  [anon_sym_scalar] = sym_identifier,
  [anon_sym_properties] = anon_sym_properties,
  [anon_sym_methods] = anon_sym_methods,
  [anon_sym_events] = anon_sym_events,
  [anon_sym_enumeration] = anon_sym_enumeration,
  [anon_sym_classdef] = anon_sym_classdef,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_try] = anon_sym_try,
  [sym_number] = sym_number,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_CR] = anon_sym_CR,
  [sym_comment] = sym_comment,
  [sym_line_continuation] = sym_line_continuation,
  [sym_command_name] = sym_command_name,
  [sym_command_argument] = sym_command_argument,
  [sym__single_quote_string_start] = anon_sym_SQUOTE,
  [sym__single_quote_string_end] = anon_sym_SQUOTE,
  [sym__double_quote_string_start] = sym__double_quote_string_start,
  [sym__double_quote_string_end] = sym__double_quote_string_start,
  [sym_formatting_sequence] = sym_formatting_sequence,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_string_content] = sym_string_content,
  [sym__entry_delimiter] = anon_sym_SEMI,
  [sym__multioutput_variable_start] = anon_sym_LBRACK,
  [sym_error_sentinel] = sym_error_sentinel,
  [sym_source_file] = sym_source_file,
  [aux_sym__block] = aux_sym__block,
  [sym_block] = sym_block,
  [sym__statement] = sym__statement,
  [sym__expression] = sym__expression,
  [sym_parenthesis] = sym_parenthesis,
  [sym__binary_expression] = sym__binary_expression,
  [sym_binary_operator] = sym_binary_operator,
  [sym_unary_operator] = sym_unary_operator,
  [sym_indirect_access] = sym_indirect_access,
  [sym_field_expression] = sym_field_expression,
  [sym_not_operator] = sym_not_operator,
  [sym_metaclass_operator] = sym_metaclass_operator,
  [sym_handle_operator] = sym_handle_operator,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_boolean_operator] = sym_boolean_operator,
  [sym_postfix_operator] = sym_postfix_operator,
  [sym_string] = sym_string,
  [sym_row] = sym_row,
  [sym_matrix] = sym_matrix,
  [sym_cell] = sym_cell,
  [sym_ignored_argument] = sym_ignored_argument,
  [sym_assignment] = sym_assignment,
  [sym_multioutput_variable] = sym_multioutput_variable,
  [sym_spread_operator] = sym_spread_operator,
  [sym_arguments] = sym_arguments,
  [sym__args] = sym__args,
  [sym_function_call] = sym_function_call,
  [sym_command] = sym_command,
  [sym__range_element] = sym__range_element,
  [sym_range] = sym_range,
  [sym_elseif_clause] = sym_elseif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_if_statement] = sym_if_statement,
  [sym_iterator] = sym_iterator,
  [sym_parfor_options] = sym_parfor_options,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_case_clause] = sym_case_clause,
  [sym_otherwise_clause] = sym_otherwise_clause,
  [sym_switch_statement] = sym_switch_statement,
  [sym__lambda_arguments] = sym__lambda_arguments,
  [sym_lambda] = sym_lambda,
  [sym_global_operator] = sym_global_operator,
  [sym_persistent_operator] = sym_persistent_operator,
  [sym__argument_attributes] = sym_attributes,
  [sym_arguments_statement] = sym_arguments_statement,
  [sym_function_output] = sym_function_output,
  [sym_function_arguments] = sym_function_arguments,
  [sym_function_definition] = sym_function_definition,
  [sym__function_definition_with_end] = sym_function_definition,
  [sym_attribute] = sym_attribute,
  [sym_attributes] = sym_attributes,
  [sym_superclasses] = sym_superclasses,
  [sym_dimensions] = sym_dimensions,
  [sym_validation_functions] = sym_validation_functions,
  [sym_default_value] = sym_default_value,
  [sym_property_name] = sym_property_name,
  [sym_property] = sym_property,
  [sym_properties] = sym_properties,
  [sym_function_signature] = sym_function_signature,
  [sym_methods] = sym_methods,
  [sym_events] = sym_events,
  [sym__enum_value] = sym__enum_value,
  [sym_enum] = sym_enum,
  [sym_enumeration] = sym_enumeration,
  [sym_class_definition] = sym_class_definition,
  [sym_catch_clause] = sym_catch_clause,
  [sym_try_statement] = sym_try_statement,
  [sym_boolean] = sym_boolean,
  [sym__end_of_line] = sym__end_of_line,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym__block_repeat1] = aux_sym__block_repeat1,
  [aux_sym_field_expression_repeat1] = aux_sym_field_expression_repeat1,
  [aux_sym_metaclass_operator_repeat1] = aux_sym_metaclass_operator_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_row_repeat1] = aux_sym_row_repeat1,
  [aux_sym_matrix_repeat1] = aux_sym_matrix_repeat1,
  [aux_sym_multioutput_variable_repeat1] = aux_sym_multioutput_variable_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_arguments_repeat2] = aux_sym_arguments_repeat2,
  [aux_sym_command_repeat1] = aux_sym_command_repeat1,
  [aux_sym_elseif_clause_repeat1] = aux_sym_elseif_clause_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_switch_statement_repeat1] = aux_sym_switch_statement_repeat1,
  [aux_sym__lambda_arguments_repeat1] = aux_sym__lambda_arguments_repeat1,
  [aux_sym_global_operator_repeat1] = aux_sym_global_operator_repeat1,
  [aux_sym__argument_attributes_repeat1] = aux_sym__argument_attributes_repeat1,
  [aux_sym_arguments_statement_repeat1] = aux_sym_arguments_statement_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_attributes_repeat1] = aux_sym_attributes_repeat1,
  [aux_sym_superclasses_repeat1] = aux_sym_superclasses_repeat1,
  [aux_sym_dimensions_repeat1] = aux_sym_dimensions_repeat1,
  [aux_sym_validation_functions_repeat1] = aux_sym_validation_functions_repeat1,
  [aux_sym_methods_repeat1] = aux_sym_methods_repeat1,
  [aux_sym_events_repeat1] = aux_sym_events_repeat1,
  [aux_sym_enum_repeat1] = aux_sym_enum_repeat1,
  [aux_sym_enumeration_repeat1] = aux_sym_enumeration_repeat1,
  [aux_sym_class_definition_repeat1] = aux_sym_class_definition_repeat1,
  [alias_sym_superclass] = alias_sym_superclass,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_matrix_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_elseif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_parfor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_otherwise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_persistent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_arguments] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endfunction] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vector] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_scalar] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_properties] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_methods] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_events] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumeration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_classdef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CR] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_line_continuation] = {
    .visible = true,
    .named = true,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_command_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__single_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__single_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym_formatting_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__entry_delimiter] = {
    .visible = true,
    .named = false,
  },
  [sym__multioutput_variable_start] = {
    .visible = true,
    .named = false,
  },
  [sym_error_sentinel] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__block] = {
    .visible = false,
    .named = false,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesis] = {
    .visible = true,
    .named = true,
  },
  [sym__binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indirect_access] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_not_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_metaclass_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_handle_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_row] = {
    .visible = true,
    .named = true,
  },
  [sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [sym_cell] = {
    .visible = true,
    .named = true,
  },
  [sym_ignored_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_multioutput_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_spread_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__args] = {
    .visible = false,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_command] = {
    .visible = true,
    .named = true,
  },
  [sym__range_element] = {
    .visible = false,
    .named = true,
  },
  [sym_range] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_iterator] = {
    .visible = true,
    .named = true,
  },
  [sym_parfor_options] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_otherwise_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__lambda_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_global_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_persistent_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__argument_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_function_output] = {
    .visible = true,
    .named = true,
  },
  [sym_function_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__function_definition_with_end] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_superclasses] = {
    .visible = true,
    .named = true,
  },
  [sym_dimensions] = {
    .visible = true,
    .named = true,
  },
  [sym_validation_functions] = {
    .visible = true,
    .named = true,
  },
  [sym_default_value] = {
    .visible = true,
    .named = true,
  },
  [sym_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym_properties] = {
    .visible = true,
    .named = true,
  },
  [sym_function_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_methods] = {
    .visible = true,
    .named = true,
  },
  [sym_events] = {
    .visible = true,
    .named = true,
  },
  [sym__enum_value] = {
    .visible = false,
    .named = true,
  },
  [sym_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_enumeration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym__end_of_line] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metaclass_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_row_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_matrix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_multioutput_variable_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_elseif_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__lambda_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__argument_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_superclasses_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dimensions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_validation_functions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_methods_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_events_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumeration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_superclass] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_argument = 1,
  field_arguments = 2,
  field_condition = 3,
  field_expression = 4,
  field_field = 5,
  field_left = 6,
  field_name = 7,
  field_object = 8,
  field_operand = 9,
  field_right = 10,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_condition] = "condition",
  [field_expression] = "expression",
  [field_field] = "field",
  [field_left] = "left",
  [field_name] = "name",
  [field_object] = "object",
  [field_operand] = "operand",
  [field_right] = "right",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 1},
  [6] = {.index = 2, .length = 1},
  [7] = {.index = 6, .length = 1},
  [8] = {.index = 7, .length = 1},
  [9] = {.index = 8, .length = 1},
  [10] = {.index = 9, .length = 1},
  [11] = {.index = 10, .length = 2},
  [12] = {.index = 12, .length = 2},
  [13] = {.index = 14, .length = 1},
  [14] = {.index = 15, .length = 1},
  [15] = {.index = 16, .length = 2},
  [16] = {.index = 2, .length = 1},
  [17] = {.index = 2, .length = 1},
  [18] = {.index = 18, .length = 1},
  [19] = {.index = 19, .length = 1},
  [20] = {.index = 20, .length = 1},
  [21] = {.index = 21, .length = 1},
  [22] = {.index = 22, .length = 2},
  [23] = {.index = 24, .length = 1},
  [24] = {.index = 25, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_operand, 1},
  [1] =
    {field_operand, 0},
  [2] =
    {field_name, 0},
  [3] =
    {field_field, 1, .inherited = true},
    {field_object, 0},
  [5] =
    {field_name, 0, .inherited = true},
  [6] =
    {field_condition, 1},
  [7] =
    {field_name, 1},
  [8] =
    {field_argument, 0},
  [9] =
    {field_field, 1},
  [10] =
    {field_left, 0},
    {field_right, 2},
  [12] =
    {field_field, 0, .inherited = true},
    {field_field, 1, .inherited = true},
  [14] =
    {field_expression, 3},
  [15] =
    {field_name, 2},
  [16] =
    {field_argument, 0},
    {field_argument, 1, .inherited = true},
  [18] =
    {field_expression, 4},
  [19] =
    {field_arguments, 1},
  [20] =
    {field_name, 3},
  [21] =
    {field_argument, 1},
  [22] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [24] =
    {field_argument, 1, .inherited = true},
  [25] =
    {field_argument, 1},
    {field_argument, 2, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [6] = {
    [0] = sym_identifier,
  },
  [16] = {
    [2] = alias_sym_superclass,
  },
  [17] = {
    [0] = sym_identifier,
    [2] = alias_sym_superclass,
  },
  [18] = {
    [2] = sym_arguments,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__lambda_arguments, 2,
    sym__lambda_arguments,
    sym_arguments,
  sym_property_name, 2,
    sym_property_name,
    alias_sym_superclass,
  sym_boolean, 2,
    sym_boolean,
    sym_identifier,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 47,
  [56] = 56,
  [57] = 57,
  [58] = 53,
  [59] = 59,
  [60] = 60,
  [61] = 45,
  [62] = 57,
  [63] = 59,
  [64] = 46,
  [65] = 49,
  [66] = 54,
  [67] = 50,
  [68] = 56,
  [69] = 51,
  [70] = 52,
  [71] = 71,
  [72] = 48,
  [73] = 60,
  [74] = 48,
  [75] = 60,
  [76] = 76,
  [77] = 76,
  [78] = 76,
  [79] = 79,
  [80] = 76,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 91,
  [93] = 93,
  [94] = 91,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 91,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 104,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 106,
  [138] = 129,
  [139] = 131,
  [140] = 104,
  [141] = 131,
  [142] = 104,
  [143] = 132,
  [144] = 129,
  [145] = 129,
  [146] = 131,
  [147] = 132,
  [148] = 135,
  [149] = 134,
  [150] = 133,
  [151] = 136,
  [152] = 82,
  [153] = 85,
  [154] = 81,
  [155] = 84,
  [156] = 83,
  [157] = 93,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 166,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 172,
  [177] = 166,
  [178] = 172,
  [179] = 174,
  [180] = 174,
  [181] = 175,
  [182] = 174,
  [183] = 175,
  [184] = 172,
  [185] = 166,
  [186] = 175,
  [187] = 172,
  [188] = 166,
  [189] = 76,
  [190] = 76,
  [191] = 79,
  [192] = 86,
  [193] = 76,
  [194] = 76,
  [195] = 89,
  [196] = 196,
  [197] = 197,
  [198] = 99,
  [199] = 199,
  [200] = 95,
  [201] = 201,
  [202] = 90,
  [203] = 101,
  [204] = 96,
  [205] = 98,
  [206] = 97,
  [207] = 76,
  [208] = 208,
  [209] = 76,
  [210] = 91,
  [211] = 91,
  [212] = 79,
  [213] = 91,
  [214] = 91,
  [215] = 215,
  [216] = 216,
  [217] = 76,
  [218] = 218,
  [219] = 219,
  [220] = 161,
  [221] = 76,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 222,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 224,
  [239] = 239,
  [240] = 225,
  [241] = 226,
  [242] = 227,
  [243] = 222,
  [244] = 235,
  [245] = 229,
  [246] = 230,
  [247] = 231,
  [248] = 232,
  [249] = 249,
  [250] = 224,
  [251] = 225,
  [252] = 226,
  [253] = 227,
  [254] = 229,
  [255] = 230,
  [256] = 231,
  [257] = 232,
  [258] = 233,
  [259] = 259,
  [260] = 233,
  [261] = 86,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 234,
  [266] = 235,
  [267] = 267,
  [268] = 103,
  [269] = 269,
  [270] = 270,
  [271] = 224,
  [272] = 225,
  [273] = 226,
  [274] = 274,
  [275] = 275,
  [276] = 233,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 88,
  [281] = 234,
  [282] = 282,
  [283] = 224,
  [284] = 225,
  [285] = 226,
  [286] = 233,
  [287] = 234,
  [288] = 224,
  [289] = 225,
  [290] = 226,
  [291] = 233,
  [292] = 234,
  [293] = 293,
  [294] = 294,
  [295] = 224,
  [296] = 225,
  [297] = 226,
  [298] = 233,
  [299] = 299,
  [300] = 234,
  [301] = 234,
  [302] = 249,
  [303] = 168,
  [304] = 224,
  [305] = 225,
  [306] = 226,
  [307] = 227,
  [308] = 222,
  [309] = 229,
  [310] = 230,
  [311] = 231,
  [312] = 262,
  [313] = 232,
  [314] = 173,
  [315] = 237,
  [316] = 249,
  [317] = 233,
  [318] = 169,
  [319] = 233,
  [320] = 267,
  [321] = 234,
  [322] = 165,
  [323] = 234,
  [324] = 170,
  [325] = 235,
  [326] = 262,
  [327] = 327,
  [328] = 237,
  [329] = 249,
  [330] = 262,
  [331] = 331,
  [332] = 237,
  [333] = 237,
  [334] = 87,
  [335] = 223,
  [336] = 233,
  [337] = 234,
  [338] = 233,
  [339] = 234,
  [340] = 233,
  [341] = 234,
  [342] = 223,
  [343] = 233,
  [344] = 234,
  [345] = 223,
  [346] = 79,
  [347] = 91,
  [348] = 76,
  [349] = 84,
  [350] = 85,
  [351] = 96,
  [352] = 91,
  [353] = 81,
  [354] = 95,
  [355] = 82,
  [356] = 356,
  [357] = 76,
  [358] = 76,
  [359] = 76,
  [360] = 91,
  [361] = 91,
  [362] = 99,
  [363] = 98,
  [364] = 83,
  [365] = 101,
  [366] = 76,
  [367] = 90,
  [368] = 89,
  [369] = 97,
  [370] = 370,
  [371] = 371,
  [372] = 86,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 93,
  [377] = 103,
  [378] = 378,
  [379] = 104,
  [380] = 84,
  [381] = 85,
  [382] = 119,
  [383] = 81,
  [384] = 82,
  [385] = 83,
  [386] = 124,
  [387] = 95,
  [388] = 125,
  [389] = 87,
  [390] = 98,
  [391] = 375,
  [392] = 120,
  [393] = 375,
  [394] = 133,
  [395] = 131,
  [396] = 104,
  [397] = 104,
  [398] = 91,
  [399] = 131,
  [400] = 104,
  [401] = 132,
  [402] = 134,
  [403] = 375,
  [404] = 91,
  [405] = 91,
  [406] = 129,
  [407] = 91,
  [408] = 121,
  [409] = 129,
  [410] = 97,
  [411] = 126,
  [412] = 123,
  [413] = 114,
  [414] = 99,
  [415] = 115,
  [416] = 108,
  [417] = 116,
  [418] = 88,
  [419] = 109,
  [420] = 105,
  [421] = 117,
  [422] = 129,
  [423] = 118,
  [424] = 135,
  [425] = 128,
  [426] = 106,
  [427] = 110,
  [428] = 111,
  [429] = 131,
  [430] = 129,
  [431] = 132,
  [432] = 375,
  [433] = 375,
  [434] = 131,
  [435] = 101,
  [436] = 122,
  [437] = 106,
  [438] = 90,
  [439] = 375,
  [440] = 107,
  [441] = 112,
  [442] = 113,
  [443] = 102,
  [444] = 89,
  [445] = 136,
  [446] = 96,
  [447] = 127,
  [448] = 103,
  [449] = 449,
  [450] = 93,
  [451] = 129,
  [452] = 122,
  [453] = 129,
  [454] = 123,
  [455] = 124,
  [456] = 456,
  [457] = 125,
  [458] = 112,
  [459] = 115,
  [460] = 81,
  [461] = 135,
  [462] = 87,
  [463] = 88,
  [464] = 104,
  [465] = 117,
  [466] = 136,
  [467] = 113,
  [468] = 119,
  [469] = 82,
  [470] = 131,
  [471] = 118,
  [472] = 104,
  [473] = 104,
  [474] = 105,
  [475] = 475,
  [476] = 84,
  [477] = 83,
  [478] = 116,
  [479] = 126,
  [480] = 107,
  [481] = 131,
  [482] = 127,
  [483] = 114,
  [484] = 108,
  [485] = 131,
  [486] = 104,
  [487] = 109,
  [488] = 132,
  [489] = 110,
  [490] = 111,
  [491] = 85,
  [492] = 132,
  [493] = 132,
  [494] = 106,
  [495] = 129,
  [496] = 120,
  [497] = 102,
  [498] = 121,
  [499] = 129,
  [500] = 133,
  [501] = 128,
  [502] = 131,
  [503] = 134,
  [504] = 106,
  [505] = 135,
  [506] = 133,
  [507] = 134,
  [508] = 93,
  [509] = 136,
  [510] = 124,
  [511] = 129,
  [512] = 131,
  [513] = 105,
  [514] = 106,
  [515] = 107,
  [516] = 108,
  [517] = 109,
  [518] = 110,
  [519] = 111,
  [520] = 112,
  [521] = 113,
  [522] = 102,
  [523] = 114,
  [524] = 115,
  [525] = 116,
  [526] = 117,
  [527] = 118,
  [528] = 119,
  [529] = 120,
  [530] = 121,
  [531] = 122,
  [532] = 123,
  [533] = 125,
  [534] = 126,
  [535] = 127,
  [536] = 132,
  [537] = 104,
  [538] = 131,
  [539] = 129,
  [540] = 132,
  [541] = 133,
  [542] = 134,
  [543] = 135,
  [544] = 136,
  [545] = 129,
  [546] = 106,
  [547] = 104,
  [548] = 131,
  [549] = 104,
  [550] = 131,
  [551] = 104,
  [552] = 132,
  [553] = 129,
  [554] = 128,
  [555] = 555,
  [556] = 135,
  [557] = 136,
  [558] = 558,
  [559] = 134,
  [560] = 560,
  [561] = 133,
  [562] = 562,
  [563] = 563,
  [564] = 562,
  [565] = 560,
  [566] = 563,
  [567] = 562,
  [568] = 560,
  [569] = 569,
  [570] = 563,
  [571] = 563,
  [572] = 562,
  [573] = 560,
  [574] = 560,
  [575] = 563,
  [576] = 562,
  [577] = 132,
  [578] = 563,
  [579] = 562,
  [580] = 560,
  [581] = 581,
  [582] = 133,
  [583] = 129,
  [584] = 135,
  [585] = 129,
  [586] = 129,
  [587] = 134,
  [588] = 136,
  [589] = 106,
  [590] = 106,
  [591] = 106,
  [592] = 83,
  [593] = 93,
  [594] = 594,
  [595] = 595,
  [596] = 84,
  [597] = 81,
  [598] = 82,
  [599] = 85,
  [600] = 600,
  [601] = 83,
  [602] = 82,
  [603] = 83,
  [604] = 84,
  [605] = 85,
  [606] = 81,
  [607] = 607,
  [608] = 93,
  [609] = 93,
  [610] = 610,
  [611] = 607,
  [612] = 612,
  [613] = 613,
  [614] = 607,
  [615] = 615,
  [616] = 607,
  [617] = 85,
  [618] = 618,
  [619] = 619,
  [620] = 620,
  [621] = 620,
  [622] = 81,
  [623] = 82,
  [624] = 624,
  [625] = 620,
  [626] = 84,
  [627] = 627,
  [628] = 628,
  [629] = 629,
  [630] = 630,
  [631] = 99,
  [632] = 632,
  [633] = 633,
  [634] = 634,
  [635] = 635,
  [636] = 636,
  [637] = 637,
  [638] = 638,
  [639] = 95,
  [640] = 101,
  [641] = 641,
  [642] = 90,
  [643] = 89,
  [644] = 98,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 657,
  [658] = 658,
  [659] = 659,
  [660] = 86,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 669,
  [670] = 670,
  [671] = 96,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 88,
  [676] = 676,
  [677] = 677,
  [678] = 678,
  [679] = 160,
  [680] = 676,
  [681] = 87,
  [682] = 158,
  [683] = 683,
  [684] = 676,
  [685] = 676,
  [686] = 686,
  [687] = 678,
  [688] = 688,
  [689] = 688,
  [690] = 690,
  [691] = 688,
  [692] = 692,
  [693] = 688,
  [694] = 694,
  [695] = 688,
  [696] = 694,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 701,
  [702] = 702,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 706,
  [707] = 707,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 718,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 731,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 738,
  [739] = 739,
  [740] = 731,
  [741] = 741,
  [742] = 742,
  [743] = 743,
  [744] = 744,
  [745] = 745,
  [746] = 746,
  [747] = 731,
  [748] = 731,
  [749] = 698,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 752,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 823,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 824,
  [843] = 843,
  [844] = 844,
  [845] = 834,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 843,
  [850] = 850,
  [851] = 851,
  [852] = 851,
  [853] = 841,
  [854] = 824,
  [855] = 855,
  [856] = 856,
  [857] = 857,
  [858] = 823,
  [859] = 859,
  [860] = 860,
  [861] = 861,
  [862] = 834,
  [863] = 841,
  [864] = 864,
  [865] = 846,
  [866] = 866,
  [867] = 867,
  [868] = 841,
  [869] = 824,
  [870] = 870,
  [871] = 831,
  [872] = 823,
  [873] = 823,
  [874] = 874,
  [875] = 875,
  [876] = 876,
  [877] = 834,
  [878] = 823,
  [879] = 879,
  [880] = 846,
  [881] = 843,
  [882] = 823,
  [883] = 823,
  [884] = 823,
  [885] = 823,
  [886] = 886,
  [887] = 887,
  [888] = 830,
  [889] = 844,
  [890] = 890,
  [891] = 867,
  [892] = 851,
  [893] = 893,
  [894] = 823,
  [895] = 823,
  [896] = 823,
  [897] = 846,
  [898] = 898,
  [899] = 899,
  [900] = 715,
  [901] = 716,
  [902] = 717,
  [903] = 903,
  [904] = 904,
  [905] = 905,
  [906] = 906,
  [907] = 714,
  [908] = 908,
  [909] = 909,
  [910] = 707,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 917,
  [918] = 918,
  [919] = 919,
  [920] = 920,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 739,
  [934] = 934,
  [935] = 935,
  [936] = 936,
  [937] = 708,
  [938] = 938,
  [939] = 939,
  [940] = 709,
  [941] = 941,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 945,
  [946] = 946,
  [947] = 947,
  [948] = 948,
  [949] = 949,
  [950] = 950,
  [951] = 938,
  [952] = 719,
  [953] = 720,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 905,
  [959] = 914,
  [960] = 960,
  [961] = 941,
  [962] = 713,
  [963] = 963,
  [964] = 964,
  [965] = 965,
  [966] = 966,
  [967] = 967,
  [968] = 968,
  [969] = 969,
  [970] = 970,
  [971] = 954,
  [972] = 641,
  [973] = 973,
  [974] = 974,
  [975] = 938,
  [976] = 976,
  [977] = 977,
  [978] = 954,
  [979] = 979,
  [980] = 905,
  [981] = 914,
  [982] = 941,
  [983] = 944,
  [984] = 984,
  [985] = 938,
  [986] = 986,
  [987] = 954,
  [988] = 988,
  [989] = 905,
  [990] = 914,
  [991] = 991,
  [992] = 750,
  [993] = 941,
  [994] = 944,
  [995] = 938,
  [996] = 954,
  [997] = 997,
  [998] = 998,
  [999] = 999,
  [1000] = 1000,
  [1001] = 1001,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 712,
  [1008] = 1008,
  [1009] = 944,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1018,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1032,
  [1033] = 1033,
  [1034] = 1017,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1041,
  [1042] = 1042,
  [1043] = 1043,
  [1044] = 1044,
  [1045] = 1045,
  [1046] = 1032,
  [1047] = 1047,
  [1048] = 1048,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1052,
  [1053] = 1032,
  [1054] = 1033,
  [1055] = 1055,
  [1056] = 1056,
  [1057] = 1057,
  [1058] = 1058,
  [1059] = 1033,
  [1060] = 1060,
  [1061] = 1032,
  [1062] = 1033,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1045,
  [1066] = 1032,
  [1067] = 1033,
  [1068] = 1068,
  [1069] = 1069,
  [1070] = 1070,
  [1071] = 1071,
  [1072] = 1031,
  [1073] = 1073,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 1078,
  [1079] = 1079,
  [1080] = 1080,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1083,
  [1086] = 1086,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 1093,
  [1094] = 1081,
  [1095] = 1095,
  [1096] = 1089,
  [1097] = 1081,
  [1098] = 1098,
  [1099] = 1099,
  [1100] = 1100,
  [1101] = 1098,
  [1102] = 1090,
  [1103] = 1103,
  [1104] = 670,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1092,
  [1108] = 1108,
  [1109] = 1088,
  [1110] = 1110,
  [1111] = 1111,
  [1112] = 1081,
  [1113] = 1082,
  [1114] = 1084,
  [1115] = 1087,
  [1116] = 1116,
  [1117] = 1117,
  [1118] = 1106,
  [1119] = 1119,
  [1120] = 1120,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1081,
  [1126] = 1081,
  [1127] = 1081,
  [1128] = 1081,
  [1129] = 1081,
  [1130] = 1081,
  [1131] = 1081,
  [1132] = 1132,
  [1133] = 1100,
  [1134] = 1119,
  [1135] = 1111,
  [1136] = 1136,
  [1137] = 669,
  [1138] = 1081,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1119,
  [1145] = 1111,
  [1146] = 1146,
  [1147] = 1086,
  [1148] = 1119,
  [1149] = 1111,
  [1150] = 1119,
  [1151] = 1111,
  [1152] = 1081,
  [1153] = 1153,
  [1154] = 1154,
  [1155] = 1154,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1160,
  [1161] = 1161,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1165,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 1164,
  [1169] = 1169,
  [1170] = 974,
  [1171] = 1171,
  [1172] = 1172,
  [1173] = 1173,
  [1174] = 1174,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1178,
  [1179] = 1179,
  [1180] = 1163,
  [1181] = 1163,
  [1182] = 1164,
  [1183] = 1167,
  [1184] = 1184,
  [1185] = 1169,
  [1186] = 1164,
  [1187] = 1171,
  [1188] = 1188,
  [1189] = 1189,
  [1190] = 1163,
  [1191] = 1164,
  [1192] = 1171,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1163,
  [1196] = 1164,
  [1197] = 1171,
  [1198] = 1171,
  [1199] = 1199,
  [1200] = 1163,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1163,
  [1207] = 1207,
  [1208] = 1162,
  [1209] = 1164,
  [1210] = 1210,
  [1211] = 984,
  [1212] = 1164,
  [1213] = 1213,
  [1214] = 1167,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 1169,
  [1218] = 1167,
  [1219] = 1171,
  [1220] = 1220,
  [1221] = 1221,
  [1222] = 1222,
  [1223] = 1169,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1164,
  [1227] = 1227,
  [1228] = 1164,
  [1229] = 1229,
  [1230] = 1164,
  [1231] = 1231,
  [1232] = 1171,
  [1233] = 1233,
  [1234] = 1169,
  [1235] = 1235,
  [1236] = 1236,
  [1237] = 1164,
  [1238] = 1171,
  [1239] = 1239,
  [1240] = 1163,
  [1241] = 1154,
  [1242] = 1167,
  [1243] = 1243,
  [1244] = 1224,
  [1245] = 1245,
  [1246] = 1233,
  [1247] = 1154,
  [1248] = 1164,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(16);
      ADVANCE_MAP(
        '&', 35,
        '\'', 53,
        '(', 19,
        ')', 20,
        '*', 25,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 38,
        '/', 27,
        ':', 61,
        ';', 17,
        '<', 44,
        '=', 60,
        '>', 49,
        '?', 42,
        '@', 43,
        '[', 54,
        '\\', 29,
        ']', 56,
        '^', 31,
        'g', 70,
        's', 71,
        '{', 57,
        '|', 33,
        '}', 58,
        '~', 41,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\n', 75,
        '\r', 76,
        '&', 35,
        '(', 19,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 39,
        ';', 17,
        '<', 44,
        '=', 60,
        '>', 49,
        '?', 42,
        '@', 43,
        '[', 54,
        '{', 57,
        '|', 10,
        '~', 41,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 75,
        '\r', 76,
        '&', 34,
        '(', 19,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 39,
        ';', 17,
        '=', 59,
        '?', 42,
        '@', 43,
        '[', 54,
        '{', 57,
        '~', 40,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '&', 35,
        '\'', 53,
        '(', 19,
        '*', 25,
        '+', 21,
        '-', 23,
        '.', 37,
        '/', 27,
        ':', 61,
        ';', 17,
        '<', 44,
        '=', 8,
        '>', 49,
        '@', 43,
        '\\', 29,
        ']', 56,
        '^', 31,
        '{', 57,
        '|', 33,
        '}', 58,
        '~', 9,
        '\n', 55,
        '\r', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(3);
      END_STATE();
    case 4:
      if (lookahead == '&') ADVANCE(50);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '&', 4,
        '(', 19,
        ')', 20,
        ',', 18,
        '.', 36,
        '<', 44,
        '=', 8,
        '>', 49,
        '{', 57,
        '|', 10,
        '}', 58,
        '~', 9,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '&', 4,
        '.', 36,
        ';', 17,
        '<', 44,
        '=', 8,
        '>', 49,
        ']', 56,
        '|', 10,
        '}', 58,
        '~', 9,
        '\n', 55,
        '\r', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(6);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '(', 19,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 12,
        ';', 17,
        '?', 42,
        '@', 43,
        '[', 54,
        ']', 56,
        '{', 57,
        '}', 58,
        '~', 40,
        '\n', 55,
        '\r', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 8:
      if (lookahead == '=') ADVANCE(46);
      END_STATE();
    case 9:
      if (lookahead == '=') ADVANCE(47);
      END_STATE();
    case 10:
      if (lookahead == '|') ADVANCE(51);
      END_STATE();
    case 11:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 12:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 13:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 14:
      if (eof) ADVANCE(16);
      ADVANCE_MAP(
        '\n', 75,
        '\r', 76,
        '&', 35,
        '\'', 53,
        '(', 19,
        '*', 25,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 38,
        '/', 27,
        ':', 61,
        ';', 17,
        '<', 44,
        '=', 60,
        '>', 49,
        '?', 42,
        '@', 43,
        '[', 54,
        '\\', 29,
        '^', 31,
        '{', 57,
        '|', 33,
        '~', 41,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(14);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 15:
      if (eof) ADVANCE(16);
      ADVANCE_MAP(
        '(', 19,
        ')', 20,
        '*', 25,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 39,
        ':', 61,
        ';', 17,
        '=', 59,
        '?', 42,
        '@', 43,
        '[', 54,
        ']', 56,
        '{', 57,
        '}', 58,
        '~', 40,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 16:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 17:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 18:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 19:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 20:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(anon_sym_DOT_PLUS);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 24:
      ACCEPT_TOKEN(anon_sym_DOT_DASH);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_DOT_STAR);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_DOT_SLASH);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_DOT_BSLASH);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_DOT_CARET);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(51);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(50);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(52);
      if (lookahead == '*') ADVANCE(26);
      if (lookahead == '+') ADVANCE(22);
      if (lookahead == '-') ADVANCE(24);
      if (lookahead == '/') ADVANCE(28);
      if (lookahead == '\\') ADVANCE(30);
      if (lookahead == '^') ADVANCE(32);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(52);
      if (lookahead == '*') ADVANCE(26);
      if (lookahead == '+') ADVANCE(22);
      if (lookahead == '-') ADVANCE(24);
      if (lookahead == '/') ADVANCE(28);
      if (lookahead == '\\') ADVANCE(30);
      if (lookahead == '^') ADVANCE(32);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '=') ADVANCE(47);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(45);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_TILDE_EQ);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(48);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_DOT_SQUOTE);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(aux_sym_matrix_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(55);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(46);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_get_DOT);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_set_DOT);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym_number);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(66);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(11);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(11);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(63);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(72);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(73);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(68);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(69);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(75);
      if (lookahead == '\r') ADVANCE(76);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_CR);
      if (lookahead == '\n') ADVANCE(75);
      if (lookahead == '\r') ADVANCE(76);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'a', 1,
        'b', 2,
        'c', 3,
        'e', 4,
        'f', 5,
        'g', 6,
        'i', 7,
        'm', 8,
        'o', 9,
        'p', 10,
        'r', 11,
        's', 12,
        't', 13,
        'v', 14,
        'w', 15,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'r') ADVANCE(16);
      END_STATE();
    case 2:
      if (lookahead == 'r') ADVANCE(17);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(18);
      if (lookahead == 'l') ADVANCE(19);
      if (lookahead == 'o') ADVANCE(20);
      END_STATE();
    case 4:
      if (lookahead == 'l') ADVANCE(21);
      if (lookahead == 'n') ADVANCE(22);
      if (lookahead == 'v') ADVANCE(23);
      END_STATE();
    case 5:
      if (lookahead == 'a') ADVANCE(24);
      if (lookahead == 'o') ADVANCE(25);
      if (lookahead == 'u') ADVANCE(26);
      END_STATE();
    case 6:
      if (lookahead == 'l') ADVANCE(27);
      END_STATE();
    case 7:
      if (lookahead == 'f') ADVANCE(28);
      END_STATE();
    case 8:
      if (lookahead == 'a') ADVANCE(29);
      if (lookahead == 'e') ADVANCE(30);
      END_STATE();
    case 9:
      if (lookahead == 't') ADVANCE(31);
      END_STATE();
    case 10:
      if (lookahead == 'a') ADVANCE(32);
      if (lookahead == 'e') ADVANCE(33);
      if (lookahead == 'r') ADVANCE(34);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(35);
      END_STATE();
    case 12:
      if (lookahead == 'c') ADVANCE(36);
      if (lookahead == 'w') ADVANCE(37);
      END_STATE();
    case 13:
      if (lookahead == 'r') ADVANCE(38);
      END_STATE();
    case 14:
      if (lookahead == 'e') ADVANCE(39);
      END_STATE();
    case 15:
      if (lookahead == 'h') ADVANCE(40);
      END_STATE();
    case 16:
      if (lookahead == 'g') ADVANCE(41);
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(42);
      END_STATE();
    case 18:
      if (lookahead == 's') ADVANCE(43);
      if (lookahead == 't') ADVANCE(44);
      END_STATE();
    case 19:
      if (lookahead == 'a') ADVANCE(45);
      END_STATE();
    case 20:
      if (lookahead == 'n') ADVANCE(46);
      END_STATE();
    case 21:
      if (lookahead == 's') ADVANCE(47);
      END_STATE();
    case 22:
      if (lookahead == 'd') ADVANCE(48);
      if (lookahead == 'u') ADVANCE(49);
      END_STATE();
    case 23:
      if (lookahead == 'e') ADVANCE(50);
      END_STATE();
    case 24:
      if (lookahead == 'l') ADVANCE(51);
      END_STATE();
    case 25:
      if (lookahead == 'r') ADVANCE(52);
      END_STATE();
    case 26:
      if (lookahead == 'n') ADVANCE(53);
      END_STATE();
    case 27:
      if (lookahead == 'o') ADVANCE(54);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 29:
      if (lookahead == 't') ADVANCE(55);
      END_STATE();
    case 30:
      if (lookahead == 't') ADVANCE(56);
      END_STATE();
    case 31:
      if (lookahead == 'h') ADVANCE(57);
      END_STATE();
    case 32:
      if (lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 33:
      if (lookahead == 'r') ADVANCE(59);
      END_STATE();
    case 34:
      if (lookahead == 'o') ADVANCE(60);
      END_STATE();
    case 35:
      if (lookahead == 't') ADVANCE(61);
      END_STATE();
    case 36:
      if (lookahead == 'a') ADVANCE(62);
      END_STATE();
    case 37:
      if (lookahead == 'i') ADVANCE(63);
      END_STATE();
    case 38:
      if (lookahead == 'u') ADVANCE(64);
      if (lookahead == 'y') ADVANCE(65);
      END_STATE();
    case 39:
      if (lookahead == 'c') ADVANCE(66);
      END_STATE();
    case 40:
      if (lookahead == 'i') ADVANCE(67);
      END_STATE();
    case 41:
      if (lookahead == 'u') ADVANCE(68);
      END_STATE();
    case 42:
      if (lookahead == 'a') ADVANCE(69);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 44:
      if (lookahead == 'c') ADVANCE(71);
      END_STATE();
    case 45:
      if (lookahead == 's') ADVANCE(72);
      END_STATE();
    case 46:
      if (lookahead == 't') ADVANCE(73);
      END_STATE();
    case 47:
      if (lookahead == 'e') ADVANCE(74);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_end);
      if (lookahead == 'f') ADVANCE(75);
      END_STATE();
    case 49:
      if (lookahead == 'm') ADVANCE(76);
      END_STATE();
    case 50:
      if (lookahead == 'n') ADVANCE(77);
      END_STATE();
    case 51:
      if (lookahead == 's') ADVANCE(78);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 53:
      if (lookahead == 'c') ADVANCE(79);
      END_STATE();
    case 54:
      if (lookahead == 'b') ADVANCE(80);
      END_STATE();
    case 55:
      if (lookahead == 'r') ADVANCE(81);
      END_STATE();
    case 56:
      if (lookahead == 'h') ADVANCE(82);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 58:
      if (lookahead == 'f') ADVANCE(84);
      END_STATE();
    case 59:
      if (lookahead == 's') ADVANCE(85);
      END_STATE();
    case 60:
      if (lookahead == 'p') ADVANCE(86);
      END_STATE();
    case 61:
      if (lookahead == 'u') ADVANCE(87);
      END_STATE();
    case 62:
      if (lookahead == 'l') ADVANCE(88);
      END_STATE();
    case 63:
      if (lookahead == 't') ADVANCE(89);
      END_STATE();
    case 64:
      if (lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 66:
      if (lookahead == 't') ADVANCE(91);
      END_STATE();
    case 67:
      if (lookahead == 'l') ADVANCE(92);
      END_STATE();
    case 68:
      if (lookahead == 'm') ADVANCE(93);
      END_STATE();
    case 69:
      if (lookahead == 'k') ADVANCE(94);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 71:
      if (lookahead == 'h') ADVANCE(95);
      END_STATE();
    case 72:
      if (lookahead == 's') ADVANCE(96);
      END_STATE();
    case 73:
      if (lookahead == 'i') ADVANCE(97);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == 'i') ADVANCE(98);
      END_STATE();
    case 75:
      if (lookahead == 'u') ADVANCE(99);
      END_STATE();
    case 76:
      if (lookahead == 'e') ADVANCE(100);
      END_STATE();
    case 77:
      if (lookahead == 't') ADVANCE(101);
      END_STATE();
    case 78:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 79:
      if (lookahead == 't') ADVANCE(103);
      END_STATE();
    case 80:
      if (lookahead == 'a') ADVANCE(104);
      END_STATE();
    case 81:
      if (lookahead == 'i') ADVANCE(105);
      END_STATE();
    case 82:
      if (lookahead == 'o') ADVANCE(106);
      END_STATE();
    case 83:
      if (lookahead == 'r') ADVANCE(107);
      END_STATE();
    case 84:
      if (lookahead == 'o') ADVANCE(108);
      END_STATE();
    case 85:
      if (lookahead == 'i') ADVANCE(109);
      END_STATE();
    case 86:
      if (lookahead == 'e') ADVANCE(110);
      END_STATE();
    case 87:
      if (lookahead == 'r') ADVANCE(111);
      END_STATE();
    case 88:
      if (lookahead == 'a') ADVANCE(112);
      END_STATE();
    case 89:
      if (lookahead == 'c') ADVANCE(113);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 91:
      if (lookahead == 'o') ADVANCE(114);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(115);
      END_STATE();
    case 93:
      if (lookahead == 'e') ADVANCE(116);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(sym_break_statement);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 96:
      if (lookahead == 'd') ADVANCE(117);
      END_STATE();
    case 97:
      if (lookahead == 'n') ADVANCE(118);
      END_STATE();
    case 98:
      if (lookahead == 'f') ADVANCE(119);
      END_STATE();
    case 99:
      if (lookahead == 'n') ADVANCE(120);
      END_STATE();
    case 100:
      if (lookahead == 'r') ADVANCE(121);
      END_STATE();
    case 101:
      if (lookahead == 's') ADVANCE(122);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 103:
      if (lookahead == 'i') ADVANCE(123);
      END_STATE();
    case 104:
      if (lookahead == 'l') ADVANCE(124);
      END_STATE();
    case 105:
      if (lookahead == 'x') ADVANCE(125);
      END_STATE();
    case 106:
      if (lookahead == 'd') ADVANCE(126);
      END_STATE();
    case 107:
      if (lookahead == 'w') ADVANCE(127);
      END_STATE();
    case 108:
      if (lookahead == 'r') ADVANCE(128);
      END_STATE();
    case 109:
      if (lookahead == 's') ADVANCE(129);
      END_STATE();
    case 110:
      if (lookahead == 'r') ADVANCE(130);
      END_STATE();
    case 111:
      if (lookahead == 'n') ADVANCE(131);
      END_STATE();
    case 112:
      if (lookahead == 'r') ADVANCE(132);
      END_STATE();
    case 113:
      if (lookahead == 'h') ADVANCE(133);
      END_STATE();
    case 114:
      if (lookahead == 'r') ADVANCE(134);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 116:
      if (lookahead == 'n') ADVANCE(135);
      END_STATE();
    case 117:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 118:
      if (lookahead == 'u') ADVANCE(137);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_elseif);
      END_STATE();
    case 120:
      if (lookahead == 'c') ADVANCE(138);
      END_STATE();
    case 121:
      if (lookahead == 'a') ADVANCE(139);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_events);
      END_STATE();
    case 123:
      if (lookahead == 'o') ADVANCE(140);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_matrix);
      END_STATE();
    case 126:
      if (lookahead == 's') ADVANCE(141);
      END_STATE();
    case 127:
      if (lookahead == 'i') ADVANCE(142);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_parfor);
      END_STATE();
    case 129:
      if (lookahead == 't') ADVANCE(143);
      END_STATE();
    case 130:
      if (lookahead == 't') ADVANCE(144);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_return_statement);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_scalar);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_vector);
      END_STATE();
    case 135:
      if (lookahead == 't') ADVANCE(145);
      END_STATE();
    case 136:
      if (lookahead == 'f') ADVANCE(146);
      END_STATE();
    case 137:
      if (lookahead == 'e') ADVANCE(147);
      END_STATE();
    case 138:
      if (lookahead == 't') ADVANCE(148);
      END_STATE();
    case 139:
      if (lookahead == 't') ADVANCE(149);
      END_STATE();
    case 140:
      if (lookahead == 'n') ADVANCE(150);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_methods);
      END_STATE();
    case 142:
      if (lookahead == 's') ADVANCE(151);
      END_STATE();
    case 143:
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 144:
      if (lookahead == 'i') ADVANCE(153);
      END_STATE();
    case 145:
      if (lookahead == 's') ADVANCE(154);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_classdef);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(sym_continue_statement);
      END_STATE();
    case 148:
      if (lookahead == 'i') ADVANCE(155);
      END_STATE();
    case 149:
      if (lookahead == 'i') ADVANCE(156);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 151:
      if (lookahead == 'e') ADVANCE(157);
      END_STATE();
    case 152:
      if (lookahead == 'n') ADVANCE(158);
      END_STATE();
    case 153:
      if (lookahead == 'e') ADVANCE(159);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_arguments);
      END_STATE();
    case 155:
      if (lookahead == 'o') ADVANCE(160);
      END_STATE();
    case 156:
      if (lookahead == 'o') ADVANCE(161);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_otherwise);
      END_STATE();
    case 158:
      if (lookahead == 't') ADVANCE(162);
      END_STATE();
    case 159:
      if (lookahead == 's') ADVANCE(163);
      END_STATE();
    case 160:
      if (lookahead == 'n') ADVANCE(164);
      END_STATE();
    case 161:
      if (lookahead == 'n') ADVANCE(165);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_persistent);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_properties);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_endfunction);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_enumeration);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 15, .external_lex_state = 2},
  [2] = {.lex_state = 14, .external_lex_state = 2},
  [3] = {.lex_state = 14, .external_lex_state = 2},
  [4] = {.lex_state = 14, .external_lex_state = 2},
  [5] = {.lex_state = 2, .external_lex_state = 2},
  [6] = {.lex_state = 2, .external_lex_state = 2},
  [7] = {.lex_state = 2, .external_lex_state = 2},
  [8] = {.lex_state = 2, .external_lex_state = 2},
  [9] = {.lex_state = 2, .external_lex_state = 2},
  [10] = {.lex_state = 2, .external_lex_state = 2},
  [11] = {.lex_state = 2, .external_lex_state = 2},
  [12] = {.lex_state = 2, .external_lex_state = 2},
  [13] = {.lex_state = 2, .external_lex_state = 2},
  [14] = {.lex_state = 2, .external_lex_state = 2},
  [15] = {.lex_state = 2, .external_lex_state = 2},
  [16] = {.lex_state = 2, .external_lex_state = 2},
  [17] = {.lex_state = 2, .external_lex_state = 2},
  [18] = {.lex_state = 2, .external_lex_state = 2},
  [19] = {.lex_state = 2, .external_lex_state = 2},
  [20] = {.lex_state = 2, .external_lex_state = 2},
  [21] = {.lex_state = 15, .external_lex_state = 2},
  [22] = {.lex_state = 15, .external_lex_state = 2},
  [23] = {.lex_state = 15, .external_lex_state = 2},
  [24] = {.lex_state = 15, .external_lex_state = 2},
  [25] = {.lex_state = 15, .external_lex_state = 2},
  [26] = {.lex_state = 15, .external_lex_state = 2},
  [27] = {.lex_state = 15, .external_lex_state = 2},
  [28] = {.lex_state = 15, .external_lex_state = 2},
  [29] = {.lex_state = 15, .external_lex_state = 2},
  [30] = {.lex_state = 15, .external_lex_state = 2},
  [31] = {.lex_state = 15, .external_lex_state = 2},
  [32] = {.lex_state = 15, .external_lex_state = 2},
  [33] = {.lex_state = 15, .external_lex_state = 2},
  [34] = {.lex_state = 15, .external_lex_state = 2},
  [35] = {.lex_state = 15, .external_lex_state = 2},
  [36] = {.lex_state = 15, .external_lex_state = 2},
  [37] = {.lex_state = 15, .external_lex_state = 2},
  [38] = {.lex_state = 15, .external_lex_state = 2},
  [39] = {.lex_state = 15, .external_lex_state = 2},
  [40] = {.lex_state = 15, .external_lex_state = 2},
  [41] = {.lex_state = 15, .external_lex_state = 2},
  [42] = {.lex_state = 15, .external_lex_state = 2},
  [43] = {.lex_state = 15, .external_lex_state = 2},
  [44] = {.lex_state = 15, .external_lex_state = 2},
  [45] = {.lex_state = 15, .external_lex_state = 2},
  [46] = {.lex_state = 15, .external_lex_state = 2},
  [47] = {.lex_state = 15, .external_lex_state = 2},
  [48] = {.lex_state = 15, .external_lex_state = 2},
  [49] = {.lex_state = 15, .external_lex_state = 2},
  [50] = {.lex_state = 15, .external_lex_state = 2},
  [51] = {.lex_state = 15, .external_lex_state = 2},
  [52] = {.lex_state = 15, .external_lex_state = 2},
  [53] = {.lex_state = 15, .external_lex_state = 2},
  [54] = {.lex_state = 15, .external_lex_state = 2},
  [55] = {.lex_state = 15, .external_lex_state = 2},
  [56] = {.lex_state = 15, .external_lex_state = 2},
  [57] = {.lex_state = 15, .external_lex_state = 2},
  [58] = {.lex_state = 15, .external_lex_state = 2},
  [59] = {.lex_state = 15, .external_lex_state = 2},
  [60] = {.lex_state = 15, .external_lex_state = 2},
  [61] = {.lex_state = 15, .external_lex_state = 2},
  [62] = {.lex_state = 15, .external_lex_state = 2},
  [63] = {.lex_state = 15, .external_lex_state = 2},
  [64] = {.lex_state = 15, .external_lex_state = 2},
  [65] = {.lex_state = 15, .external_lex_state = 2},
  [66] = {.lex_state = 15, .external_lex_state = 2},
  [67] = {.lex_state = 15, .external_lex_state = 2},
  [68] = {.lex_state = 15, .external_lex_state = 2},
  [69] = {.lex_state = 15, .external_lex_state = 2},
  [70] = {.lex_state = 15, .external_lex_state = 2},
  [71] = {.lex_state = 15, .external_lex_state = 2},
  [72] = {.lex_state = 15, .external_lex_state = 2},
  [73] = {.lex_state = 15, .external_lex_state = 2},
  [74] = {.lex_state = 15, .external_lex_state = 2},
  [75] = {.lex_state = 15, .external_lex_state = 2},
  [76] = {.lex_state = 14, .external_lex_state = 2},
  [77] = {.lex_state = 14, .external_lex_state = 2},
  [78] = {.lex_state = 14, .external_lex_state = 2},
  [79] = {.lex_state = 14, .external_lex_state = 2},
  [80] = {.lex_state = 14, .external_lex_state = 2},
  [81] = {.lex_state = 14, .external_lex_state = 2},
  [82] = {.lex_state = 14, .external_lex_state = 2},
  [83] = {.lex_state = 14, .external_lex_state = 2},
  [84] = {.lex_state = 14, .external_lex_state = 2},
  [85] = {.lex_state = 14, .external_lex_state = 2},
  [86] = {.lex_state = 14, .external_lex_state = 2},
  [87] = {.lex_state = 14, .external_lex_state = 2},
  [88] = {.lex_state = 14, .external_lex_state = 2},
  [89] = {.lex_state = 14, .external_lex_state = 2},
  [90] = {.lex_state = 14, .external_lex_state = 2},
  [91] = {.lex_state = 14, .external_lex_state = 2},
  [92] = {.lex_state = 14, .external_lex_state = 2},
  [93] = {.lex_state = 14, .external_lex_state = 2},
  [94] = {.lex_state = 14, .external_lex_state = 2},
  [95] = {.lex_state = 14, .external_lex_state = 2},
  [96] = {.lex_state = 14, .external_lex_state = 2},
  [97] = {.lex_state = 14, .external_lex_state = 2},
  [98] = {.lex_state = 14, .external_lex_state = 2},
  [99] = {.lex_state = 14, .external_lex_state = 2},
  [100] = {.lex_state = 14, .external_lex_state = 2},
  [101] = {.lex_state = 14, .external_lex_state = 2},
  [102] = {.lex_state = 14, .external_lex_state = 2},
  [103] = {.lex_state = 14, .external_lex_state = 2},
  [104] = {.lex_state = 14, .external_lex_state = 2},
  [105] = {.lex_state = 14, .external_lex_state = 2},
  [106] = {.lex_state = 14, .external_lex_state = 2},
  [107] = {.lex_state = 14, .external_lex_state = 2},
  [108] = {.lex_state = 14, .external_lex_state = 2},
  [109] = {.lex_state = 14, .external_lex_state = 2},
  [110] = {.lex_state = 14, .external_lex_state = 2},
  [111] = {.lex_state = 14, .external_lex_state = 2},
  [112] = {.lex_state = 14, .external_lex_state = 2},
  [113] = {.lex_state = 14, .external_lex_state = 2},
  [114] = {.lex_state = 14, .external_lex_state = 2},
  [115] = {.lex_state = 14, .external_lex_state = 2},
  [116] = {.lex_state = 14, .external_lex_state = 2},
  [117] = {.lex_state = 14, .external_lex_state = 2},
  [118] = {.lex_state = 14, .external_lex_state = 2},
  [119] = {.lex_state = 14, .external_lex_state = 2},
  [120] = {.lex_state = 14, .external_lex_state = 2},
  [121] = {.lex_state = 14, .external_lex_state = 2},
  [122] = {.lex_state = 14, .external_lex_state = 2},
  [123] = {.lex_state = 14, .external_lex_state = 2},
  [124] = {.lex_state = 14, .external_lex_state = 2},
  [125] = {.lex_state = 14, .external_lex_state = 2},
  [126] = {.lex_state = 14, .external_lex_state = 2},
  [127] = {.lex_state = 14, .external_lex_state = 2},
  [128] = {.lex_state = 14, .external_lex_state = 2},
  [129] = {.lex_state = 14, .external_lex_state = 2},
  [130] = {.lex_state = 14, .external_lex_state = 2},
  [131] = {.lex_state = 14, .external_lex_state = 2},
  [132] = {.lex_state = 14, .external_lex_state = 2},
  [133] = {.lex_state = 14, .external_lex_state = 2},
  [134] = {.lex_state = 14, .external_lex_state = 2},
  [135] = {.lex_state = 14, .external_lex_state = 2},
  [136] = {.lex_state = 14, .external_lex_state = 2},
  [137] = {.lex_state = 14, .external_lex_state = 2},
  [138] = {.lex_state = 14, .external_lex_state = 2},
  [139] = {.lex_state = 14, .external_lex_state = 2},
  [140] = {.lex_state = 14, .external_lex_state = 2},
  [141] = {.lex_state = 14, .external_lex_state = 2},
  [142] = {.lex_state = 14, .external_lex_state = 2},
  [143] = {.lex_state = 14, .external_lex_state = 2},
  [144] = {.lex_state = 14, .external_lex_state = 2},
  [145] = {.lex_state = 14, .external_lex_state = 2},
  [146] = {.lex_state = 14, .external_lex_state = 2},
  [147] = {.lex_state = 14, .external_lex_state = 2},
  [148] = {.lex_state = 14, .external_lex_state = 2},
  [149] = {.lex_state = 14, .external_lex_state = 2},
  [150] = {.lex_state = 14, .external_lex_state = 2},
  [151] = {.lex_state = 14, .external_lex_state = 2},
  [152] = {.lex_state = 1, .external_lex_state = 2},
  [153] = {.lex_state = 1, .external_lex_state = 2},
  [154] = {.lex_state = 1, .external_lex_state = 2},
  [155] = {.lex_state = 1, .external_lex_state = 2},
  [156] = {.lex_state = 1, .external_lex_state = 2},
  [157] = {.lex_state = 1, .external_lex_state = 2},
  [158] = {.lex_state = 14, .external_lex_state = 2},
  [159] = {.lex_state = 7, .external_lex_state = 3},
  [160] = {.lex_state = 2, .external_lex_state = 2},
  [161] = {.lex_state = 7, .external_lex_state = 4},
  [162] = {.lex_state = 7, .external_lex_state = 3},
  [163] = {.lex_state = 7, .external_lex_state = 3},
  [164] = {.lex_state = 7, .external_lex_state = 3},
  [165] = {.lex_state = 15, .external_lex_state = 2},
  [166] = {.lex_state = 15, .external_lex_state = 3},
  [167] = {.lex_state = 15, .external_lex_state = 3},
  [168] = {.lex_state = 15, .external_lex_state = 2},
  [169] = {.lex_state = 15, .external_lex_state = 2},
  [170] = {.lex_state = 15, .external_lex_state = 2},
  [171] = {.lex_state = 15, .external_lex_state = 3},
  [172] = {.lex_state = 15, .external_lex_state = 3},
  [173] = {.lex_state = 15, .external_lex_state = 2},
  [174] = {.lex_state = 15, .external_lex_state = 3},
  [175] = {.lex_state = 15, .external_lex_state = 3},
  [176] = {.lex_state = 15, .external_lex_state = 3},
  [177] = {.lex_state = 15, .external_lex_state = 3},
  [178] = {.lex_state = 15, .external_lex_state = 3},
  [179] = {.lex_state = 15, .external_lex_state = 3},
  [180] = {.lex_state = 15, .external_lex_state = 3},
  [181] = {.lex_state = 15, .external_lex_state = 3},
  [182] = {.lex_state = 15, .external_lex_state = 3},
  [183] = {.lex_state = 15, .external_lex_state = 3},
  [184] = {.lex_state = 15, .external_lex_state = 3},
  [185] = {.lex_state = 15, .external_lex_state = 3},
  [186] = {.lex_state = 15, .external_lex_state = 3},
  [187] = {.lex_state = 15, .external_lex_state = 3},
  [188] = {.lex_state = 15, .external_lex_state = 3},
  [189] = {.lex_state = 14, .external_lex_state = 5},
  [190] = {.lex_state = 14, .external_lex_state = 5},
  [191] = {.lex_state = 14, .external_lex_state = 5},
  [192] = {.lex_state = 14, .external_lex_state = 5},
  [193] = {.lex_state = 14, .external_lex_state = 5},
  [194] = {.lex_state = 14, .external_lex_state = 5},
  [195] = {.lex_state = 14, .external_lex_state = 5},
  [196] = {.lex_state = 15, .external_lex_state = 3},
  [197] = {.lex_state = 15, .external_lex_state = 3},
  [198] = {.lex_state = 14, .external_lex_state = 5},
  [199] = {.lex_state = 15, .external_lex_state = 3},
  [200] = {.lex_state = 14, .external_lex_state = 5},
  [201] = {.lex_state = 15, .external_lex_state = 3},
  [202] = {.lex_state = 14, .external_lex_state = 5},
  [203] = {.lex_state = 14, .external_lex_state = 5},
  [204] = {.lex_state = 14, .external_lex_state = 5},
  [205] = {.lex_state = 14, .external_lex_state = 5},
  [206] = {.lex_state = 14, .external_lex_state = 5},
  [207] = {.lex_state = 3, .external_lex_state = 6},
  [208] = {.lex_state = 14, .external_lex_state = 5},
  [209] = {.lex_state = 3, .external_lex_state = 6},
  [210] = {.lex_state = 14, .external_lex_state = 5},
  [211] = {.lex_state = 14, .external_lex_state = 5},
  [212] = {.lex_state = 3, .external_lex_state = 6},
  [213] = {.lex_state = 14, .external_lex_state = 5},
  [214] = {.lex_state = 14, .external_lex_state = 5},
  [215] = {.lex_state = 15, .external_lex_state = 3},
  [216] = {.lex_state = 15, .external_lex_state = 3},
  [217] = {.lex_state = 3, .external_lex_state = 6},
  [218] = {.lex_state = 15, .external_lex_state = 3},
  [219] = {.lex_state = 15, .external_lex_state = 3},
  [220] = {.lex_state = 15, .external_lex_state = 3},
  [221] = {.lex_state = 3, .external_lex_state = 6},
  [222] = {.lex_state = 15, .external_lex_state = 3},
  [223] = {.lex_state = 15, .external_lex_state = 3},
  [224] = {.lex_state = 15, .external_lex_state = 3},
  [225] = {.lex_state = 15, .external_lex_state = 3},
  [226] = {.lex_state = 15, .external_lex_state = 3},
  [227] = {.lex_state = 15, .external_lex_state = 3},
  [228] = {.lex_state = 15, .external_lex_state = 3},
  [229] = {.lex_state = 15, .external_lex_state = 3},
  [230] = {.lex_state = 15, .external_lex_state = 3},
  [231] = {.lex_state = 15, .external_lex_state = 3},
  [232] = {.lex_state = 15, .external_lex_state = 3},
  [233] = {.lex_state = 15, .external_lex_state = 3},
  [234] = {.lex_state = 15, .external_lex_state = 3},
  [235] = {.lex_state = 15, .external_lex_state = 3},
  [236] = {.lex_state = 15, .external_lex_state = 3},
  [237] = {.lex_state = 15, .external_lex_state = 3},
  [238] = {.lex_state = 15, .external_lex_state = 3},
  [239] = {.lex_state = 15, .external_lex_state = 3},
  [240] = {.lex_state = 15, .external_lex_state = 3},
  [241] = {.lex_state = 15, .external_lex_state = 3},
  [242] = {.lex_state = 15, .external_lex_state = 3},
  [243] = {.lex_state = 15, .external_lex_state = 3},
  [244] = {.lex_state = 15, .external_lex_state = 3},
  [245] = {.lex_state = 15, .external_lex_state = 3},
  [246] = {.lex_state = 15, .external_lex_state = 3},
  [247] = {.lex_state = 15, .external_lex_state = 3},
  [248] = {.lex_state = 15, .external_lex_state = 3},
  [249] = {.lex_state = 15, .external_lex_state = 3},
  [250] = {.lex_state = 15, .external_lex_state = 3},
  [251] = {.lex_state = 15, .external_lex_state = 3},
  [252] = {.lex_state = 15, .external_lex_state = 3},
  [253] = {.lex_state = 15, .external_lex_state = 3},
  [254] = {.lex_state = 15, .external_lex_state = 3},
  [255] = {.lex_state = 15, .external_lex_state = 3},
  [256] = {.lex_state = 15, .external_lex_state = 3},
  [257] = {.lex_state = 15, .external_lex_state = 3},
  [258] = {.lex_state = 15, .external_lex_state = 3},
  [259] = {.lex_state = 15, .external_lex_state = 2},
  [260] = {.lex_state = 15, .external_lex_state = 3},
  [261] = {.lex_state = 3, .external_lex_state = 6},
  [262] = {.lex_state = 15, .external_lex_state = 3},
  [263] = {.lex_state = 0, .external_lex_state = 5},
  [264] = {.lex_state = 15, .external_lex_state = 3},
  [265] = {.lex_state = 15, .external_lex_state = 3},
  [266] = {.lex_state = 15, .external_lex_state = 3},
  [267] = {.lex_state = 15, .external_lex_state = 3},
  [268] = {.lex_state = 14, .external_lex_state = 5},
  [269] = {.lex_state = 15, .external_lex_state = 3},
  [270] = {.lex_state = 15, .external_lex_state = 3},
  [271] = {.lex_state = 15, .external_lex_state = 3},
  [272] = {.lex_state = 15, .external_lex_state = 3},
  [273] = {.lex_state = 15, .external_lex_state = 3},
  [274] = {.lex_state = 15, .external_lex_state = 3},
  [275] = {.lex_state = 15, .external_lex_state = 3},
  [276] = {.lex_state = 15, .external_lex_state = 3},
  [277] = {.lex_state = 0, .external_lex_state = 5},
  [278] = {.lex_state = 0, .external_lex_state = 5},
  [279] = {.lex_state = 0, .external_lex_state = 5},
  [280] = {.lex_state = 14, .external_lex_state = 5},
  [281] = {.lex_state = 15, .external_lex_state = 3},
  [282] = {.lex_state = 15, .external_lex_state = 3},
  [283] = {.lex_state = 15, .external_lex_state = 3},
  [284] = {.lex_state = 15, .external_lex_state = 3},
  [285] = {.lex_state = 15, .external_lex_state = 3},
  [286] = {.lex_state = 15, .external_lex_state = 3},
  [287] = {.lex_state = 15, .external_lex_state = 3},
  [288] = {.lex_state = 15, .external_lex_state = 3},
  [289] = {.lex_state = 15, .external_lex_state = 3},
  [290] = {.lex_state = 15, .external_lex_state = 3},
  [291] = {.lex_state = 15, .external_lex_state = 3},
  [292] = {.lex_state = 15, .external_lex_state = 3},
  [293] = {.lex_state = 15, .external_lex_state = 3},
  [294] = {.lex_state = 15, .external_lex_state = 3},
  [295] = {.lex_state = 15, .external_lex_state = 3},
  [296] = {.lex_state = 15, .external_lex_state = 3},
  [297] = {.lex_state = 15, .external_lex_state = 3},
  [298] = {.lex_state = 15, .external_lex_state = 3},
  [299] = {.lex_state = 15, .external_lex_state = 3},
  [300] = {.lex_state = 15, .external_lex_state = 3},
  [301] = {.lex_state = 15, .external_lex_state = 3},
  [302] = {.lex_state = 15, .external_lex_state = 3},
  [303] = {.lex_state = 15, .external_lex_state = 2},
  [304] = {.lex_state = 15, .external_lex_state = 3},
  [305] = {.lex_state = 15, .external_lex_state = 3},
  [306] = {.lex_state = 15, .external_lex_state = 3},
  [307] = {.lex_state = 15, .external_lex_state = 3},
  [308] = {.lex_state = 15, .external_lex_state = 3},
  [309] = {.lex_state = 15, .external_lex_state = 3},
  [310] = {.lex_state = 15, .external_lex_state = 3},
  [311] = {.lex_state = 15, .external_lex_state = 3},
  [312] = {.lex_state = 15, .external_lex_state = 3},
  [313] = {.lex_state = 15, .external_lex_state = 3},
  [314] = {.lex_state = 15, .external_lex_state = 2},
  [315] = {.lex_state = 15, .external_lex_state = 3},
  [316] = {.lex_state = 15, .external_lex_state = 3},
  [317] = {.lex_state = 15, .external_lex_state = 3},
  [318] = {.lex_state = 15, .external_lex_state = 2},
  [319] = {.lex_state = 15, .external_lex_state = 3},
  [320] = {.lex_state = 15, .external_lex_state = 3},
  [321] = {.lex_state = 15, .external_lex_state = 3},
  [322] = {.lex_state = 15, .external_lex_state = 2},
  [323] = {.lex_state = 15, .external_lex_state = 3},
  [324] = {.lex_state = 15, .external_lex_state = 2},
  [325] = {.lex_state = 15, .external_lex_state = 3},
  [326] = {.lex_state = 15, .external_lex_state = 3},
  [327] = {.lex_state = 15, .external_lex_state = 3},
  [328] = {.lex_state = 15, .external_lex_state = 3},
  [329] = {.lex_state = 15, .external_lex_state = 3},
  [330] = {.lex_state = 15, .external_lex_state = 3},
  [331] = {.lex_state = 15, .external_lex_state = 3},
  [332] = {.lex_state = 15, .external_lex_state = 3},
  [333] = {.lex_state = 15, .external_lex_state = 3},
  [334] = {.lex_state = 14, .external_lex_state = 5},
  [335] = {.lex_state = 15, .external_lex_state = 3},
  [336] = {.lex_state = 15, .external_lex_state = 3},
  [337] = {.lex_state = 15, .external_lex_state = 3},
  [338] = {.lex_state = 15, .external_lex_state = 3},
  [339] = {.lex_state = 15, .external_lex_state = 3},
  [340] = {.lex_state = 15, .external_lex_state = 3},
  [341] = {.lex_state = 15, .external_lex_state = 3},
  [342] = {.lex_state = 15, .external_lex_state = 3},
  [343] = {.lex_state = 15, .external_lex_state = 3},
  [344] = {.lex_state = 15, .external_lex_state = 3},
  [345] = {.lex_state = 15, .external_lex_state = 3},
  [346] = {.lex_state = 0, .external_lex_state = 5},
  [347] = {.lex_state = 3, .external_lex_state = 6},
  [348] = {.lex_state = 0, .external_lex_state = 5},
  [349] = {.lex_state = 14, .external_lex_state = 5},
  [350] = {.lex_state = 14, .external_lex_state = 5},
  [351] = {.lex_state = 3, .external_lex_state = 6},
  [352] = {.lex_state = 3, .external_lex_state = 6},
  [353] = {.lex_state = 14, .external_lex_state = 5},
  [354] = {.lex_state = 3, .external_lex_state = 6},
  [355] = {.lex_state = 14, .external_lex_state = 5},
  [356] = {.lex_state = 0, .external_lex_state = 5},
  [357] = {.lex_state = 0, .external_lex_state = 5},
  [358] = {.lex_state = 0, .external_lex_state = 5},
  [359] = {.lex_state = 0, .external_lex_state = 5},
  [360] = {.lex_state = 3, .external_lex_state = 6},
  [361] = {.lex_state = 3, .external_lex_state = 6},
  [362] = {.lex_state = 3, .external_lex_state = 6},
  [363] = {.lex_state = 3, .external_lex_state = 6},
  [364] = {.lex_state = 14, .external_lex_state = 5},
  [365] = {.lex_state = 3, .external_lex_state = 6},
  [366] = {.lex_state = 0, .external_lex_state = 5},
  [367] = {.lex_state = 3, .external_lex_state = 6},
  [368] = {.lex_state = 3, .external_lex_state = 6},
  [369] = {.lex_state = 3, .external_lex_state = 6},
  [370] = {.lex_state = 15, .external_lex_state = 2},
  [371] = {.lex_state = 15, .external_lex_state = 2},
  [372] = {.lex_state = 0, .external_lex_state = 5},
  [373] = {.lex_state = 15, .external_lex_state = 2},
  [374] = {.lex_state = 0, .external_lex_state = 5},
  [375] = {.lex_state = 0, .external_lex_state = 5},
  [376] = {.lex_state = 14, .external_lex_state = 5},
  [377] = {.lex_state = 3, .external_lex_state = 6},
  [378] = {.lex_state = 15, .external_lex_state = 2},
  [379] = {.lex_state = 14, .external_lex_state = 5},
  [380] = {.lex_state = 3, .external_lex_state = 6},
  [381] = {.lex_state = 3, .external_lex_state = 6},
  [382] = {.lex_state = 14, .external_lex_state = 5},
  [383] = {.lex_state = 3, .external_lex_state = 6},
  [384] = {.lex_state = 3, .external_lex_state = 6},
  [385] = {.lex_state = 3, .external_lex_state = 6},
  [386] = {.lex_state = 14, .external_lex_state = 5},
  [387] = {.lex_state = 0, .external_lex_state = 5},
  [388] = {.lex_state = 14, .external_lex_state = 5},
  [389] = {.lex_state = 3, .external_lex_state = 6},
  [390] = {.lex_state = 0, .external_lex_state = 5},
  [391] = {.lex_state = 0, .external_lex_state = 5},
  [392] = {.lex_state = 14, .external_lex_state = 5},
  [393] = {.lex_state = 0, .external_lex_state = 5},
  [394] = {.lex_state = 14, .external_lex_state = 5},
  [395] = {.lex_state = 14, .external_lex_state = 5},
  [396] = {.lex_state = 14, .external_lex_state = 5},
  [397] = {.lex_state = 14, .external_lex_state = 5},
  [398] = {.lex_state = 0, .external_lex_state = 5},
  [399] = {.lex_state = 14, .external_lex_state = 5},
  [400] = {.lex_state = 14, .external_lex_state = 5},
  [401] = {.lex_state = 14, .external_lex_state = 5},
  [402] = {.lex_state = 14, .external_lex_state = 5},
  [403] = {.lex_state = 0, .external_lex_state = 5},
  [404] = {.lex_state = 0, .external_lex_state = 5},
  [405] = {.lex_state = 0, .external_lex_state = 5},
  [406] = {.lex_state = 14, .external_lex_state = 5},
  [407] = {.lex_state = 0, .external_lex_state = 5},
  [408] = {.lex_state = 14, .external_lex_state = 5},
  [409] = {.lex_state = 14, .external_lex_state = 5},
  [410] = {.lex_state = 0, .external_lex_state = 5},
  [411] = {.lex_state = 14, .external_lex_state = 5},
  [412] = {.lex_state = 14, .external_lex_state = 5},
  [413] = {.lex_state = 14, .external_lex_state = 5},
  [414] = {.lex_state = 0, .external_lex_state = 5},
  [415] = {.lex_state = 14, .external_lex_state = 5},
  [416] = {.lex_state = 14, .external_lex_state = 5},
  [417] = {.lex_state = 14, .external_lex_state = 5},
  [418] = {.lex_state = 3, .external_lex_state = 6},
  [419] = {.lex_state = 14, .external_lex_state = 5},
  [420] = {.lex_state = 14, .external_lex_state = 5},
  [421] = {.lex_state = 14, .external_lex_state = 5},
  [422] = {.lex_state = 14, .external_lex_state = 5},
  [423] = {.lex_state = 14, .external_lex_state = 5},
  [424] = {.lex_state = 14, .external_lex_state = 5},
  [425] = {.lex_state = 14, .external_lex_state = 5},
  [426] = {.lex_state = 14, .external_lex_state = 5},
  [427] = {.lex_state = 14, .external_lex_state = 5},
  [428] = {.lex_state = 14, .external_lex_state = 5},
  [429] = {.lex_state = 14, .external_lex_state = 5},
  [430] = {.lex_state = 14, .external_lex_state = 5},
  [431] = {.lex_state = 14, .external_lex_state = 5},
  [432] = {.lex_state = 0, .external_lex_state = 5},
  [433] = {.lex_state = 0, .external_lex_state = 5},
  [434] = {.lex_state = 14, .external_lex_state = 5},
  [435] = {.lex_state = 0, .external_lex_state = 5},
  [436] = {.lex_state = 14, .external_lex_state = 5},
  [437] = {.lex_state = 14, .external_lex_state = 5},
  [438] = {.lex_state = 0, .external_lex_state = 5},
  [439] = {.lex_state = 0, .external_lex_state = 5},
  [440] = {.lex_state = 14, .external_lex_state = 5},
  [441] = {.lex_state = 14, .external_lex_state = 5},
  [442] = {.lex_state = 14, .external_lex_state = 5},
  [443] = {.lex_state = 14, .external_lex_state = 5},
  [444] = {.lex_state = 0, .external_lex_state = 5},
  [445] = {.lex_state = 14, .external_lex_state = 5},
  [446] = {.lex_state = 0, .external_lex_state = 5},
  [447] = {.lex_state = 14, .external_lex_state = 5},
  [448] = {.lex_state = 0, .external_lex_state = 5},
  [449] = {.lex_state = 0, .external_lex_state = 5},
  [450] = {.lex_state = 3, .external_lex_state = 6},
  [451] = {.lex_state = 3, .external_lex_state = 6},
  [452] = {.lex_state = 3, .external_lex_state = 6},
  [453] = {.lex_state = 3, .external_lex_state = 6},
  [454] = {.lex_state = 3, .external_lex_state = 6},
  [455] = {.lex_state = 3, .external_lex_state = 6},
  [456] = {.lex_state = 0, .external_lex_state = 5},
  [457] = {.lex_state = 3, .external_lex_state = 6},
  [458] = {.lex_state = 3, .external_lex_state = 6},
  [459] = {.lex_state = 3, .external_lex_state = 6},
  [460] = {.lex_state = 0, .external_lex_state = 5},
  [461] = {.lex_state = 3, .external_lex_state = 6},
  [462] = {.lex_state = 0, .external_lex_state = 5},
  [463] = {.lex_state = 0, .external_lex_state = 5},
  [464] = {.lex_state = 3, .external_lex_state = 6},
  [465] = {.lex_state = 3, .external_lex_state = 6},
  [466] = {.lex_state = 3, .external_lex_state = 6},
  [467] = {.lex_state = 3, .external_lex_state = 6},
  [468] = {.lex_state = 3, .external_lex_state = 6},
  [469] = {.lex_state = 0, .external_lex_state = 5},
  [470] = {.lex_state = 3, .external_lex_state = 6},
  [471] = {.lex_state = 3, .external_lex_state = 6},
  [472] = {.lex_state = 3, .external_lex_state = 6},
  [473] = {.lex_state = 3, .external_lex_state = 6},
  [474] = {.lex_state = 3, .external_lex_state = 6},
  [475] = {.lex_state = 14, .external_lex_state = 5},
  [476] = {.lex_state = 0, .external_lex_state = 5},
  [477] = {.lex_state = 0, .external_lex_state = 5},
  [478] = {.lex_state = 3, .external_lex_state = 6},
  [479] = {.lex_state = 3, .external_lex_state = 6},
  [480] = {.lex_state = 3, .external_lex_state = 6},
  [481] = {.lex_state = 3, .external_lex_state = 6},
  [482] = {.lex_state = 3, .external_lex_state = 6},
  [483] = {.lex_state = 3, .external_lex_state = 6},
  [484] = {.lex_state = 3, .external_lex_state = 6},
  [485] = {.lex_state = 3, .external_lex_state = 6},
  [486] = {.lex_state = 3, .external_lex_state = 6},
  [487] = {.lex_state = 3, .external_lex_state = 6},
  [488] = {.lex_state = 3, .external_lex_state = 6},
  [489] = {.lex_state = 3, .external_lex_state = 6},
  [490] = {.lex_state = 3, .external_lex_state = 6},
  [491] = {.lex_state = 0, .external_lex_state = 5},
  [492] = {.lex_state = 3, .external_lex_state = 6},
  [493] = {.lex_state = 14, .external_lex_state = 5},
  [494] = {.lex_state = 3, .external_lex_state = 6},
  [495] = {.lex_state = 3, .external_lex_state = 6},
  [496] = {.lex_state = 3, .external_lex_state = 6},
  [497] = {.lex_state = 3, .external_lex_state = 6},
  [498] = {.lex_state = 3, .external_lex_state = 6},
  [499] = {.lex_state = 3, .external_lex_state = 6},
  [500] = {.lex_state = 3, .external_lex_state = 6},
  [501] = {.lex_state = 3, .external_lex_state = 6},
  [502] = {.lex_state = 3, .external_lex_state = 6},
  [503] = {.lex_state = 3, .external_lex_state = 6},
  [504] = {.lex_state = 3, .external_lex_state = 6},
  [505] = {.lex_state = 14, .external_lex_state = 5},
  [506] = {.lex_state = 14, .external_lex_state = 5},
  [507] = {.lex_state = 14, .external_lex_state = 5},
  [508] = {.lex_state = 0, .external_lex_state = 5},
  [509] = {.lex_state = 14, .external_lex_state = 5},
  [510] = {.lex_state = 0, .external_lex_state = 5},
  [511] = {.lex_state = 0, .external_lex_state = 5},
  [512] = {.lex_state = 0, .external_lex_state = 5},
  [513] = {.lex_state = 0, .external_lex_state = 5},
  [514] = {.lex_state = 0, .external_lex_state = 5},
  [515] = {.lex_state = 0, .external_lex_state = 5},
  [516] = {.lex_state = 0, .external_lex_state = 5},
  [517] = {.lex_state = 0, .external_lex_state = 5},
  [518] = {.lex_state = 0, .external_lex_state = 5},
  [519] = {.lex_state = 0, .external_lex_state = 5},
  [520] = {.lex_state = 0, .external_lex_state = 5},
  [521] = {.lex_state = 0, .external_lex_state = 5},
  [522] = {.lex_state = 0, .external_lex_state = 5},
  [523] = {.lex_state = 0, .external_lex_state = 5},
  [524] = {.lex_state = 0, .external_lex_state = 5},
  [525] = {.lex_state = 0, .external_lex_state = 5},
  [526] = {.lex_state = 0, .external_lex_state = 5},
  [527] = {.lex_state = 0, .external_lex_state = 5},
  [528] = {.lex_state = 0, .external_lex_state = 5},
  [529] = {.lex_state = 0, .external_lex_state = 5},
  [530] = {.lex_state = 0, .external_lex_state = 5},
  [531] = {.lex_state = 0, .external_lex_state = 5},
  [532] = {.lex_state = 0, .external_lex_state = 5},
  [533] = {.lex_state = 0, .external_lex_state = 5},
  [534] = {.lex_state = 0, .external_lex_state = 5},
  [535] = {.lex_state = 0, .external_lex_state = 5},
  [536] = {.lex_state = 3, .external_lex_state = 6},
  [537] = {.lex_state = 0, .external_lex_state = 5},
  [538] = {.lex_state = 0, .external_lex_state = 5},
  [539] = {.lex_state = 0, .external_lex_state = 5},
  [540] = {.lex_state = 0, .external_lex_state = 5},
  [541] = {.lex_state = 0, .external_lex_state = 5},
  [542] = {.lex_state = 0, .external_lex_state = 5},
  [543] = {.lex_state = 0, .external_lex_state = 5},
  [544] = {.lex_state = 0, .external_lex_state = 5},
  [545] = {.lex_state = 0, .external_lex_state = 5},
  [546] = {.lex_state = 0, .external_lex_state = 5},
  [547] = {.lex_state = 0, .external_lex_state = 5},
  [548] = {.lex_state = 0, .external_lex_state = 5},
  [549] = {.lex_state = 0, .external_lex_state = 5},
  [550] = {.lex_state = 0, .external_lex_state = 5},
  [551] = {.lex_state = 0, .external_lex_state = 5},
  [552] = {.lex_state = 0, .external_lex_state = 5},
  [553] = {.lex_state = 0, .external_lex_state = 5},
  [554] = {.lex_state = 0, .external_lex_state = 5},
  [555] = {.lex_state = 0, .external_lex_state = 5},
  [556] = {.lex_state = 3, .external_lex_state = 6},
  [557] = {.lex_state = 3, .external_lex_state = 6},
  [558] = {.lex_state = 0, .external_lex_state = 5},
  [559] = {.lex_state = 3, .external_lex_state = 6},
  [560] = {.lex_state = 0, .external_lex_state = 5},
  [561] = {.lex_state = 3, .external_lex_state = 6},
  [562] = {.lex_state = 0, .external_lex_state = 5},
  [563] = {.lex_state = 0, .external_lex_state = 5},
  [564] = {.lex_state = 0, .external_lex_state = 5},
  [565] = {.lex_state = 0, .external_lex_state = 5},
  [566] = {.lex_state = 0, .external_lex_state = 5},
  [567] = {.lex_state = 0, .external_lex_state = 5},
  [568] = {.lex_state = 0, .external_lex_state = 5},
  [569] = {.lex_state = 0, .external_lex_state = 5},
  [570] = {.lex_state = 0, .external_lex_state = 5},
  [571] = {.lex_state = 0, .external_lex_state = 5},
  [572] = {.lex_state = 0, .external_lex_state = 5},
  [573] = {.lex_state = 0, .external_lex_state = 5},
  [574] = {.lex_state = 0, .external_lex_state = 5},
  [575] = {.lex_state = 0, .external_lex_state = 5},
  [576] = {.lex_state = 0, .external_lex_state = 5},
  [577] = {.lex_state = 0, .external_lex_state = 5},
  [578] = {.lex_state = 0, .external_lex_state = 5},
  [579] = {.lex_state = 0, .external_lex_state = 5},
  [580] = {.lex_state = 0, .external_lex_state = 5},
  [581] = {.lex_state = 0, .external_lex_state = 5},
  [582] = {.lex_state = 0, .external_lex_state = 5},
  [583] = {.lex_state = 0, .external_lex_state = 5},
  [584] = {.lex_state = 0, .external_lex_state = 5},
  [585] = {.lex_state = 0, .external_lex_state = 5},
  [586] = {.lex_state = 0, .external_lex_state = 5},
  [587] = {.lex_state = 0, .external_lex_state = 5},
  [588] = {.lex_state = 0, .external_lex_state = 5},
  [589] = {.lex_state = 0, .external_lex_state = 5},
  [590] = {.lex_state = 0, .external_lex_state = 5},
  [591] = {.lex_state = 0, .external_lex_state = 5},
  [592] = {.lex_state = 1, .external_lex_state = 5},
  [593] = {.lex_state = 1, .external_lex_state = 5},
  [594] = {.lex_state = 14, .external_lex_state = 5},
  [595] = {.lex_state = 15, .external_lex_state = 5},
  [596] = {.lex_state = 1, .external_lex_state = 5},
  [597] = {.lex_state = 1, .external_lex_state = 5},
  [598] = {.lex_state = 1, .external_lex_state = 5},
  [599] = {.lex_state = 1, .external_lex_state = 5},
  [600] = {.lex_state = 2, .external_lex_state = 5},
  [601] = {.lex_state = 6, .external_lex_state = 6},
  [602] = {.lex_state = 6, .external_lex_state = 6},
  [603] = {.lex_state = 5, .external_lex_state = 5},
  [604] = {.lex_state = 6, .external_lex_state = 6},
  [605] = {.lex_state = 6, .external_lex_state = 6},
  [606] = {.lex_state = 6, .external_lex_state = 6},
  [607] = {.lex_state = 0, .external_lex_state = 5},
  [608] = {.lex_state = 6, .external_lex_state = 6},
  [609] = {.lex_state = 5, .external_lex_state = 5},
  [610] = {.lex_state = 3, .external_lex_state = 6},
  [611] = {.lex_state = 0, .external_lex_state = 5},
  [612] = {.lex_state = 14, .external_lex_state = 5},
  [613] = {.lex_state = 14, .external_lex_state = 5},
  [614] = {.lex_state = 0, .external_lex_state = 5},
  [615] = {.lex_state = 3, .external_lex_state = 6},
  [616] = {.lex_state = 0, .external_lex_state = 5},
  [617] = {.lex_state = 5, .external_lex_state = 5},
  [618] = {.lex_state = 15, .external_lex_state = 5},
  [619] = {.lex_state = 15, .external_lex_state = 5},
  [620] = {.lex_state = 14, .external_lex_state = 5},
  [621] = {.lex_state = 14, .external_lex_state = 5},
  [622] = {.lex_state = 5, .external_lex_state = 5},
  [623] = {.lex_state = 5, .external_lex_state = 5},
  [624] = {.lex_state = 15, .external_lex_state = 5},
  [625] = {.lex_state = 14, .external_lex_state = 5},
  [626] = {.lex_state = 5, .external_lex_state = 5},
  [627] = {.lex_state = 3, .external_lex_state = 6},
  [628] = {.lex_state = 14, .external_lex_state = 5},
  [629] = {.lex_state = 0, .external_lex_state = 5},
  [630] = {.lex_state = 14, .external_lex_state = 5},
  [631] = {.lex_state = 15, .external_lex_state = 5},
  [632] = {.lex_state = 15, .external_lex_state = 5},
  [633] = {.lex_state = 0, .external_lex_state = 5},
  [634] = {.lex_state = 0, .external_lex_state = 5},
  [635] = {.lex_state = 14, .external_lex_state = 5},
  [636] = {.lex_state = 0, .external_lex_state = 5},
  [637] = {.lex_state = 0, .external_lex_state = 5},
  [638] = {.lex_state = 15, .external_lex_state = 5},
  [639] = {.lex_state = 15, .external_lex_state = 5},
  [640] = {.lex_state = 15, .external_lex_state = 5},
  [641] = {.lex_state = 2, .external_lex_state = 5},
  [642] = {.lex_state = 15, .external_lex_state = 5},
  [643] = {.lex_state = 15, .external_lex_state = 5},
  [644] = {.lex_state = 15, .external_lex_state = 5},
  [645] = {.lex_state = 15, .external_lex_state = 3},
  [646] = {.lex_state = 0, .external_lex_state = 7},
  [647] = {.lex_state = 15, .external_lex_state = 5},
  [648] = {.lex_state = 0, .external_lex_state = 5},
  [649] = {.lex_state = 15, .external_lex_state = 5},
  [650] = {.lex_state = 0, .external_lex_state = 7},
  [651] = {.lex_state = 0, .external_lex_state = 7},
  [652] = {.lex_state = 2, .external_lex_state = 5},
  [653] = {.lex_state = 15, .external_lex_state = 5},
  [654] = {.lex_state = 0, .external_lex_state = 5},
  [655] = {.lex_state = 15, .external_lex_state = 5},
  [656] = {.lex_state = 15, .external_lex_state = 5},
  [657] = {.lex_state = 15, .external_lex_state = 5},
  [658] = {.lex_state = 15, .external_lex_state = 5},
  [659] = {.lex_state = 15, .external_lex_state = 5},
  [660] = {.lex_state = 15, .external_lex_state = 5},
  [661] = {.lex_state = 2, .external_lex_state = 5},
  [662] = {.lex_state = 14, .external_lex_state = 5},
  [663] = {.lex_state = 15, .external_lex_state = 5},
  [664] = {.lex_state = 15, .external_lex_state = 5},
  [665] = {.lex_state = 15, .external_lex_state = 5},
  [666] = {.lex_state = 15, .external_lex_state = 5},
  [667] = {.lex_state = 0, .external_lex_state = 7},
  [668] = {.lex_state = 0, .external_lex_state = 7},
  [669] = {.lex_state = 14, .external_lex_state = 5},
  [670] = {.lex_state = 14, .external_lex_state = 5},
  [671] = {.lex_state = 15, .external_lex_state = 5},
  [672] = {.lex_state = 15, .external_lex_state = 5},
  [673] = {.lex_state = 14, .external_lex_state = 5},
  [674] = {.lex_state = 0, .external_lex_state = 5},
  [675] = {.lex_state = 15, .external_lex_state = 5},
  [676] = {.lex_state = 0, .external_lex_state = 5},
  [677] = {.lex_state = 14, .external_lex_state = 5},
  [678] = {.lex_state = 14, .external_lex_state = 5},
  [679] = {.lex_state = 14, .external_lex_state = 5},
  [680] = {.lex_state = 0, .external_lex_state = 5},
  [681] = {.lex_state = 15, .external_lex_state = 5},
  [682] = {.lex_state = 0, .external_lex_state = 5},
  [683] = {.lex_state = 14, .external_lex_state = 5},
  [684] = {.lex_state = 0, .external_lex_state = 5},
  [685] = {.lex_state = 0, .external_lex_state = 5},
  [686] = {.lex_state = 14, .external_lex_state = 5},
  [687] = {.lex_state = 15, .external_lex_state = 5},
  [688] = {.lex_state = 0, .external_lex_state = 5},
  [689] = {.lex_state = 0, .external_lex_state = 5},
  [690] = {.lex_state = 14, .external_lex_state = 5},
  [691] = {.lex_state = 0, .external_lex_state = 5},
  [692] = {.lex_state = 14, .external_lex_state = 5},
  [693] = {.lex_state = 0, .external_lex_state = 5},
  [694] = {.lex_state = 14, .external_lex_state = 5},
  [695] = {.lex_state = 0, .external_lex_state = 5},
  [696] = {.lex_state = 14, .external_lex_state = 5},
  [697] = {.lex_state = 15, .external_lex_state = 5},
  [698] = {.lex_state = 14, .external_lex_state = 5},
  [699] = {.lex_state = 14, .external_lex_state = 5},
  [700] = {.lex_state = 14, .external_lex_state = 5},
  [701] = {.lex_state = 14, .external_lex_state = 5},
  [702] = {.lex_state = 14, .external_lex_state = 5},
  [703] = {.lex_state = 0, .external_lex_state = 5},
  [704] = {.lex_state = 14, .external_lex_state = 5},
  [705] = {.lex_state = 14, .external_lex_state = 5},
  [706] = {.lex_state = 14, .external_lex_state = 5},
  [707] = {.lex_state = 0, .external_lex_state = 7},
  [708] = {.lex_state = 0, .external_lex_state = 7},
  [709] = {.lex_state = 0, .external_lex_state = 7},
  [710] = {.lex_state = 15, .external_lex_state = 5},
  [711] = {.lex_state = 15, .external_lex_state = 5},
  [712] = {.lex_state = 0, .external_lex_state = 7},
  [713] = {.lex_state = 0, .external_lex_state = 7},
  [714] = {.lex_state = 0, .external_lex_state = 7},
  [715] = {.lex_state = 0, .external_lex_state = 7},
  [716] = {.lex_state = 0, .external_lex_state = 7},
  [717] = {.lex_state = 0, .external_lex_state = 7},
  [718] = {.lex_state = 14, .external_lex_state = 5},
  [719] = {.lex_state = 0, .external_lex_state = 7},
  [720] = {.lex_state = 0, .external_lex_state = 7},
  [721] = {.lex_state = 14, .external_lex_state = 5},
  [722] = {.lex_state = 14, .external_lex_state = 5},
  [723] = {.lex_state = 14, .external_lex_state = 5},
  [724] = {.lex_state = 15, .external_lex_state = 5},
  [725] = {.lex_state = 15, .external_lex_state = 5},
  [726] = {.lex_state = 15, .external_lex_state = 5},
  [727] = {.lex_state = 15, .external_lex_state = 5},
  [728] = {.lex_state = 15, .external_lex_state = 5},
  [729] = {.lex_state = 14, .external_lex_state = 5},
  [730] = {.lex_state = 14, .external_lex_state = 5},
  [731] = {.lex_state = 15, .external_lex_state = 5},
  [732] = {.lex_state = 15, .external_lex_state = 5},
  [733] = {.lex_state = 15, .external_lex_state = 5},
  [734] = {.lex_state = 15, .external_lex_state = 5},
  [735] = {.lex_state = 14, .external_lex_state = 5},
  [736] = {.lex_state = 14, .external_lex_state = 5},
  [737] = {.lex_state = 15, .external_lex_state = 5},
  [738] = {.lex_state = 14, .external_lex_state = 5},
  [739] = {.lex_state = 2, .external_lex_state = 5},
  [740] = {.lex_state = 15, .external_lex_state = 5},
  [741] = {.lex_state = 14, .external_lex_state = 5},
  [742] = {.lex_state = 15, .external_lex_state = 5},
  [743] = {.lex_state = 14, .external_lex_state = 5},
  [744] = {.lex_state = 14, .external_lex_state = 5},
  [745] = {.lex_state = 14, .external_lex_state = 5},
  [746] = {.lex_state = 14, .external_lex_state = 5},
  [747] = {.lex_state = 15, .external_lex_state = 5},
  [748] = {.lex_state = 15, .external_lex_state = 5},
  [749] = {.lex_state = 14, .external_lex_state = 5},
  [750] = {.lex_state = 0, .external_lex_state = 7},
  [751] = {.lex_state = 7, .external_lex_state = 6},
  [752] = {.lex_state = 0, .external_lex_state = 7},
  [753] = {.lex_state = 14, .external_lex_state = 8},
  [754] = {.lex_state = 0, .external_lex_state = 7},
  [755] = {.lex_state = 14, .external_lex_state = 5},
  [756] = {.lex_state = 14, .external_lex_state = 5},
  [757] = {.lex_state = 0, .external_lex_state = 7},
  [758] = {.lex_state = 14, .external_lex_state = 5},
  [759] = {.lex_state = 7, .external_lex_state = 6},
  [760] = {.lex_state = 7, .external_lex_state = 6},
  [761] = {.lex_state = 0, .external_lex_state = 7},
  [762] = {.lex_state = 14, .external_lex_state = 5},
  [763] = {.lex_state = 14, .external_lex_state = 5},
  [764] = {.lex_state = 0, .external_lex_state = 7},
  [765] = {.lex_state = 14, .external_lex_state = 5},
  [766] = {.lex_state = 14, .external_lex_state = 5},
  [767] = {.lex_state = 15, .external_lex_state = 5},
  [768] = {.lex_state = 0, .external_lex_state = 7},
  [769] = {.lex_state = 0, .external_lex_state = 7},
  [770] = {.lex_state = 15, .external_lex_state = 5},
  [771] = {.lex_state = 0, .external_lex_state = 7},
  [772] = {.lex_state = 0, .external_lex_state = 7},
  [773] = {.lex_state = 15, .external_lex_state = 5},
  [774] = {.lex_state = 0, .external_lex_state = 7},
  [775] = {.lex_state = 15, .external_lex_state = 5},
  [776] = {.lex_state = 15, .external_lex_state = 5},
  [777] = {.lex_state = 7, .external_lex_state = 6},
  [778] = {.lex_state = 0, .external_lex_state = 5},
  [779] = {.lex_state = 7, .external_lex_state = 6},
  [780] = {.lex_state = 14, .external_lex_state = 8},
  [781] = {.lex_state = 0, .external_lex_state = 7},
  [782] = {.lex_state = 15, .external_lex_state = 5},
  [783] = {.lex_state = 15, .external_lex_state = 5},
  [784] = {.lex_state = 15, .external_lex_state = 5},
  [785] = {.lex_state = 15, .external_lex_state = 5},
  [786] = {.lex_state = 0, .external_lex_state = 7},
  [787] = {.lex_state = 0, .external_lex_state = 7},
  [788] = {.lex_state = 14, .external_lex_state = 5},
  [789] = {.lex_state = 14, .external_lex_state = 5},
  [790] = {.lex_state = 14, .external_lex_state = 5},
  [791] = {.lex_state = 14, .external_lex_state = 5},
  [792] = {.lex_state = 0, .external_lex_state = 7},
  [793] = {.lex_state = 15, .external_lex_state = 5},
  [794] = {.lex_state = 15, .external_lex_state = 5},
  [795] = {.lex_state = 14, .external_lex_state = 5},
  [796] = {.lex_state = 0, .external_lex_state = 7},
  [797] = {.lex_state = 14, .external_lex_state = 5},
  [798] = {.lex_state = 14, .external_lex_state = 5},
  [799] = {.lex_state = 14, .external_lex_state = 8},
  [800] = {.lex_state = 0, .external_lex_state = 7},
  [801] = {.lex_state = 14, .external_lex_state = 5},
  [802] = {.lex_state = 14, .external_lex_state = 5},
  [803] = {.lex_state = 14, .external_lex_state = 5},
  [804] = {.lex_state = 14, .external_lex_state = 5},
  [805] = {.lex_state = 15, .external_lex_state = 5},
  [806] = {.lex_state = 0, .external_lex_state = 7},
  [807] = {.lex_state = 15, .external_lex_state = 5},
  [808] = {.lex_state = 15, .external_lex_state = 5},
  [809] = {.lex_state = 15, .external_lex_state = 5},
  [810] = {.lex_state = 0, .external_lex_state = 7},
  [811] = {.lex_state = 0, .external_lex_state = 7},
  [812] = {.lex_state = 14, .external_lex_state = 5},
  [813] = {.lex_state = 0, .external_lex_state = 7},
  [814] = {.lex_state = 0, .external_lex_state = 7},
  [815] = {.lex_state = 0, .external_lex_state = 7},
  [816] = {.lex_state = 15, .external_lex_state = 5},
  [817] = {.lex_state = 14, .external_lex_state = 5},
  [818] = {.lex_state = 15, .external_lex_state = 5},
  [819] = {.lex_state = 0, .external_lex_state = 7},
  [820] = {.lex_state = 14, .external_lex_state = 5},
  [821] = {.lex_state = 15, .external_lex_state = 5},
  [822] = {.lex_state = 15, .external_lex_state = 5},
  [823] = {.lex_state = 15, .external_lex_state = 5},
  [824] = {.lex_state = 0, .external_lex_state = 9},
  [825] = {.lex_state = 14, .external_lex_state = 5},
  [826] = {.lex_state = 14, .external_lex_state = 5},
  [827] = {.lex_state = 14, .external_lex_state = 5},
  [828] = {.lex_state = 14, .external_lex_state = 5},
  [829] = {.lex_state = 15, .external_lex_state = 5},
  [830] = {.lex_state = 14, .external_lex_state = 5},
  [831] = {.lex_state = 0, .external_lex_state = 10},
  [832] = {.lex_state = 14, .external_lex_state = 5},
  [833] = {.lex_state = 14, .external_lex_state = 5},
  [834] = {.lex_state = 0, .external_lex_state = 10},
  [835] = {.lex_state = 14, .external_lex_state = 5},
  [836] = {.lex_state = 14, .external_lex_state = 5},
  [837] = {.lex_state = 15, .external_lex_state = 5},
  [838] = {.lex_state = 14, .external_lex_state = 5},
  [839] = {.lex_state = 14, .external_lex_state = 5},
  [840] = {.lex_state = 14, .external_lex_state = 5},
  [841] = {.lex_state = 0, .external_lex_state = 10},
  [842] = {.lex_state = 0, .external_lex_state = 9},
  [843] = {.lex_state = 14, .external_lex_state = 5},
  [844] = {.lex_state = 14, .external_lex_state = 5},
  [845] = {.lex_state = 0, .external_lex_state = 10},
  [846] = {.lex_state = 0, .external_lex_state = 9},
  [847] = {.lex_state = 14, .external_lex_state = 5},
  [848] = {.lex_state = 14, .external_lex_state = 5},
  [849] = {.lex_state = 14, .external_lex_state = 5},
  [850] = {.lex_state = 14, .external_lex_state = 5},
  [851] = {.lex_state = 14, .external_lex_state = 5},
  [852] = {.lex_state = 14, .external_lex_state = 5},
  [853] = {.lex_state = 0, .external_lex_state = 10},
  [854] = {.lex_state = 0, .external_lex_state = 9},
  [855] = {.lex_state = 15, .external_lex_state = 5},
  [856] = {.lex_state = 14, .external_lex_state = 5},
  [857] = {.lex_state = 14, .external_lex_state = 5},
  [858] = {.lex_state = 15, .external_lex_state = 5},
  [859] = {.lex_state = 14, .external_lex_state = 5},
  [860] = {.lex_state = 7, .external_lex_state = 6},
  [861] = {.lex_state = 14, .external_lex_state = 5},
  [862] = {.lex_state = 0, .external_lex_state = 10},
  [863] = {.lex_state = 0, .external_lex_state = 10},
  [864] = {.lex_state = 14, .external_lex_state = 5},
  [865] = {.lex_state = 0, .external_lex_state = 9},
  [866] = {.lex_state = 7, .external_lex_state = 5},
  [867] = {.lex_state = 14, .external_lex_state = 5},
  [868] = {.lex_state = 0, .external_lex_state = 10},
  [869] = {.lex_state = 0, .external_lex_state = 9},
  [870] = {.lex_state = 14, .external_lex_state = 5},
  [871] = {.lex_state = 0, .external_lex_state = 9},
  [872] = {.lex_state = 15, .external_lex_state = 5},
  [873] = {.lex_state = 15, .external_lex_state = 5},
  [874] = {.lex_state = 14, .external_lex_state = 5},
  [875] = {.lex_state = 14, .external_lex_state = 5},
  [876] = {.lex_state = 0, .external_lex_state = 5},
  [877] = {.lex_state = 0, .external_lex_state = 10},
  [878] = {.lex_state = 15, .external_lex_state = 5},
  [879] = {.lex_state = 14, .external_lex_state = 5},
  [880] = {.lex_state = 0, .external_lex_state = 9},
  [881] = {.lex_state = 14, .external_lex_state = 5},
  [882] = {.lex_state = 15, .external_lex_state = 5},
  [883] = {.lex_state = 15, .external_lex_state = 5},
  [884] = {.lex_state = 15, .external_lex_state = 5},
  [885] = {.lex_state = 15, .external_lex_state = 5},
  [886] = {.lex_state = 14, .external_lex_state = 5},
  [887] = {.lex_state = 14, .external_lex_state = 5},
  [888] = {.lex_state = 14, .external_lex_state = 5},
  [889] = {.lex_state = 14, .external_lex_state = 5},
  [890] = {.lex_state = 15, .external_lex_state = 5},
  [891] = {.lex_state = 14, .external_lex_state = 5},
  [892] = {.lex_state = 14, .external_lex_state = 5},
  [893] = {.lex_state = 14, .external_lex_state = 5},
  [894] = {.lex_state = 15, .external_lex_state = 5},
  [895] = {.lex_state = 15, .external_lex_state = 5},
  [896] = {.lex_state = 15, .external_lex_state = 5},
  [897] = {.lex_state = 0, .external_lex_state = 9},
  [898] = {.lex_state = 15, .external_lex_state = 5},
  [899] = {.lex_state = 0, .external_lex_state = 5},
  [900] = {.lex_state = 14, .external_lex_state = 5},
  [901] = {.lex_state = 14, .external_lex_state = 5},
  [902] = {.lex_state = 14, .external_lex_state = 5},
  [903] = {.lex_state = 14, .external_lex_state = 5},
  [904] = {.lex_state = 0, .external_lex_state = 5},
  [905] = {.lex_state = 7, .external_lex_state = 5},
  [906] = {.lex_state = 15, .external_lex_state = 5},
  [907] = {.lex_state = 14, .external_lex_state = 5},
  [908] = {.lex_state = 14, .external_lex_state = 5},
  [909] = {.lex_state = 14, .external_lex_state = 5},
  [910] = {.lex_state = 14, .external_lex_state = 5},
  [911] = {.lex_state = 15, .external_lex_state = 5},
  [912] = {.lex_state = 14, .external_lex_state = 5},
  [913] = {.lex_state = 15, .external_lex_state = 5},
  [914] = {.lex_state = 7, .external_lex_state = 5},
  [915] = {.lex_state = 14, .external_lex_state = 5},
  [916] = {.lex_state = 0, .external_lex_state = 5},
  [917] = {.lex_state = 14, .external_lex_state = 5},
  [918] = {.lex_state = 14, .external_lex_state = 5},
  [919] = {.lex_state = 14, .external_lex_state = 5},
  [920] = {.lex_state = 15, .external_lex_state = 5},
  [921] = {.lex_state = 7, .external_lex_state = 5},
  [922] = {.lex_state = 15, .external_lex_state = 5},
  [923] = {.lex_state = 15, .external_lex_state = 5},
  [924] = {.lex_state = 14, .external_lex_state = 5},
  [925] = {.lex_state = 15, .external_lex_state = 5},
  [926] = {.lex_state = 0, .external_lex_state = 5},
  [927] = {.lex_state = 14, .external_lex_state = 5},
  [928] = {.lex_state = 14, .external_lex_state = 5},
  [929] = {.lex_state = 14, .external_lex_state = 5},
  [930] = {.lex_state = 15, .external_lex_state = 5},
  [931] = {.lex_state = 14, .external_lex_state = 5},
  [932] = {.lex_state = 15, .external_lex_state = 5},
  [933] = {.lex_state = 15, .external_lex_state = 5},
  [934] = {.lex_state = 14, .external_lex_state = 5},
  [935] = {.lex_state = 15, .external_lex_state = 5},
  [936] = {.lex_state = 14, .external_lex_state = 5},
  [937] = {.lex_state = 14, .external_lex_state = 5},
  [938] = {.lex_state = 0, .external_lex_state = 5},
  [939] = {.lex_state = 15, .external_lex_state = 5},
  [940] = {.lex_state = 14, .external_lex_state = 5},
  [941] = {.lex_state = 7, .external_lex_state = 5},
  [942] = {.lex_state = 15, .external_lex_state = 5},
  [943] = {.lex_state = 0, .external_lex_state = 5},
  [944] = {.lex_state = 7, .external_lex_state = 5},
  [945] = {.lex_state = 14, .external_lex_state = 5},
  [946] = {.lex_state = 15, .external_lex_state = 5},
  [947] = {.lex_state = 15, .external_lex_state = 5},
  [948] = {.lex_state = 15, .external_lex_state = 5},
  [949] = {.lex_state = 14, .external_lex_state = 5},
  [950] = {.lex_state = 14, .external_lex_state = 5},
  [951] = {.lex_state = 0, .external_lex_state = 5},
  [952] = {.lex_state = 14, .external_lex_state = 5},
  [953] = {.lex_state = 14, .external_lex_state = 5},
  [954] = {.lex_state = 0, .external_lex_state = 5},
  [955] = {.lex_state = 14, .external_lex_state = 5},
  [956] = {.lex_state = 0, .external_lex_state = 5},
  [957] = {.lex_state = 0, .external_lex_state = 5},
  [958] = {.lex_state = 7, .external_lex_state = 5},
  [959] = {.lex_state = 7, .external_lex_state = 5},
  [960] = {.lex_state = 14, .external_lex_state = 5},
  [961] = {.lex_state = 7, .external_lex_state = 5},
  [962] = {.lex_state = 14, .external_lex_state = 5},
  [963] = {.lex_state = 15, .external_lex_state = 5},
  [964] = {.lex_state = 15, .external_lex_state = 5},
  [965] = {.lex_state = 14, .external_lex_state = 5},
  [966] = {.lex_state = 14, .external_lex_state = 5},
  [967] = {.lex_state = 14, .external_lex_state = 5},
  [968] = {.lex_state = 15, .external_lex_state = 5},
  [969] = {.lex_state = 0, .external_lex_state = 5},
  [970] = {.lex_state = 0, .external_lex_state = 5},
  [971] = {.lex_state = 0, .external_lex_state = 5},
  [972] = {.lex_state = 15, .external_lex_state = 5},
  [973] = {.lex_state = 15, .external_lex_state = 5},
  [974] = {.lex_state = 14, .external_lex_state = 5},
  [975] = {.lex_state = 0, .external_lex_state = 5},
  [976] = {.lex_state = 14, .external_lex_state = 5},
  [977] = {.lex_state = 14, .external_lex_state = 5},
  [978] = {.lex_state = 0, .external_lex_state = 5},
  [979] = {.lex_state = 15, .external_lex_state = 5},
  [980] = {.lex_state = 7, .external_lex_state = 5},
  [981] = {.lex_state = 7, .external_lex_state = 5},
  [982] = {.lex_state = 7, .external_lex_state = 5},
  [983] = {.lex_state = 7, .external_lex_state = 5},
  [984] = {.lex_state = 14, .external_lex_state = 5},
  [985] = {.lex_state = 0, .external_lex_state = 5},
  [986] = {.lex_state = 14, .external_lex_state = 5},
  [987] = {.lex_state = 0, .external_lex_state = 5},
  [988] = {.lex_state = 14, .external_lex_state = 5},
  [989] = {.lex_state = 7, .external_lex_state = 5},
  [990] = {.lex_state = 7, .external_lex_state = 5},
  [991] = {.lex_state = 14, .external_lex_state = 5},
  [992] = {.lex_state = 14, .external_lex_state = 5},
  [993] = {.lex_state = 7, .external_lex_state = 5},
  [994] = {.lex_state = 7, .external_lex_state = 5},
  [995] = {.lex_state = 0, .external_lex_state = 5},
  [996] = {.lex_state = 0, .external_lex_state = 5},
  [997] = {.lex_state = 14, .external_lex_state = 5},
  [998] = {.lex_state = 15, .external_lex_state = 5},
  [999] = {.lex_state = 14, .external_lex_state = 5},
  [1000] = {.lex_state = 15, .external_lex_state = 5},
  [1001] = {.lex_state = 14, .external_lex_state = 5},
  [1002] = {.lex_state = 15, .external_lex_state = 5},
  [1003] = {.lex_state = 14, .external_lex_state = 5},
  [1004] = {.lex_state = 14, .external_lex_state = 5},
  [1005] = {.lex_state = 15, .external_lex_state = 5},
  [1006] = {.lex_state = 14, .external_lex_state = 5},
  [1007] = {.lex_state = 14, .external_lex_state = 5},
  [1008] = {.lex_state = 15, .external_lex_state = 5},
  [1009] = {.lex_state = 7, .external_lex_state = 5},
  [1010] = {.lex_state = 0, .external_lex_state = 5},
  [1011] = {.lex_state = 0, .external_lex_state = 5},
  [1012] = {.lex_state = 0, .external_lex_state = 5},
  [1013] = {.lex_state = 15, .external_lex_state = 5},
  [1014] = {.lex_state = 15, .external_lex_state = 5},
  [1015] = {.lex_state = 15, .external_lex_state = 5},
  [1016] = {.lex_state = 0, .external_lex_state = 5},
  [1017] = {.lex_state = 0, .external_lex_state = 5},
  [1018] = {.lex_state = 15, .external_lex_state = 5},
  [1019] = {.lex_state = 0, .external_lex_state = 5},
  [1020] = {.lex_state = 15, .external_lex_state = 5},
  [1021] = {.lex_state = 0, .external_lex_state = 5},
  [1022] = {.lex_state = 0, .external_lex_state = 5},
  [1023] = {.lex_state = 0, .external_lex_state = 5},
  [1024] = {.lex_state = 15, .external_lex_state = 5},
  [1025] = {.lex_state = 0, .external_lex_state = 5},
  [1026] = {.lex_state = 15, .external_lex_state = 5},
  [1027] = {.lex_state = 0, .external_lex_state = 5},
  [1028] = {.lex_state = 15, .external_lex_state = 5},
  [1029] = {.lex_state = 15, .external_lex_state = 5},
  [1030] = {.lex_state = 15, .external_lex_state = 5},
  [1031] = {.lex_state = 0, .external_lex_state = 5},
  [1032] = {.lex_state = 0, .external_lex_state = 5},
  [1033] = {.lex_state = 0, .external_lex_state = 5},
  [1034] = {.lex_state = 0, .external_lex_state = 5},
  [1035] = {.lex_state = 0, .external_lex_state = 5},
  [1036] = {.lex_state = 15, .external_lex_state = 5},
  [1037] = {.lex_state = 0, .external_lex_state = 5},
  [1038] = {.lex_state = 15, .external_lex_state = 5},
  [1039] = {.lex_state = 15, .external_lex_state = 5},
  [1040] = {.lex_state = 15, .external_lex_state = 5},
  [1041] = {.lex_state = 15, .external_lex_state = 5},
  [1042] = {.lex_state = 0, .external_lex_state = 5},
  [1043] = {.lex_state = 0, .external_lex_state = 5},
  [1044] = {.lex_state = 15, .external_lex_state = 5},
  [1045] = {.lex_state = 0, .external_lex_state = 5},
  [1046] = {.lex_state = 0, .external_lex_state = 5},
  [1047] = {.lex_state = 15, .external_lex_state = 5},
  [1048] = {.lex_state = 0, .external_lex_state = 5},
  [1049] = {.lex_state = 0, .external_lex_state = 5},
  [1050] = {.lex_state = 0, .external_lex_state = 5},
  [1051] = {.lex_state = 15, .external_lex_state = 5},
  [1052] = {.lex_state = 15, .external_lex_state = 5},
  [1053] = {.lex_state = 0, .external_lex_state = 5},
  [1054] = {.lex_state = 0, .external_lex_state = 5},
  [1055] = {.lex_state = 0, .external_lex_state = 5},
  [1056] = {.lex_state = 15, .external_lex_state = 5},
  [1057] = {.lex_state = 0, .external_lex_state = 5},
  [1058] = {.lex_state = 0, .external_lex_state = 5},
  [1059] = {.lex_state = 0, .external_lex_state = 5},
  [1060] = {.lex_state = 0, .external_lex_state = 5},
  [1061] = {.lex_state = 0, .external_lex_state = 5},
  [1062] = {.lex_state = 0, .external_lex_state = 5},
  [1063] = {.lex_state = 0, .external_lex_state = 5},
  [1064] = {.lex_state = 15, .external_lex_state = 5},
  [1065] = {.lex_state = 0, .external_lex_state = 5},
  [1066] = {.lex_state = 0, .external_lex_state = 5},
  [1067] = {.lex_state = 0, .external_lex_state = 5},
  [1068] = {.lex_state = 15, .external_lex_state = 5},
  [1069] = {.lex_state = 15, .external_lex_state = 5},
  [1070] = {.lex_state = 15, .external_lex_state = 5},
  [1071] = {.lex_state = 0, .external_lex_state = 5},
  [1072] = {.lex_state = 0, .external_lex_state = 5},
  [1073] = {.lex_state = 15, .external_lex_state = 5},
  [1074] = {.lex_state = 15, .external_lex_state = 5},
  [1075] = {.lex_state = 15, .external_lex_state = 5},
  [1076] = {.lex_state = 15, .external_lex_state = 5},
  [1077] = {.lex_state = 15, .external_lex_state = 5},
  [1078] = {.lex_state = 0, .external_lex_state = 5},
  [1079] = {.lex_state = 15, .external_lex_state = 5},
  [1080] = {.lex_state = 15, .external_lex_state = 5},
  [1081] = {.lex_state = 15, .external_lex_state = 5},
  [1082] = {.lex_state = 15, .external_lex_state = 5},
  [1083] = {.lex_state = 15, .external_lex_state = 5},
  [1084] = {.lex_state = 15, .external_lex_state = 5},
  [1085] = {.lex_state = 15, .external_lex_state = 5},
  [1086] = {.lex_state = 15, .external_lex_state = 5},
  [1087] = {.lex_state = 15, .external_lex_state = 5},
  [1088] = {.lex_state = 15, .external_lex_state = 5},
  [1089] = {.lex_state = 15, .external_lex_state = 5},
  [1090] = {.lex_state = 15, .external_lex_state = 5},
  [1091] = {.lex_state = 15, .external_lex_state = 5},
  [1092] = {.lex_state = 15, .external_lex_state = 5},
  [1093] = {.lex_state = 0, .external_lex_state = 5},
  [1094] = {.lex_state = 15, .external_lex_state = 5},
  [1095] = {.lex_state = 15, .external_lex_state = 5},
  [1096] = {.lex_state = 15, .external_lex_state = 5},
  [1097] = {.lex_state = 15, .external_lex_state = 5},
  [1098] = {.lex_state = 15, .external_lex_state = 5},
  [1099] = {.lex_state = 15, .external_lex_state = 5},
  [1100] = {.lex_state = 15, .external_lex_state = 5},
  [1101] = {.lex_state = 15, .external_lex_state = 5},
  [1102] = {.lex_state = 15, .external_lex_state = 5},
  [1103] = {.lex_state = 0, .external_lex_state = 5},
  [1104] = {.lex_state = 0, .external_lex_state = 5},
  [1105] = {.lex_state = 15, .external_lex_state = 5},
  [1106] = {.lex_state = 15, .external_lex_state = 5},
  [1107] = {.lex_state = 15, .external_lex_state = 5},
  [1108] = {.lex_state = 0, .external_lex_state = 5},
  [1109] = {.lex_state = 15, .external_lex_state = 5},
  [1110] = {.lex_state = 0, .external_lex_state = 5},
  [1111] = {.lex_state = 15, .external_lex_state = 5},
  [1112] = {.lex_state = 15, .external_lex_state = 5},
  [1113] = {.lex_state = 15, .external_lex_state = 5},
  [1114] = {.lex_state = 15, .external_lex_state = 5},
  [1115] = {.lex_state = 15, .external_lex_state = 5},
  [1116] = {.lex_state = 15, .external_lex_state = 5},
  [1117] = {.lex_state = 15, .external_lex_state = 5},
  [1118] = {.lex_state = 15, .external_lex_state = 5},
  [1119] = {.lex_state = 15, .external_lex_state = 5},
  [1120] = {.lex_state = 15, .external_lex_state = 5},
  [1121] = {.lex_state = 15, .external_lex_state = 5},
  [1122] = {.lex_state = 15, .external_lex_state = 5},
  [1123] = {.lex_state = 15, .external_lex_state = 5},
  [1124] = {.lex_state = 15, .external_lex_state = 5},
  [1125] = {.lex_state = 15, .external_lex_state = 5},
  [1126] = {.lex_state = 15, .external_lex_state = 5},
  [1127] = {.lex_state = 15, .external_lex_state = 5},
  [1128] = {.lex_state = 15, .external_lex_state = 5},
  [1129] = {.lex_state = 15, .external_lex_state = 5},
  [1130] = {.lex_state = 15, .external_lex_state = 5},
  [1131] = {.lex_state = 15, .external_lex_state = 5},
  [1132] = {.lex_state = 15, .external_lex_state = 5},
  [1133] = {.lex_state = 15, .external_lex_state = 5},
  [1134] = {.lex_state = 15, .external_lex_state = 5},
  [1135] = {.lex_state = 15, .external_lex_state = 5},
  [1136] = {.lex_state = 15, .external_lex_state = 5},
  [1137] = {.lex_state = 0, .external_lex_state = 5},
  [1138] = {.lex_state = 15, .external_lex_state = 5},
  [1139] = {.lex_state = 15, .external_lex_state = 5},
  [1140] = {.lex_state = 15, .external_lex_state = 5},
  [1141] = {.lex_state = 0, .external_lex_state = 5},
  [1142] = {.lex_state = 15, .external_lex_state = 5},
  [1143] = {.lex_state = 15, .external_lex_state = 5},
  [1144] = {.lex_state = 15, .external_lex_state = 5},
  [1145] = {.lex_state = 15, .external_lex_state = 5},
  [1146] = {.lex_state = 15, .external_lex_state = 5},
  [1147] = {.lex_state = 15, .external_lex_state = 5},
  [1148] = {.lex_state = 15, .external_lex_state = 5},
  [1149] = {.lex_state = 15, .external_lex_state = 5},
  [1150] = {.lex_state = 15, .external_lex_state = 5},
  [1151] = {.lex_state = 15, .external_lex_state = 5},
  [1152] = {.lex_state = 15, .external_lex_state = 5},
  [1153] = {.lex_state = 15, .external_lex_state = 5},
  [1154] = {.lex_state = 0, .external_lex_state = 5},
  [1155] = {.lex_state = 0, .external_lex_state = 5},
  [1156] = {.lex_state = 15, .external_lex_state = 5},
  [1157] = {.lex_state = 15, .external_lex_state = 5},
  [1158] = {.lex_state = 15, .external_lex_state = 5},
  [1159] = {.lex_state = 15, .external_lex_state = 5},
  [1160] = {.lex_state = 15, .external_lex_state = 5},
  [1161] = {.lex_state = 15, .external_lex_state = 5},
  [1162] = {.lex_state = 0, .external_lex_state = 5},
  [1163] = {.lex_state = 15, .external_lex_state = 5},
  [1164] = {.lex_state = 0, .external_lex_state = 5},
  [1165] = {.lex_state = 15, .external_lex_state = 5},
  [1166] = {.lex_state = 15, .external_lex_state = 5},
  [1167] = {.lex_state = 0, .external_lex_state = 5},
  [1168] = {.lex_state = 0, .external_lex_state = 5},
  [1169] = {.lex_state = 0, .external_lex_state = 5},
  [1170] = {.lex_state = 15, .external_lex_state = 5},
  [1171] = {.lex_state = 15, .external_lex_state = 5},
  [1172] = {.lex_state = 0, .external_lex_state = 5},
  [1173] = {.lex_state = 15, .external_lex_state = 5},
  [1174] = {.lex_state = 15, .external_lex_state = 5},
  [1175] = {.lex_state = 15, .external_lex_state = 5},
  [1176] = {.lex_state = 0, .external_lex_state = 5},
  [1177] = {.lex_state = 0, .external_lex_state = 5},
  [1178] = {.lex_state = 15, .external_lex_state = 5},
  [1179] = {.lex_state = 0, .external_lex_state = 5},
  [1180] = {.lex_state = 15, .external_lex_state = 5},
  [1181] = {.lex_state = 15, .external_lex_state = 5},
  [1182] = {.lex_state = 0, .external_lex_state = 5},
  [1183] = {.lex_state = 0, .external_lex_state = 5},
  [1184] = {.lex_state = 15, .external_lex_state = 5},
  [1185] = {.lex_state = 0, .external_lex_state = 5},
  [1186] = {.lex_state = 0, .external_lex_state = 5},
  [1187] = {.lex_state = 15, .external_lex_state = 5},
  [1188] = {.lex_state = 0, .external_lex_state = 5},
  [1189] = {.lex_state = 15, .external_lex_state = 5},
  [1190] = {.lex_state = 15, .external_lex_state = 5},
  [1191] = {.lex_state = 0, .external_lex_state = 5},
  [1192] = {.lex_state = 15, .external_lex_state = 5},
  [1193] = {.lex_state = 15, .external_lex_state = 5},
  [1194] = {.lex_state = 15, .external_lex_state = 5},
  [1195] = {.lex_state = 15, .external_lex_state = 5},
  [1196] = {.lex_state = 0, .external_lex_state = 5},
  [1197] = {.lex_state = 15, .external_lex_state = 5},
  [1198] = {.lex_state = 15, .external_lex_state = 5},
  [1199] = {.lex_state = 15, .external_lex_state = 5},
  [1200] = {.lex_state = 15, .external_lex_state = 5},
  [1201] = {.lex_state = 15, .external_lex_state = 5},
  [1202] = {.lex_state = 15, .external_lex_state = 5},
  [1203] = {.lex_state = 0, .external_lex_state = 5},
  [1204] = {.lex_state = 15, .external_lex_state = 5},
  [1205] = {.lex_state = 0, .external_lex_state = 5},
  [1206] = {.lex_state = 15, .external_lex_state = 5},
  [1207] = {.lex_state = 0, .external_lex_state = 5},
  [1208] = {.lex_state = 0, .external_lex_state = 5},
  [1209] = {.lex_state = 0, .external_lex_state = 5},
  [1210] = {.lex_state = 15, .external_lex_state = 5},
  [1211] = {.lex_state = 15, .external_lex_state = 5},
  [1212] = {.lex_state = 0, .external_lex_state = 5},
  [1213] = {.lex_state = 15, .external_lex_state = 5},
  [1214] = {.lex_state = 0, .external_lex_state = 5},
  [1215] = {.lex_state = 15, .external_lex_state = 5},
  [1216] = {.lex_state = 0, .external_lex_state = 5},
  [1217] = {.lex_state = 0, .external_lex_state = 5},
  [1218] = {.lex_state = 0, .external_lex_state = 5},
  [1219] = {.lex_state = 15, .external_lex_state = 5},
  [1220] = {.lex_state = 15, .external_lex_state = 5},
  [1221] = {.lex_state = 0, .external_lex_state = 5},
  [1222] = {.lex_state = 15, .external_lex_state = 5},
  [1223] = {.lex_state = 0, .external_lex_state = 5},
  [1224] = {.lex_state = 15, .external_lex_state = 5},
  [1225] = {.lex_state = 15, .external_lex_state = 5},
  [1226] = {.lex_state = 0, .external_lex_state = 5},
  [1227] = {.lex_state = 0, .external_lex_state = 5},
  [1228] = {.lex_state = 0, .external_lex_state = 5},
  [1229] = {.lex_state = 15, .external_lex_state = 5},
  [1230] = {.lex_state = 0, .external_lex_state = 5},
  [1231] = {.lex_state = 15, .external_lex_state = 5},
  [1232] = {.lex_state = 15, .external_lex_state = 5},
  [1233] = {.lex_state = 15, .external_lex_state = 5},
  [1234] = {.lex_state = 0, .external_lex_state = 5},
  [1235] = {.lex_state = 0, .external_lex_state = 5},
  [1236] = {.lex_state = 15, .external_lex_state = 5},
  [1237] = {.lex_state = 0, .external_lex_state = 5},
  [1238] = {.lex_state = 15, .external_lex_state = 5},
  [1239] = {.lex_state = 15, .external_lex_state = 5},
  [1240] = {.lex_state = 15, .external_lex_state = 5},
  [1241] = {.lex_state = 0, .external_lex_state = 5},
  [1242] = {.lex_state = 0, .external_lex_state = 5},
  [1243] = {.lex_state = 15, .external_lex_state = 5},
  [1244] = {.lex_state = 15, .external_lex_state = 5},
  [1245] = {.lex_state = 15, .external_lex_state = 5},
  [1246] = {.lex_state = 15, .external_lex_state = 5},
  [1247] = {.lex_state = 0, .external_lex_state = 5},
  [1248] = {.lex_state = 0, .external_lex_state = 5},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DOT_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_DOT_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_DOT_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_DOT_SLASH] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_DOT_BSLASH] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_DOT_CARET] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_TILDE_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_DOT_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [sym_return_statement] = ACTIONS(1),
    [sym_continue_statement] = ACTIONS(1),
    [sym_break_statement] = ACTIONS(1),
    [anon_sym_elseif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_parfor] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_otherwise] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_persistent] = ACTIONS(1),
    [anon_sym_arguments] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_get_DOT] = ACTIONS(1),
    [anon_sym_set_DOT] = ACTIONS(1),
    [anon_sym_endfunction] = ACTIONS(1),
    [anon_sym_vector] = ACTIONS(1),
    [anon_sym_matrix] = ACTIONS(1),
    [anon_sym_scalar] = ACTIONS(1),
    [anon_sym_properties] = ACTIONS(1),
    [anon_sym_methods] = ACTIONS(1),
    [anon_sym_events] = ACTIONS(1),
    [anon_sym_enumeration] = ACTIONS(1),
    [anon_sym_classdef] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(1),
    [sym_command_argument] = ACTIONS(1),
    [sym__single_quote_string_start] = ACTIONS(1),
    [sym__single_quote_string_end] = ACTIONS(1),
    [sym__double_quote_string_start] = ACTIONS(1),
    [sym__double_quote_string_end] = ACTIONS(1),
    [sym_formatting_sequence] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_string_content] = ACTIONS(1),
    [sym__entry_delimiter] = ACTIONS(1),
    [sym__multioutput_variable_start] = ACTIONS(1),
    [sym_error_sentinel] = ACTIONS(1),
  },
  [1] = {
    [sym_source_file] = STATE(1227),
    [aux_sym__block] = STATE(71),
    [sym__statement] = STATE(843),
    [sym__expression] = STATE(621),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(621),
    [sym_handle_operator] = STATE(621),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(843),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(843),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(621),
    [sym_if_statement] = STATE(843),
    [sym_for_statement] = STATE(843),
    [sym_while_statement] = STATE(843),
    [sym_switch_statement] = STATE(843),
    [sym_lambda] = STATE(621),
    [sym_global_operator] = STATE(843),
    [sym_persistent_operator] = STATE(843),
    [sym_function_definition] = STATE(923),
    [sym__function_definition_with_end] = STATE(851),
    [sym_class_definition] = STATE(843),
    [sym_try_statement] = STATE(843),
    [sym_boolean] = STATE(210),
    [aux_sym_source_file_repeat1] = STATE(923),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(23),
    [sym_continue_statement] = ACTIONS(23),
    [sym_break_statement] = ACTIONS(23),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(39),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [2] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(783),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_elseif_clause] = STATE(785),
    [sym_else_clause] = STATE(1204),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(5),
    [aux_sym_elseif_clause_repeat1] = STATE(5),
    [aux_sym_if_statement_repeat1] = STATE(785),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_COMMA] = ACTIONS(57),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(81),
    [anon_sym_else] = ACTIONS(83),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(85),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(57),
    [anon_sym_CR] = ACTIONS(57),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [3] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1056),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(8),
    [aux_sym_elseif_clause_repeat1] = STATE(8),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(93),
    [anon_sym_else] = ACTIONS(93),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(93),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(91),
    [anon_sym_CR] = ACTIONS(91),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [4] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1161),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(13),
    [aux_sym_elseif_clause_repeat1] = STATE(13),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(95),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(97),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(95),
    [anon_sym_CR] = ACTIONS(95),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [5] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(784),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_elseif_clause] = STATE(782),
    [sym_else_clause] = STATE(1239),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [aux_sym_if_statement_repeat1] = STATE(782),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(81),
    [anon_sym_else] = ACTIONS(83),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(101),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [6] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1026),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_catch_clause] = STATE(1199),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(7),
    [aux_sym_elseif_clause_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(103),
    [anon_sym_COMMA] = ACTIONS(103),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(105),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(107),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(103),
    [anon_sym_CR] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [7] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1040),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_catch_clause] = STATE(1245),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(109),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(107),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [8] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1030),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(111),
    [anon_sym_else] = ACTIONS(111),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(111),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [9] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1036),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(113),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_case] = ACTIONS(113),
    [anon_sym_otherwise] = ACTIONS(113),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [10] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1229),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(12),
    [aux_sym_elseif_clause_repeat1] = STATE(12),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(115),
    [anon_sym_COMMA] = ACTIONS(115),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [11] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1178),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(18),
    [aux_sym_elseif_clause_repeat1] = STATE(18),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(119),
    [anon_sym_COMMA] = ACTIONS(119),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(119),
    [anon_sym_CR] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [12] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1160),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(123),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [13] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1175),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(125),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [14] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1189),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(15),
    [aux_sym_elseif_clause_repeat1] = STATE(15),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(129),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(127),
    [anon_sym_CR] = ACTIONS(127),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [15] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1194),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(131),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [16] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1158),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(133),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [17] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1215),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(135),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [18] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1201),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(137),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [19] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1173),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(20),
    [aux_sym_elseif_clause_repeat1] = STATE(20),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [20] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1153),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(143),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [21] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(973),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(42),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(42),
    [ts_builtin_sym_end] = ACTIONS(145),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(149),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_endfunction] = ACTIONS(149),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [22] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(1008),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(159),
    [anon_sym_endfunction] = ACTIONS(157),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [23] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(898),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(30),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(30),
    [ts_builtin_sym_end] = ACTIONS(161),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(163),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(165),
    [anon_sym_endfunction] = ACTIONS(163),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [24] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(920),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(32),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(32),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(171),
    [anon_sym_endfunction] = ACTIONS(169),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [25] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(920),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(171),
    [anon_sym_endfunction] = ACTIONS(169),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [26] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(922),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(173),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(175),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(177),
    [anon_sym_endfunction] = ACTIONS(175),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [27] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(925),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(34),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(145),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(179),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_endfunction] = ACTIONS(179),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [28] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(946),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(36),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(36),
    [ts_builtin_sym_end] = ACTIONS(181),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(183),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(185),
    [anon_sym_endfunction] = ACTIONS(183),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [29] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(948),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(37),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(37),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(187),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(159),
    [anon_sym_endfunction] = ACTIONS(187),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [30] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(948),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(187),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(159),
    [anon_sym_endfunction] = ACTIONS(187),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [31] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(939),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(22),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(22),
    [ts_builtin_sym_end] = ACTIONS(161),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(189),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(165),
    [anon_sym_endfunction] = ACTIONS(189),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [32] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(963),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(191),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(193),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(195),
    [anon_sym_endfunction] = ACTIONS(193),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [33] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(979),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(39),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(39),
    [ts_builtin_sym_end] = ACTIONS(197),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(199),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(201),
    [anon_sym_endfunction] = ACTIONS(199),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [34] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(979),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(197),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(199),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(201),
    [anon_sym_endfunction] = ACTIONS(199),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [35] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(930),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(40),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(40),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(171),
    [anon_sym_endfunction] = ACTIONS(203),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [36] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(930),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(171),
    [anon_sym_endfunction] = ACTIONS(203),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [37] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(947),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(173),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(205),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(177),
    [anon_sym_endfunction] = ACTIONS(205),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [38] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(1000),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(25),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(25),
    [ts_builtin_sym_end] = ACTIONS(181),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(207),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(185),
    [anon_sym_endfunction] = ACTIONS(207),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [39] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(942),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(209),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(211),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(213),
    [anon_sym_endfunction] = ACTIONS(211),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [40] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(911),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(191),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(215),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(195),
    [anon_sym_endfunction] = ACTIONS(215),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [41] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(913),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(43),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(43),
    [ts_builtin_sym_end] = ACTIONS(197),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(201),
    [anon_sym_endfunction] = ACTIONS(217),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [42] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(913),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(197),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(201),
    [anon_sym_endfunction] = ACTIONS(217),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [43] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(968),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [ts_builtin_sym_end] = ACTIONS(209),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(219),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(213),
    [anon_sym_endfunction] = ACTIONS(219),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [44] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(1008),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(26),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(26),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(159),
    [anon_sym_endfunction] = ACTIONS(157),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [45] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1113),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(46),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(46),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(221),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(221),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [46] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1083),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(223),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(223),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [47] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1092),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(225),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(225),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [48] = {
    [aux_sym__block] = STATE(60),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(227),
    [anon_sym_else] = ACTIONS(227),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(227),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_case] = ACTIONS(227),
    [anon_sym_otherwise] = ACTIONS(227),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(227),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [49] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1147),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(50),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(50),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(229),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(229),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [50] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1096),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(231),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(231),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [51] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1102),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(55),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(55),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(233),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(233),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [52] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1102),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(233),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(233),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [53] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1115),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(235),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(235),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [54] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1147),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(229),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(229),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [55] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1107),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(237),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(237),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [56] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1109),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(52),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(52),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(239),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(239),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [57] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1114),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(54),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(54),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(241),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(241),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [58] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1087),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(243),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(243),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [59] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1083),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(53),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(53),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(223),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(223),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [60] = {
    [aux_sym__block] = STATE(60),
    [sym__statement] = STATE(881),
    [sym__expression] = STATE(620),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(620),
    [sym_handle_operator] = STATE(620),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(881),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(881),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(620),
    [sym_if_statement] = STATE(881),
    [sym_for_statement] = STATE(881),
    [sym_while_statement] = STATE(881),
    [sym_switch_statement] = STATE(881),
    [sym_lambda] = STATE(620),
    [sym_global_operator] = STATE(881),
    [sym_persistent_operator] = STATE(881),
    [sym__function_definition_with_end] = STATE(892),
    [sym_class_definition] = STATE(881),
    [sym_try_statement] = STATE(881),
    [sym_boolean] = STATE(210),
    [sym_identifier] = ACTIONS(245),
    [anon_sym_LPAREN] = ACTIONS(248),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(254),
    [anon_sym_QMARK] = ACTIONS(257),
    [anon_sym_AT] = ACTIONS(260),
    [anon_sym_LBRACK] = ACTIONS(263),
    [anon_sym_LBRACE] = ACTIONS(266),
    [sym_return_statement] = ACTIONS(269),
    [sym_continue_statement] = ACTIONS(269),
    [sym_break_statement] = ACTIONS(269),
    [anon_sym_elseif] = ACTIONS(272),
    [anon_sym_else] = ACTIONS(272),
    [anon_sym_if] = ACTIONS(274),
    [anon_sym_end] = ACTIONS(272),
    [anon_sym_for] = ACTIONS(277),
    [anon_sym_parfor] = ACTIONS(280),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_case] = ACTIONS(272),
    [anon_sym_otherwise] = ACTIONS(272),
    [anon_sym_switch] = ACTIONS(286),
    [anon_sym_global] = ACTIONS(289),
    [anon_sym_persistent] = ACTIONS(292),
    [anon_sym_function] = ACTIONS(295),
    [anon_sym_classdef] = ACTIONS(298),
    [anon_sym_catch] = ACTIONS(272),
    [anon_sym_try] = ACTIONS(301),
    [sym_number] = ACTIONS(304),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(310),
    [sym__single_quote_string_start] = ACTIONS(313),
    [sym__double_quote_string_start] = ACTIONS(316),
    [sym__multioutput_variable_start] = ACTIONS(319),
  },
  [61] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1082),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(64),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(64),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(322),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(322),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [62] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1084),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(66),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(66),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(324),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(324),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [63] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1085),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(58),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(58),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(326),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(326),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [64] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1085),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(326),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(326),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [65] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1086),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(67),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(67),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(328),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(328),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [66] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1086),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(328),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(328),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [67] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1089),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(330),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(330),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [68] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1088),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(70),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(70),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(332),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(332),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [69] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1090),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(47),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(47),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(334),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(334),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [70] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1090),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym_arguments_statement] = STATE(259),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [aux_sym_function_definition_repeat1] = STATE(259),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(334),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(334),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [71] = {
    [aux_sym__block] = STATE(75),
    [sym__statement] = STATE(843),
    [sym__expression] = STATE(621),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(621),
    [sym_handle_operator] = STATE(621),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(843),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(843),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(621),
    [sym_if_statement] = STATE(843),
    [sym_for_statement] = STATE(843),
    [sym_while_statement] = STATE(843),
    [sym_switch_statement] = STATE(843),
    [sym_lambda] = STATE(621),
    [sym_global_operator] = STATE(843),
    [sym_persistent_operator] = STATE(843),
    [sym_function_definition] = STATE(964),
    [sym__function_definition_with_end] = STATE(851),
    [sym_class_definition] = STATE(843),
    [sym_try_statement] = STATE(843),
    [sym_boolean] = STATE(210),
    [aux_sym_source_file_repeat1] = STATE(964),
    [ts_builtin_sym_end] = ACTIONS(336),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(23),
    [sym_continue_statement] = ACTIONS(23),
    [sym_break_statement] = ACTIONS(23),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(39),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [72] = {
    [aux_sym__block] = STATE(73),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [ts_builtin_sym_end] = ACTIONS(338),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(227),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(340),
    [anon_sym_endfunction] = ACTIONS(227),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [73] = {
    [aux_sym__block] = STATE(73),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [ts_builtin_sym_end] = ACTIONS(343),
    [sym_identifier] = ACTIONS(245),
    [anon_sym_LPAREN] = ACTIONS(248),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(254),
    [anon_sym_QMARK] = ACTIONS(257),
    [anon_sym_AT] = ACTIONS(260),
    [anon_sym_LBRACK] = ACTIONS(263),
    [anon_sym_LBRACE] = ACTIONS(266),
    [sym_return_statement] = ACTIONS(345),
    [sym_continue_statement] = ACTIONS(345),
    [sym_break_statement] = ACTIONS(345),
    [anon_sym_if] = ACTIONS(274),
    [anon_sym_end] = ACTIONS(272),
    [anon_sym_for] = ACTIONS(277),
    [anon_sym_parfor] = ACTIONS(280),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_switch] = ACTIONS(286),
    [anon_sym_global] = ACTIONS(289),
    [anon_sym_persistent] = ACTIONS(292),
    [anon_sym_function] = ACTIONS(295),
    [anon_sym_endfunction] = ACTIONS(272),
    [anon_sym_classdef] = ACTIONS(298),
    [anon_sym_try] = ACTIONS(301),
    [sym_number] = ACTIONS(304),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(310),
    [sym__single_quote_string_start] = ACTIONS(313),
    [sym__double_quote_string_start] = ACTIONS(316),
    [sym__multioutput_variable_start] = ACTIONS(319),
  },
  [74] = {
    [aux_sym__block] = STATE(73),
    [sym__statement] = STATE(849),
    [sym__expression] = STATE(625),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(625),
    [sym_handle_operator] = STATE(625),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(849),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(849),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(625),
    [sym_if_statement] = STATE(849),
    [sym_for_statement] = STATE(849),
    [sym_while_statement] = STATE(849),
    [sym_switch_statement] = STATE(849),
    [sym_lambda] = STATE(625),
    [sym_global_operator] = STATE(849),
    [sym_persistent_operator] = STATE(849),
    [sym__function_definition_with_end] = STATE(852),
    [sym_class_definition] = STATE(849),
    [sym_try_statement] = STATE(849),
    [sym_boolean] = STATE(210),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(227),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(227),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [75] = {
    [aux_sym__block] = STATE(75),
    [sym__statement] = STATE(843),
    [sym__expression] = STATE(621),
    [sym_parenthesis] = STATE(434),
    [sym__binary_expression] = STATE(607),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(379),
    [sym_indirect_access] = STATE(938),
    [sym_field_expression] = STATE(475),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(621),
    [sym_handle_operator] = STATE(621),
    [sym_comparison_operator] = STATE(420),
    [sym_boolean_operator] = STATE(420),
    [sym_postfix_operator] = STATE(434),
    [sym_string] = STATE(434),
    [sym_matrix] = STATE(434),
    [sym_cell] = STATE(426),
    [sym_ignored_argument] = STATE(1176),
    [sym_assignment] = STATE(843),
    [sym_multioutput_variable] = STATE(1176),
    [sym_function_call] = STATE(208),
    [sym_command] = STATE(843),
    [sym__range_element] = STATE(1155),
    [sym_range] = STATE(621),
    [sym_if_statement] = STATE(843),
    [sym_for_statement] = STATE(843),
    [sym_while_statement] = STATE(843),
    [sym_switch_statement] = STATE(843),
    [sym_lambda] = STATE(621),
    [sym_global_operator] = STATE(843),
    [sym_persistent_operator] = STATE(843),
    [sym__function_definition_with_end] = STATE(851),
    [sym_class_definition] = STATE(843),
    [sym_try_statement] = STATE(843),
    [sym_boolean] = STATE(210),
    [ts_builtin_sym_end] = ACTIONS(343),
    [sym_identifier] = ACTIONS(245),
    [anon_sym_LPAREN] = ACTIONS(248),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(254),
    [anon_sym_QMARK] = ACTIONS(257),
    [anon_sym_AT] = ACTIONS(260),
    [anon_sym_LBRACK] = ACTIONS(263),
    [anon_sym_LBRACE] = ACTIONS(266),
    [sym_return_statement] = ACTIONS(348),
    [sym_continue_statement] = ACTIONS(348),
    [sym_break_statement] = ACTIONS(348),
    [anon_sym_if] = ACTIONS(274),
    [anon_sym_for] = ACTIONS(277),
    [anon_sym_parfor] = ACTIONS(280),
    [anon_sym_while] = ACTIONS(283),
    [anon_sym_switch] = ACTIONS(286),
    [anon_sym_global] = ACTIONS(289),
    [anon_sym_persistent] = ACTIONS(292),
    [anon_sym_function] = ACTIONS(295),
    [anon_sym_classdef] = ACTIONS(298),
    [anon_sym_try] = ACTIONS(301),
    [sym_number] = ACTIONS(304),
    [anon_sym_true] = ACTIONS(307),
    [anon_sym_false] = ACTIONS(307),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(310),
    [sym__single_quote_string_start] = ACTIONS(313),
    [sym__double_quote_string_start] = ACTIONS(316),
    [sym__multioutput_variable_start] = ACTIONS(319),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 10,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(355), 1,
      anon_sym_DOT,
    ACTIONS(357), 1,
      anon_sym_AT,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(95), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(363), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [85] = 12,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(355), 1,
      anon_sym_DOT,
    ACTIONS(357), 1,
      anon_sym_AT,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    ACTIONS(367), 1,
      anon_sym_COLON,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(95), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [174] = 12,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(355), 1,
      anon_sym_DOT,
    ACTIONS(357), 1,
      anon_sym_AT,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(95), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(372), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [263] = 10,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(355), 1,
      anon_sym_DOT,
    ACTIONS(357), 1,
      anon_sym_AT,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(95), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(378), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(376), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [348] = 12,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(355), 1,
      anon_sym_DOT,
    ACTIONS(357), 1,
      anon_sym_AT,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    ACTIONS(372), 1,
      anon_sym_COLON,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(95), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [437] = 5,
    ACTIONS(382), 1,
      anon_sym_DOT,
    STATE(83), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(384), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(380), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [511] = 5,
    ACTIONS(382), 1,
      anon_sym_DOT,
    STATE(83), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(388), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(386), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [585] = 5,
    ACTIONS(392), 1,
      anon_sym_DOT,
    STATE(83), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(390), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [659] = 5,
    ACTIONS(382), 1,
      anon_sym_DOT,
    STATE(81), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(399), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(397), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [733] = 5,
    ACTIONS(382), 1,
      anon_sym_DOT,
    STATE(82), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(403), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(401), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [807] = 7,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(357), 1,
      anon_sym_AT,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    STATE(95), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(407), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(405), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [885] = 5,
    ACTIONS(355), 1,
      anon_sym_DOT,
    STATE(88), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(411), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(409), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [959] = 5,
    ACTIONS(415), 1,
      anon_sym_DOT,
    STATE(88), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(418), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(413), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1033] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(422), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(420), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1102] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(426), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(424), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1171] = 10,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(428), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1254] = 8,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    ACTIONS(428), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(363), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1333] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(390), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1402] = 10,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    ACTIONS(428), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(372), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1485] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(432), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(430), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1554] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(436), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(434), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1623] = 8,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    ACTIONS(428), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(378), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(376), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1702] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(440), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(438), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1771] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(444), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(442), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1840] = 10,
    ACTIONS(353), 1,
      anon_sym_LPAREN,
    ACTIONS(361), 1,
      anon_sym_LBRACE,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(428), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1923] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(448), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(446), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1992] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(452), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(450), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2060] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(454), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2128] = 6,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2202] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 41,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2272] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 39,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2344] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(462), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(460), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2412] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(378), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(376), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2482] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(378), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(376), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2552] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(376), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2620] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(378), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(376), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2690] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(468), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(466), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(464), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2760] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(472), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(470), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2828] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(474), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2896] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(480), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(478), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2964] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(484), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(482), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3032] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(488), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(486), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3100] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(492), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(490), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3168] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(496), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(494), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3236] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(502), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(504), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(500), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(498), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3308] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(502), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(504), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(498), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3378] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(502), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(504), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(498), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3448] = 7,
    ACTIONS(508), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(502), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(504), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(506), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(500), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(498), 42,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3524] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(502), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(504), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(506), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(500), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(498), 43,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3598] = 4,
    ACTIONS(512), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(514), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(510), 54,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3668] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(518), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(516), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3736] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(522), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(520), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3804] = 5,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(531), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(526), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(524), 46,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3876] = 6,
    ACTIONS(533), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3950] = 6,
    ACTIONS(535), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4024] = 6,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4098] = 5,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4170] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(466), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4240] = 5,
    ACTIONS(542), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(466), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 48,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4312] = 6,
    ACTIONS(542), 1,
      anon_sym_AMP_AMP,
    ACTIONS(546), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(548), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(466), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(544), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4386] = 6,
    ACTIONS(542), 1,
      anon_sym_AMP_AMP,
    ACTIONS(546), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(552), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(466), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(550), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4460] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(363), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4530] = 6,
    ACTIONS(554), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4604] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(363), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4674] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(363), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4744] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(372), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4818] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(557), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(535), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(458), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4892] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(374), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(372), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4964] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(363), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5034] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(559), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(554), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(533), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5108] = 6,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(359), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5182] = 5,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5252] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(548), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(544), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5323] = 5,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 45,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5392] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 46,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5459] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(552), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(550), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5530] = 5,
    ACTIONS(561), 1,
      anon_sym_DOT,
    STATE(156), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(388), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(386), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5589] = 5,
    ACTIONS(561), 1,
      anon_sym_DOT,
    STATE(152), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(403), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(401), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5648] = 5,
    ACTIONS(561), 1,
      anon_sym_DOT,
    STATE(156), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(384), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(380), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5707] = 5,
    ACTIONS(561), 1,
      anon_sym_DOT,
    STATE(154), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(399), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(397), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5766] = 5,
    ACTIONS(563), 1,
      anon_sym_DOT,
    STATE(156), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(390), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5825] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(390), 41,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5879] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(568), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(566), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5936] = 30,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(574), 1,
      anon_sym_COMMA,
    ACTIONS(576), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_TILDE,
    ACTIONS(582), 1,
      anon_sym_QMARK,
    ACTIONS(584), 1,
      anon_sym_AT,
    ACTIONS(586), 1,
      anon_sym_LBRACK,
    ACTIONS(588), 1,
      aux_sym_matrix_token1,
    ACTIONS(590), 1,
      anon_sym_LBRACE,
    ACTIONS(592), 1,
      sym_number,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(759), 1,
      sym_ignored_argument,
    STATE(921), 1,
      sym_row,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(572), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6041] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(160), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(602), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(605), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(600), 31,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [6095] = 27,
    ACTIONS(576), 1,
      anon_sym_LPAREN,
    ACTIONS(586), 1,
      anon_sym_LBRACK,
    ACTIONS(590), 1,
      anon_sym_LBRACE,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(607), 1,
      sym_identifier,
    ACTIONS(611), 1,
      anon_sym_TILDE,
    ACTIONS(613), 1,
      anon_sym_QMARK,
    ACTIONS(615), 1,
      anon_sym_AT,
    ACTIONS(619), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(352), 1,
      sym_boolean,
    STATE(464), 1,
      sym_unary_operator,
    STATE(492), 1,
      sym_not_operator,
    STATE(495), 1,
      sym_binary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(617), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(609), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(458), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(481), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [6192] = 28,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(576), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_TILDE,
    ACTIONS(582), 1,
      anon_sym_QMARK,
    ACTIONS(584), 1,
      anon_sym_AT,
    ACTIONS(586), 1,
      anon_sym_LBRACK,
    ACTIONS(590), 1,
      anon_sym_LBRACE,
    ACTIONS(592), 1,
      sym_number,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      aux_sym_matrix_token1,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(860), 1,
      sym_ignored_argument,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(621), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(627), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6291] = 28,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(576), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_TILDE,
    ACTIONS(582), 1,
      anon_sym_QMARK,
    ACTIONS(584), 1,
      anon_sym_AT,
    ACTIONS(586), 1,
      anon_sym_LBRACK,
    ACTIONS(590), 1,
      anon_sym_LBRACE,
    ACTIONS(592), 1,
      sym_number,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(627), 1,
      aux_sym_matrix_token1,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(860), 1,
      sym_ignored_argument,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(625), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(627), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6390] = 28,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(576), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_TILDE,
    ACTIONS(582), 1,
      anon_sym_QMARK,
    ACTIONS(584), 1,
      anon_sym_AT,
    ACTIONS(586), 1,
      anon_sym_LBRACK,
    ACTIONS(590), 1,
      anon_sym_LBRACE,
    ACTIONS(592), 1,
      sym_number,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(631), 1,
      aux_sym_matrix_token1,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(860), 1,
      sym_ignored_argument,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(578), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(629), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(627), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6489] = 5,
    STATE(170), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(633), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(635), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [6541] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(655), 1,
      anon_sym_RBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1185), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6641] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(667), 1,
      anon_sym_RBRACE,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1234), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6741] = 5,
    STATE(169), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(669), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(343), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(272), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [6793] = 5,
    STATE(170), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(671), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(673), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [6845] = 5,
    STATE(170), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(679), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(675), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(677), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [6897] = 29,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(682), 1,
      sym_identifier,
    ACTIONS(684), 1,
      anon_sym_RPAREN,
    STATE(375), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(560), 1,
      sym_binary_operator,
    STATE(563), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1218), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(562), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6997] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(655), 1,
      anon_sym_RPAREN,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1183), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7097] = 5,
    STATE(165), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(690), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(686), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(688), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [7149] = 29,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(706), 1,
      anon_sym_RBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(759), 1,
      sym_ignored_argument,
    STATE(958), 1,
      sym_row,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7249] = 29,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(712), 1,
      anon_sym_RBRACE,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(759), 1,
      sym_ignored_argument,
    STATE(959), 1,
      sym_row,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7349] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(684), 1,
      anon_sym_RPAREN,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1218), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7449] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(684), 1,
      anon_sym_RBRACE,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1223), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7549] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(667), 1,
      anon_sym_RPAREN,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1242), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7649] = 29,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(714), 1,
      anon_sym_RBRACK,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(759), 1,
      sym_ignored_argument,
    STATE(985), 1,
      sym_indirect_access,
    STATE(989), 1,
      sym_row,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7749] = 29,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(716), 1,
      anon_sym_RBRACK,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(759), 1,
      sym_ignored_argument,
    STATE(905), 1,
      sym_row,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7849] = 29,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(718), 1,
      anon_sym_RBRACE,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(759), 1,
      sym_ignored_argument,
    STATE(914), 1,
      sym_row,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7949] = 29,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(720), 1,
      anon_sym_RBRACK,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(759), 1,
      sym_ignored_argument,
    STATE(980), 1,
      sym_row,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8049] = 29,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(722), 1,
      anon_sym_RBRACE,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(759), 1,
      sym_ignored_argument,
    STATE(981), 1,
      sym_row,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8149] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(724), 1,
      anon_sym_RPAREN,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1214), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8249] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(724), 1,
      anon_sym_RBRACE,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1217), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8349] = 29,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(692), 1,
      anon_sym_COMMA,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(726), 1,
      anon_sym_RBRACE,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(759), 1,
      sym_ignored_argument,
    STATE(985), 1,
      sym_indirect_access,
    STATE(990), 1,
      sym_row,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8449] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(728), 1,
      anon_sym_RPAREN,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1167), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8549] = 29,
    ACTIONS(639), 1,
      sym_identifier,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(728), 1,
      anon_sym_RBRACE,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(926), 1,
      sym_spread_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1169), 1,
      sym_arguments,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8649] = 9,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(200), 1,
      sym__args,
    STATE(334), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8708] = 11,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(200), 1,
      sym__args,
    STATE(334), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8771] = 9,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(200), 1,
      sym__args,
    STATE(334), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8830] = 6,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(200), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(405), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8883] = 11,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(200), 1,
      sym__args,
    STATE(334), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(372), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [8946] = 11,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(200), 1,
      sym__args,
    STATE(334), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9009] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(420), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9053] = 27,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(740), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1019), 1,
      sym_spread_operator,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(654), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9147] = 27,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(742), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1019), 1,
      sym_spread_operator,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(654), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9241] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(442), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9285] = 27,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1019), 1,
      sym_spread_operator,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(654), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9379] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(430), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9423] = 27,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1019), 1,
      sym_spread_operator,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(654), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9517] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(424), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9561] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(446), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9605] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(434), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9649] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(438), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9693] = 7,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      anon_sym_AT,
    STATE(198), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9746] = 12,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(752), 1,
      anon_sym_DOT,
    ACTIONS(754), 1,
      anon_sym_AT,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym__args,
    STATE(389), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [9809] = 12,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(760), 1,
      anon_sym_EQ,
    STATE(200), 1,
      sym__args,
    STATE(334), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [9872] = 12,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(752), 1,
      anon_sym_DOT,
    ACTIONS(754), 1,
      anon_sym_AT,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym__args,
    STATE(389), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(374), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(372), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [9935] = 9,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      anon_sym_AT,
    STATE(198), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9992] = 9,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      anon_sym_AT,
    STATE(198), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [10049] = 10,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(752), 1,
      anon_sym_DOT,
    ACTIONS(754), 1,
      anon_sym_AT,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym__args,
    STATE(389), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [10108] = 9,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      anon_sym_AT,
    STATE(198), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(372), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10165] = 7,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      anon_sym_AT,
    STATE(198), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [10218] = 26,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(860), 1,
      sym_ignored_argument,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(627), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10309] = 27,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(762), 1,
      sym_identifier,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(766), 1,
      sym_number,
    STATE(374), 1,
      sym_function_call,
    STATE(449), 1,
      sym_boolean,
    STATE(512), 1,
      sym_parenthesis,
    STATE(539), 1,
      sym_binary_operator,
    STATE(558), 1,
      sym_unary_operator,
    STATE(569), 1,
      sym_cell,
    STATE(581), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1022), 1,
      sym__enum_value,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(555), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10402] = 10,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(752), 1,
      anon_sym_DOT,
    ACTIONS(754), 1,
      anon_sym_AT,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym__args,
    STATE(389), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(363), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [10461] = 26,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(698), 1,
      anon_sym_TILDE,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(760), 1,
      sym_ignored_argument,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(610), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10552] = 27,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(762), 1,
      sym_identifier,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(766), 1,
      sym_number,
    STATE(374), 1,
      sym_function_call,
    STATE(449), 1,
      sym_boolean,
    STATE(512), 1,
      sym_parenthesis,
    STATE(539), 1,
      sym_binary_operator,
    STATE(558), 1,
      sym_unary_operator,
    STATE(569), 1,
      sym_cell,
    STATE(581), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1108), 1,
      sym__enum_value,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(555), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10645] = 26,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(617), 1,
      anon_sym_EQ,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(774), 1,
      anon_sym_AT,
    ACTIONS(776), 1,
      sym_number,
    STATE(194), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(397), 1,
      sym_unary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(430), 1,
      sym_binary_operator,
    STATE(431), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(429), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(441), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10736] = 12,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(752), 1,
      anon_sym_DOT,
    ACTIONS(754), 1,
      anon_sym_AT,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym__args,
    STATE(389), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10799] = 23,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      sym_number,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(92), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(121), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(139), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10883] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(798), 1,
      sym_identifier,
    STATE(393), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(560), 1,
      sym_binary_operator,
    STATE(563), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(562), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(684), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10971] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(774), 1,
      anon_sym_AT,
    ACTIONS(776), 1,
      sym_number,
    STATE(194), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(397), 1,
      sym_unary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(430), 1,
      sym_binary_operator,
    STATE(431), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(382), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(429), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [11059] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(774), 1,
      anon_sym_AT,
    ACTIONS(776), 1,
      sym_number,
    STATE(194), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(397), 1,
      sym_unary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(430), 1,
      sym_binary_operator,
    STATE(431), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(394), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(429), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [11147] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(774), 1,
      anon_sym_AT,
    ACTIONS(776), 1,
      sym_number,
    STATE(194), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(397), 1,
      sym_unary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(430), 1,
      sym_binary_operator,
    STATE(431), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(402), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(429), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [11235] = 23,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(804), 1,
      sym_number,
    STATE(217), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(473), 1,
      sym_unary_operator,
    STATE(494), 1,
      sym_cell,
    STATE(499), 1,
      sym_binary_operator,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(496), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(470), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11319] = 23,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(804), 1,
      sym_number,
    STATE(217), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(473), 1,
      sym_unary_operator,
    STATE(494), 1,
      sym_cell,
    STATE(499), 1,
      sym_binary_operator,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(498), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(470), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11403] = 23,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(804), 1,
      sym_number,
    STATE(217), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(473), 1,
      sym_unary_operator,
    STATE(494), 1,
      sym_cell,
    STATE(499), 1,
      sym_binary_operator,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(452), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(470), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11487] = 23,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(804), 1,
      sym_number,
    STATE(217), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(473), 1,
      sym_unary_operator,
    STATE(494), 1,
      sym_cell,
    STATE(499), 1,
      sym_binary_operator,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(454), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(470), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11571] = 23,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(804), 1,
      sym_number,
    STATE(217), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(473), 1,
      sym_unary_operator,
    STATE(494), 1,
      sym_cell,
    STATE(499), 1,
      sym_binary_operator,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(455), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(470), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11655] = 25,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(806), 1,
      sym_identifier,
    ACTIONS(808), 1,
      sym_number,
    STATE(209), 1,
      sym_function_call,
    STATE(361), 1,
      sym_boolean,
    STATE(453), 1,
      sym_binary_operator,
    STATE(457), 1,
      sym__range_element,
    STATE(486), 1,
      sym_unary_operator,
    STATE(488), 1,
      sym_not_operator,
    STATE(589), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(485), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11743] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(774), 1,
      anon_sym_AT,
    ACTIONS(776), 1,
      sym_number,
    STATE(194), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(397), 1,
      sym_unary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(430), 1,
      sym_binary_operator,
    STATE(431), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(424), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(429), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [11831] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(774), 1,
      anon_sym_AT,
    ACTIONS(776), 1,
      sym_number,
    STATE(194), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(397), 1,
      sym_unary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(430), 1,
      sym_binary_operator,
    STATE(431), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(429), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(445), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11919] = 25,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(806), 1,
      sym_identifier,
    ACTIONS(808), 1,
      sym_number,
    STATE(209), 1,
      sym_function_call,
    STATE(361), 1,
      sym_boolean,
    STATE(453), 1,
      sym_binary_operator,
    STATE(486), 1,
      sym_unary_operator,
    STATE(488), 1,
      sym_not_operator,
    STATE(501), 1,
      sym__range_element,
    STATE(589), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(485), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12007] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(674), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12095] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(810), 1,
      sym_identifier,
    STATE(398), 1,
      sym_boolean,
    STATE(403), 1,
      sym_function_call,
    STATE(514), 1,
      sym_cell,
    STATE(568), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(564), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12183] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(382), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [12271] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(636), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12359] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(506), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12447] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(507), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12535] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      sym_number,
    STATE(189), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(396), 1,
      sym_unary_operator,
    STATE(406), 1,
      sym_binary_operator,
    STATE(437), 1,
      sym_cell,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(392), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(395), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12619] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      sym_number,
    STATE(189), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(396), 1,
      sym_unary_operator,
    STATE(406), 1,
      sym_binary_operator,
    STATE(437), 1,
      sym_cell,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(408), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(395), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12703] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(820), 1,
      sym_identifier,
    ACTIONS(822), 1,
      sym_number,
    STATE(193), 1,
      sym_function_call,
    STATE(213), 1,
      sym_boolean,
    STATE(400), 1,
      sym_unary_operator,
    STATE(401), 1,
      sym_not_operator,
    STATE(409), 1,
      sym_binary_operator,
    STATE(425), 1,
      sym__range_element,
    STATE(590), 1,
      sym_cell,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(399), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12791] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      sym_number,
    STATE(189), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(396), 1,
      sym_unary_operator,
    STATE(406), 1,
      sym_binary_operator,
    STATE(437), 1,
      sym_cell,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(436), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(395), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12875] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      sym_number,
    STATE(189), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(396), 1,
      sym_unary_operator,
    STATE(406), 1,
      sym_binary_operator,
    STATE(437), 1,
      sym_cell,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(412), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(395), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12959] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      sym_number,
    STATE(189), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(396), 1,
      sym_unary_operator,
    STATE(406), 1,
      sym_binary_operator,
    STATE(437), 1,
      sym_cell,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(386), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(395), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13043] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(820), 1,
      sym_identifier,
    ACTIONS(822), 1,
      sym_number,
    STATE(193), 1,
      sym_function_call,
    STATE(213), 1,
      sym_boolean,
    STATE(388), 1,
      sym__range_element,
    STATE(400), 1,
      sym_unary_operator,
    STATE(401), 1,
      sym_not_operator,
    STATE(409), 1,
      sym_binary_operator,
    STATE(590), 1,
      sym_cell,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(399), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13131] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(824), 1,
      sym_identifier,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(828), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      sym_number,
    STATE(357), 1,
      sym_function_call,
    STATE(405), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(537), 1,
      sym_unary_operator,
    STATE(540), 1,
      sym_not_operator,
    STATE(545), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(520), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(538), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [13219] = 25,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AT,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(468), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [13307] = 25,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AT,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(561), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13395] = 25,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AT,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(559), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13483] = 23,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      sym_number,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(92), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(120), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(139), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13567] = 23,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      sym_number,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(92), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(122), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(139), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13651] = 23,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      sym_number,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(92), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(123), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(139), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13735] = 23,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      sym_number,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(92), 1,
      sym_boolean,
    STATE(137), 1,
      sym_cell,
    STATE(140), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(124), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(139), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13819] = 25,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(836), 1,
      sym_identifier,
    ACTIONS(838), 1,
      sym_number,
    STATE(78), 1,
      sym_function_call,
    STATE(94), 1,
      sym_boolean,
    STATE(125), 1,
      sym__range_element,
    STATE(142), 1,
      sym_unary_operator,
    STATE(143), 1,
      sym_not_operator,
    STATE(145), 1,
      sym_binary_operator,
    STATE(591), 1,
      sym_cell,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(141), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13907] = 25,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(556), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13995] = 5,
    ACTIONS(844), 1,
      anon_sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(259), 2,
      sym_arguments_statement,
      aux_sym_function_definition_repeat1,
    ACTIONS(840), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(842), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [14043] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(812), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(505), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14131] = 7,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(754), 1,
      anon_sym_AT,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(407), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(405), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [14183] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(847), 1,
      sym_identifier,
    ACTIONS(849), 1,
      sym_number,
    STATE(191), 1,
      sym_function_call,
    STATE(206), 1,
      sym_boolean,
    STATE(419), 1,
      sym_unary_operator,
    STATE(427), 1,
      sym_not_operator,
    STATE(428), 1,
      sym_cell,
    STATE(585), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(416), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14271] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(861), 1,
      anon_sym_EQ,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [14337] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(865), 1,
      anon_sym_QMARK,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(3), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [14425] = 25,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(700), 1,
      anon_sym_QMARK,
    ACTIONS(702), 1,
      anon_sym_AT,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(557), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14513] = 25,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(836), 1,
      sym_identifier,
    ACTIONS(838), 1,
      sym_number,
    STATE(78), 1,
      sym_function_call,
    STATE(94), 1,
      sym_boolean,
    STATE(128), 1,
      sym__range_element,
    STATE(142), 1,
      sym_unary_operator,
    STATE(143), 1,
      sym_not_operator,
    STATE(145), 1,
      sym_binary_operator,
    STATE(591), 1,
      sym_cell,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(141), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14601] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(865), 1,
      anon_sym_QMARK,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(158), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14689] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(454), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [14731] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(812), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(613), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14819] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(865), 1,
      anon_sym_QMARK,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(2), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [14907] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(869), 1,
      sym_number,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(873), 1,
      anon_sym_AT,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(119), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [14995] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(869), 1,
      sym_number,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(873), 1,
      anon_sym_AT,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(150), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15083] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(869), 1,
      sym_number,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(873), 1,
      anon_sym_AT,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(149), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15171] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(865), 1,
      anon_sym_QMARK,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(4), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [15259] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15347] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(865), 1,
      anon_sym_QMARK,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15435] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(875), 1,
      anon_sym_EQ,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [15501] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(877), 1,
      anon_sym_EQ,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [15567] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(879), 1,
      anon_sym_EQ,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [15633] = 4,
    ACTIONS(881), 1,
      anon_sym_DOT,
    STATE(280), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(413), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [15679] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(865), 1,
      anon_sym_QMARK,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(151), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15767] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(812), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(630), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15855] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(824), 1,
      sym_identifier,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(828), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      sym_number,
    STATE(357), 1,
      sym_function_call,
    STATE(405), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(537), 1,
      sym_unary_operator,
    STATE(540), 1,
      sym_not_operator,
    STATE(545), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(528), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(538), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [15943] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(824), 1,
      sym_identifier,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(828), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      sym_number,
    STATE(357), 1,
      sym_function_call,
    STATE(405), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(537), 1,
      sym_unary_operator,
    STATE(540), 1,
      sym_not_operator,
    STATE(545), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(538), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(541), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16031] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(824), 1,
      sym_identifier,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(828), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      sym_number,
    STATE(357), 1,
      sym_function_call,
    STATE(405), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(537), 1,
      sym_unary_operator,
    STATE(540), 1,
      sym_not_operator,
    STATE(545), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(538), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(542), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16119] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(824), 1,
      sym_identifier,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(828), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      sym_number,
    STATE(357), 1,
      sym_function_call,
    STATE(405), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(537), 1,
      sym_unary_operator,
    STATE(540), 1,
      sym_not_operator,
    STATE(545), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(538), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(543), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16207] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(824), 1,
      sym_identifier,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(828), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      sym_number,
    STATE(357), 1,
      sym_function_call,
    STATE(405), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(537), 1,
      sym_unary_operator,
    STATE(540), 1,
      sym_not_operator,
    STATE(545), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(538), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(544), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16295] = 25,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(607), 1,
      sym_identifier,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(884), 1,
      anon_sym_AT,
    ACTIONS(886), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(352), 1,
      sym_boolean,
    STATE(464), 1,
      sym_unary_operator,
    STATE(492), 1,
      sym_not_operator,
    STATE(495), 1,
      sym_binary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(468), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(481), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16383] = 25,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(607), 1,
      sym_identifier,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(884), 1,
      anon_sym_AT,
    ACTIONS(886), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(352), 1,
      sym_boolean,
    STATE(464), 1,
      sym_unary_operator,
    STATE(492), 1,
      sym_not_operator,
    STATE(495), 1,
      sym_binary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(481), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(500), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16471] = 25,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(607), 1,
      sym_identifier,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(884), 1,
      anon_sym_AT,
    ACTIONS(886), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(352), 1,
      sym_boolean,
    STATE(464), 1,
      sym_unary_operator,
    STATE(492), 1,
      sym_not_operator,
    STATE(495), 1,
      sym_binary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(481), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(503), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16559] = 25,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(607), 1,
      sym_identifier,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(884), 1,
      anon_sym_AT,
    ACTIONS(886), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(352), 1,
      sym_boolean,
    STATE(464), 1,
      sym_unary_operator,
    STATE(492), 1,
      sym_not_operator,
    STATE(495), 1,
      sym_binary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(461), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(481), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16647] = 25,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(607), 1,
      sym_identifier,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(884), 1,
      anon_sym_AT,
    ACTIONS(886), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(352), 1,
      sym_boolean,
    STATE(464), 1,
      sym_unary_operator,
    STATE(492), 1,
      sym_not_operator,
    STATE(495), 1,
      sym_binary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(466), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(481), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16735] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16823] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(637), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16911] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(888), 1,
      sym_identifier,
    ACTIONS(890), 1,
      anon_sym_AT,
    ACTIONS(892), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(106), 1,
      sym_cell,
    STATE(130), 1,
      sym_unary_operator,
    STATE(132), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(119), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16999] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(888), 1,
      sym_identifier,
    ACTIONS(890), 1,
      anon_sym_AT,
    ACTIONS(892), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(106), 1,
      sym_cell,
    STATE(130), 1,
      sym_unary_operator,
    STATE(132), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(133), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17087] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(888), 1,
      sym_identifier,
    ACTIONS(890), 1,
      anon_sym_AT,
    ACTIONS(892), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(106), 1,
      sym_cell,
    STATE(130), 1,
      sym_unary_operator,
    STATE(132), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(134), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17175] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(888), 1,
      sym_identifier,
    ACTIONS(890), 1,
      anon_sym_AT,
    ACTIONS(892), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(106), 1,
      sym_cell,
    STATE(130), 1,
      sym_unary_operator,
    STATE(132), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(135), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17263] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(648), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17351] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(812), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(509), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17439] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(888), 1,
      sym_identifier,
    ACTIONS(890), 1,
      anon_sym_AT,
    ACTIONS(892), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(106), 1,
      sym_cell,
    STATE(130), 1,
      sym_unary_operator,
    STATE(132), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(136), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17527] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(774), 1,
      anon_sym_AT,
    ACTIONS(776), 1,
      sym_number,
    STATE(194), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(397), 1,
      sym_unary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(430), 1,
      sym_binary_operator,
    STATE(431), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(429), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(441), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17615] = 5,
    STATE(318), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(894), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(343), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(272), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [17663] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(896), 1,
      sym_identifier,
    ACTIONS(898), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(528), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17751] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(896), 1,
      sym_identifier,
    ACTIONS(898), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(582), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17839] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(896), 1,
      sym_identifier,
    ACTIONS(898), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(587), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17927] = 23,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(900), 1,
      sym_identifier,
    ACTIONS(902), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(404), 1,
      sym_boolean,
    STATE(546), 1,
      sym_cell,
    STATE(549), 1,
      sym_unary_operator,
    STATE(553), 1,
      sym_binary_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(529), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(548), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18011] = 23,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(900), 1,
      sym_identifier,
    ACTIONS(902), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(404), 1,
      sym_boolean,
    STATE(546), 1,
      sym_cell,
    STATE(549), 1,
      sym_unary_operator,
    STATE(553), 1,
      sym_binary_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(530), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(548), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18095] = 23,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(900), 1,
      sym_identifier,
    ACTIONS(902), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(404), 1,
      sym_boolean,
    STATE(546), 1,
      sym_cell,
    STATE(549), 1,
      sym_unary_operator,
    STATE(553), 1,
      sym_binary_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(531), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(548), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18179] = 23,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(900), 1,
      sym_identifier,
    ACTIONS(902), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(404), 1,
      sym_boolean,
    STATE(546), 1,
      sym_cell,
    STATE(549), 1,
      sym_unary_operator,
    STATE(553), 1,
      sym_binary_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(532), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(548), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18263] = 23,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(900), 1,
      sym_identifier,
    ACTIONS(902), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(404), 1,
      sym_boolean,
    STATE(546), 1,
      sym_cell,
    STATE(549), 1,
      sym_unary_operator,
    STATE(553), 1,
      sym_binary_operator,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(510), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(548), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18347] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(904), 1,
      sym_identifier,
    ACTIONS(906), 1,
      sym_number,
    STATE(346), 1,
      sym_function_call,
    STATE(410), 1,
      sym_boolean,
    STATE(517), 1,
      sym_unary_operator,
    STATE(518), 1,
      sym_not_operator,
    STATE(519), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18435] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(910), 1,
      sym_number,
    STATE(359), 1,
      sym_function_call,
    STATE(407), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(514), 1,
      sym_cell,
    STATE(533), 1,
      sym__range_element,
    STATE(551), 1,
      sym_unary_operator,
    STATE(552), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(550), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18523] = 5,
    STATE(322), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(912), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(686), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(688), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [18571] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(914), 1,
      sym_identifier,
    STATE(398), 1,
      sym_boolean,
    STATE(433), 1,
      sym_function_call,
    STATE(514), 1,
      sym_cell,
    STATE(573), 1,
      sym_binary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(578), 1,
      sym_unary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(572), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18659] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(888), 1,
      sym_identifier,
    ACTIONS(890), 1,
      anon_sym_AT,
    ACTIONS(892), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(106), 1,
      sym_cell,
    STATE(130), 1,
      sym_unary_operator,
    STATE(132), 1,
      sym_not_operator,
    STATE(138), 1,
      sym_binary_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(112), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [18747] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(896), 1,
      sym_identifier,
    STATE(366), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(584), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18835] = 5,
    STATE(324), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(916), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(671), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(673), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [18883] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(505), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18971] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(896), 1,
      sym_identifier,
    STATE(366), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(682), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19059] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      anon_sym_QMARK,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(509), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19147] = 5,
    STATE(324), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(916), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(633), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(635), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [19195] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(896), 1,
      sym_identifier,
    STATE(366), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(588), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19283] = 5,
    STATE(324), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(918), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(675), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(677), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [19331] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(908), 1,
      sym_identifier,
    ACTIONS(910), 1,
      sym_number,
    STATE(359), 1,
      sym_function_call,
    STATE(407), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(514), 1,
      sym_cell,
    STATE(551), 1,
      sym_unary_operator,
    STATE(552), 1,
      sym_not_operator,
    STATE(554), 1,
      sym__range_element,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(550), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19419] = 25,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(921), 1,
      sym_identifier,
    ACTIONS(923), 1,
      sym_number,
    STATE(212), 1,
      sym_function_call,
    STATE(369), 1,
      sym_boolean,
    STATE(487), 1,
      sym_unary_operator,
    STATE(489), 1,
      sym_not_operator,
    STATE(490), 1,
      sym_cell,
    STATE(586), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(484), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19507] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(812), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(628), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19595] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(925), 1,
      sym_identifier,
    STATE(391), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(574), 1,
      sym_binary_operator,
    STATE(575), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(576), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19683] = 25,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(607), 1,
      sym_identifier,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(884), 1,
      anon_sym_AT,
    ACTIONS(886), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(352), 1,
      sym_boolean,
    STATE(464), 1,
      sym_unary_operator,
    STATE(492), 1,
      sym_not_operator,
    STATE(495), 1,
      sym_binary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(458), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(481), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [19771] = 25,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(927), 1,
      sym_identifier,
    ACTIONS(929), 1,
      sym_number,
    STATE(79), 1,
      sym_function_call,
    STATE(97), 1,
      sym_boolean,
    STATE(109), 1,
      sym_unary_operator,
    STATE(110), 1,
      sym_not_operator,
    STATE(111), 1,
      sym_cell,
    STATE(583), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(108), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19859] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(812), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(210), 1,
      sym_boolean,
    STATE(379), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(426), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(607), 1,
      sym__binary_expression,
    STATE(938), 1,
      sym_indirect_access,
    STATE(1155), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(420), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(594), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19947] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(931), 1,
      sym_identifier,
    STATE(398), 1,
      sym_boolean,
    STATE(439), 1,
      sym_function_call,
    STATE(514), 1,
      sym_cell,
    STATE(565), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(567), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20035] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(933), 1,
      sym_identifier,
    STATE(398), 1,
      sym_boolean,
    STATE(432), 1,
      sym_function_call,
    STATE(514), 1,
      sym_cell,
    STATE(571), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(580), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(688), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20123] = 4,
    ACTIONS(732), 1,
      anon_sym_DOT,
    STATE(280), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(409), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [20169] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(798), 1,
      sym_identifier,
    STATE(393), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(560), 1,
      sym_binary_operator,
    STATE(563), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(562), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(680), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20257] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(584), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20345] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(649), 1,
      anon_sym_AT,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    STATE(348), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(588), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20433] = 25,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AT,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(556), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20521] = 25,
    ACTIONS(570), 1,
      sym_identifier,
    ACTIONS(596), 1,
      sym__single_quote_string_start,
    ACTIONS(598), 1,
      sym__double_quote_string_start,
    ACTIONS(694), 1,
      anon_sym_LPAREN,
    ACTIONS(704), 1,
      anon_sym_LBRACK,
    ACTIONS(708), 1,
      anon_sym_LBRACE,
    ACTIONS(710), 1,
      sym_number,
    ACTIONS(802), 1,
      anon_sym_TILDE,
    ACTIONS(832), 1,
      anon_sym_QMARK,
    ACTIONS(834), 1,
      anon_sym_AT,
    STATE(221), 1,
      sym_function_call,
    STATE(347), 1,
      sym_boolean,
    STATE(451), 1,
      sym_binary_operator,
    STATE(472), 1,
      sym_unary_operator,
    STATE(504), 1,
      sym_cell,
    STATE(536), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(985), 1,
      sym_indirect_access,
    STATE(1154), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(594), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(696), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(502), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(557), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20609] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(869), 1,
      sym_number,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(873), 1,
      anon_sym_AT,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20697] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_LBRACK,
    ACTIONS(788), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym__single_quote_string_start,
    ACTIONS(796), 1,
      sym__double_quote_string_start,
    ACTIONS(863), 1,
      sym_identifier,
    ACTIONS(869), 1,
      sym_number,
    ACTIONS(871), 1,
      anon_sym_QMARK,
    ACTIONS(873), 1,
      anon_sym_AT,
    STATE(80), 1,
      sym_function_call,
    STATE(100), 1,
      sym_boolean,
    STATE(104), 1,
      sym_unary_operator,
    STATE(106), 1,
      sym_cell,
    STATE(129), 1,
      sym_binary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(611), 1,
      sym__binary_expression,
    STATE(995), 1,
      sym_indirect_access,
    STATE(1241), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(792), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(105), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(146), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(151), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20785] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(798), 1,
      sym_identifier,
    STATE(393), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(560), 1,
      sym_binary_operator,
    STATE(563), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(562), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(685), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20873] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(896), 1,
      sym_identifier,
    ACTIONS(898), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(584), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20961] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(826), 1,
      anon_sym_QMARK,
    ACTIONS(896), 1,
      sym_identifier,
    ACTIONS(898), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(539), 1,
      sym_binary_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(512), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(588), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21049] = 25,
    ACTIONS(641), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_TILDE,
    ACTIONS(647), 1,
      anon_sym_QMARK,
    ACTIONS(651), 1,
      anon_sym_LBRACK,
    ACTIONS(653), 1,
      anon_sym_LBRACE,
    ACTIONS(659), 1,
      sym_number,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(764), 1,
      anon_sym_AT,
    ACTIONS(798), 1,
      sym_identifier,
    STATE(393), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(514), 1,
      sym_cell,
    STATE(560), 1,
      sym_binary_operator,
    STATE(563), 1,
      sym_unary_operator,
    STATE(577), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(975), 1,
      sym_indirect_access,
    STATE(1247), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(513), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(562), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(676), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21137] = 10,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(378), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21194] = 10,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    ACTIONS(935), 1,
      anon_sym_AT,
    STATE(362), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [21251] = 13,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(456), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [21314] = 4,
    ACTIONS(937), 1,
      anon_sym_DOT,
    STATE(353), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(397), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [21359] = 4,
    ACTIONS(937), 1,
      anon_sym_DOT,
    STATE(355), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(401), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [21404] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(436), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(434), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21447] = 10,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    ACTIONS(935), 1,
      anon_sym_AT,
    STATE(362), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [21504] = 4,
    ACTIONS(937), 1,
      anon_sym_DOT,
    STATE(364), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [21549] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(432), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(430), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21592] = 4,
    ACTIONS(937), 1,
      anon_sym_DOT,
    STATE(364), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(386), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [21637] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(877), 1,
      anon_sym_EQ,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [21702] = 13,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(939), 1,
      anon_sym_COLON,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [21765] = 10,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(363), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21822] = 13,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(367), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(939), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [21885] = 8,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    ACTIONS(935), 1,
      anon_sym_AT,
    STATE(362), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(363), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21938] = 10,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    ACTIONS(935), 1,
      anon_sym_AT,
    STATE(362), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(374), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(372), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [21995] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(444), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(442), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22038] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(440), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(438), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22081] = 4,
    ACTIONS(942), 1,
      anon_sym_DOT,
    STATE(364), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(390), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22126] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(448), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(446), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22169] = 13,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22232] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(426), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(424), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22275] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(422), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(420), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22318] = 8,
    ACTIONS(750), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_LBRACE,
    ACTIONS(935), 1,
      anon_sym_AT,
    STATE(362), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22371] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(945), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(947), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [22413] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(949), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(951), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [22455] = 7,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(405), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(407), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22505] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(953), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(955), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [22547] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(957), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22611] = 13,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(456), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22673] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(390), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22713] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(454), 31,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22755] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(959), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(961), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [22797] = 5,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22842] = 5,
    ACTIONS(963), 1,
      anon_sym_DOT,
    STATE(383), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(399), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(397), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22887] = 5,
    ACTIONS(963), 1,
      anon_sym_DOT,
    STATE(384), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(403), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(401), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22932] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(494), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22971] = 5,
    ACTIONS(963), 1,
      anon_sym_DOT,
    STATE(385), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(384), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(380), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23016] = 5,
    ACTIONS(963), 1,
      anon_sym_DOT,
    STATE(385), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(388), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(386), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23061] = 5,
    ACTIONS(965), 1,
      anon_sym_DOT,
    STATE(385), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(390), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23106] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(972), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(968), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(970), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(498), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23151] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(430), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(432), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23192] = 3,
    ACTIONS(974), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(510), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23233] = 5,
    ACTIONS(752), 1,
      anon_sym_DOT,
    STATE(418), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(411), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(409), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23278] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(438), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(440), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23319] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(976), 1,
      anon_sym_RPAREN,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23382] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(972), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(970), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(498), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23425] = 13,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 7,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23486] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(978), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23527] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23568] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23609] = 5,
    ACTIONS(535), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23654] = 11,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(980), 1,
      anon_sym_AT,
    STATE(414), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23711] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(372), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23756] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(458), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(535), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23801] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(372), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23844] = 4,
    ACTIONS(982), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(978), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 25,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23887] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(984), 1,
      anon_sym_RPAREN,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23950] = 8,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(980), 1,
      anon_sym_AT,
    STATE(414), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(363), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24001] = 11,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(939), 1,
      anon_sym_COLON,
    ACTIONS(980), 1,
      anon_sym_AT,
    STATE(414), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24058] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24099] = 11,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(980), 1,
      anon_sym_AT,
    STATE(414), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(367), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(939), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24156] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(972), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(498), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24197] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(533), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(554), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [24242] = 8,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(980), 1,
      anon_sym_AT,
    STATE(414), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(378), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24293] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24332] = 6,
    ACTIONS(986), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(972), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(968), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(970), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(498), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24379] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(474), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24418] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(442), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(444), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24459] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(478), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24498] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24539] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(482), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24578] = 5,
    ACTIONS(988), 1,
      anon_sym_DOT,
    STATE(418), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(418), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(413), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24623] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24664] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 18,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24705] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(486), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24744] = 5,
    ACTIONS(533), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24789] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(490), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24828] = 5,
    ACTIONS(982), 1,
      anon_sym_AMP_AMP,
    ACTIONS(991), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(978), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(544), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24873] = 4,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(526), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(524), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24916] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24959] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24998] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25039] = 5,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25084] = 5,
    ACTIONS(554), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25129] = 4,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25172] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(993), 1,
      anon_sym_RPAREN,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25235] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(995), 1,
      anon_sym_RPAREN,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25298] = 5,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25343] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(446), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(448), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25384] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(972), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(498), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25425] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25466] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(424), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(426), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25507] = 14,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(853), 1,
      anon_sym_DOT,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_RPAREN,
    STATE(387), 1,
      sym__args,
    STATE(462), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25570] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25609] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(978), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(464), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25650] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(470), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25689] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(450), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25728] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(420), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(422), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25769] = 5,
    ACTIONS(982), 1,
      anon_sym_AMP_AMP,
    ACTIONS(991), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(978), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(550), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25814] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(434), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(436), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25855] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(520), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25894] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(454), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(456), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25934] = 12,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(980), 1,
      anon_sym_AT,
    STATE(414), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(957), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25992] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(390), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26032] = 6,
    ACTIONS(533), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26077] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(999), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(498), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26118] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(559), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(533), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(554), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26163] = 7,
    ACTIONS(1005), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(999), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1001), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1003), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(498), 15,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26210] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(999), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1001), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1003), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(498), 16,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26255] = 5,
    ACTIONS(853), 1,
      anon_sym_DOT,
    STATE(463), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(409), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(411), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26298] = 4,
    ACTIONS(1007), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(514), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(510), 27,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [26339] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(468), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1009), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(464), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26380] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(480), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(478), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26419] = 5,
    ACTIONS(1011), 1,
      anon_sym_DOT,
    STATE(477), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(384), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26462] = 6,
    ACTIONS(1013), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1015), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(548), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1009), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(544), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26507] = 5,
    ACTIONS(853), 1,
      anon_sym_DOT,
    STATE(463), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(409), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(411), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26550] = 5,
    ACTIONS(1017), 1,
      anon_sym_DOT,
    STATE(463), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(413), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(418), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26593] = 6,
    ACTIONS(535), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26638] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(488), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(486), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26677] = 6,
    ACTIONS(1013), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1015), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(552), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1009), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(550), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26722] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(472), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(470), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26761] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(496), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(494), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26800] = 5,
    ACTIONS(1011), 1,
      anon_sym_DOT,
    STATE(477), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(386), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(388), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26843] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(363), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26884] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(492), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(490), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26923] = 6,
    ACTIONS(458), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26968] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(363), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27009] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 14,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27050] = 6,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(760), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27095] = 5,
    ACTIONS(1011), 1,
      anon_sym_DOT,
    STATE(460), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(397), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(399), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27138] = 5,
    ACTIONS(1020), 1,
      anon_sym_DOT,
    STATE(477), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(390), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(395), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27181] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(484), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(482), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27220] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(518), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(516), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27259] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(462), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(460), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27298] = 6,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27343] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(522), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(520), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27382] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(474), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27421] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27462] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(374), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(372), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27507] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(557), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(458), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(535), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27552] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27593] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(374), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(372), 6,
      anon_sym_SEMI,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(367), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27636] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(376), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27675] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27716] = 5,
    ACTIONS(1011), 1,
      anon_sym_DOT,
    STATE(469), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(401), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(403), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27759] = 5,
    ACTIONS(367), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(365), 13,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27802] = 4,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [27843] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(363), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27884] = 6,
    ACTIONS(554), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27929] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(999), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1003), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(498), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27972] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(452), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(450), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28011] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(999), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(498), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28052] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(363), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28093] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1009), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28134] = 5,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(531), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(526), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(524), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [28177] = 6,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28222] = 5,
    ACTIONS(1013), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1009), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 21,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28265] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(756), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(365), 12,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28308] = 5,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1027), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(544), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [28350] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [28388] = 4,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 22,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [28428] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(390), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(395), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28466] = 5,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1027), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(550), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [28508] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1033), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(498), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1029), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1031), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(504), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28551] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(554), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(559), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1035), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28596] = 7,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28641] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(370), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28682] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28725] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(462), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28762] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(378), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28801] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(378), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28840] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(378), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28877] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(378), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28916] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1038), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1040), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(468), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28957] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(470), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(472), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28994] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(450), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(452), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29031] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(474), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(476), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29068] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(478), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(480), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29105] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(482), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(484), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29142] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(486), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(488), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29179] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(490), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(492), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29216] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(494), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(496), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29253] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1033), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(498), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1031), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(504), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29294] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1033), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(498), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(504), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29333] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1033), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(498), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(504), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29372] = 7,
    ACTIONS(1042), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1033), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(498), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1029), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1031), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(504), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29417] = 4,
    ACTIONS(1044), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(510), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(514), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [29456] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(518), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29493] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(520), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(522), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29530] = 5,
    ACTIONS(372), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(365), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(351), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29571] = 7,
    ACTIONS(1046), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29616] = 7,
    ACTIONS(939), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29661] = 7,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29706] = 6,
    ACTIONS(939), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(370), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29749] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1038), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1040), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(540), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29790] = 6,
    ACTIONS(1049), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1038), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1040), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(540), 19,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29833] = 7,
    ACTIONS(1049), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1051), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(544), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1038), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1040), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(548), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29878] = 7,
    ACTIONS(1049), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1051), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(550), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1038), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1040), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(552), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29923] = 7,
    ACTIONS(1035), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29968] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(363), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30007] = 7,
    ACTIONS(557), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30052] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(363), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30091] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(363), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30130] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(367), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(939), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30175] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(535), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(557), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1046), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30220] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(367), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(374), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(939), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30263] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(351), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(363), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30302] = 6,
    ACTIONS(1044), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(524), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(526), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(531), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [30345] = 8,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(957), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30391] = 6,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(548), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1056), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(544), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30433] = 6,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(552), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1056), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(550), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30475] = 8,
    ACTIONS(557), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(957), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30521] = 5,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1056), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 18,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30561] = 7,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30605] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1056), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(538), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30643] = 7,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30687] = 7,
    ACTIONS(557), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30731] = 8,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(984), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30776] = 8,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(997), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30821] = 8,
    ACTIONS(557), 1,
      anon_sym_COLON,
    ACTIONS(997), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30866] = 8,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(997), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30911] = 8,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(984), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30956] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(957), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30999] = 8,
    ACTIONS(557), 1,
      anon_sym_COLON,
    ACTIONS(984), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31044] = 8,
    ACTIONS(557), 1,
      anon_sym_COLON,
    ACTIONS(993), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31089] = 8,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(995), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31134] = 8,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(995), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31179] = 8,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(976), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31224] = 8,
    ACTIONS(557), 1,
      anon_sym_COLON,
    ACTIONS(976), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31269] = 8,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(976), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31314] = 6,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31355] = 8,
    ACTIONS(557), 1,
      anon_sym_COLON,
    ACTIONS(995), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31400] = 8,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(993), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31445] = 8,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(993), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(857), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31490] = 7,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(957), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31532] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(540), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [31570] = 7,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1066), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31612] = 7,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(544), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(548), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [31654] = 7,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1072), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31696] = 7,
    ACTIONS(559), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1074), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31738] = 6,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(540), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [31778] = 7,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(550), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(552), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [31820] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1074), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31859] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1072), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31898] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(351), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(365), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1066), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(370), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(363), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31937] = 4,
    ACTIONS(1076), 1,
      anon_sym_DOT,
    STATE(592), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(390), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [31971] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(390), 22,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [32000] = 11,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1027), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1081), 1,
      anon_sym_end,
    ACTIONS(1083), 1,
      anon_sym_case,
    ACTIONS(1085), 1,
      anon_sym_otherwise,
    STATE(1243), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(635), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(773), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1079), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32045] = 16,
    ACTIONS(1087), 1,
      sym_identifier,
    ACTIONS(1089), 1,
      anon_sym_COMMA,
    ACTIONS(1091), 1,
      anon_sym_LPAREN,
    ACTIONS(1093), 1,
      anon_sym_DOT,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1097), 1,
      anon_sym_AT,
    ACTIONS(1099), 1,
      anon_sym_RBRACK,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    STATE(632), 1,
      sym_function_call,
    STATE(639), 1,
      sym__args,
    STATE(681), 1,
      aux_sym_field_expression_repeat1,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(624), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [32098] = 4,
    ACTIONS(1103), 1,
      anon_sym_DOT,
    STATE(597), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(397), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [32126] = 4,
    ACTIONS(1103), 1,
      anon_sym_DOT,
    STATE(592), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [32154] = 4,
    ACTIONS(1103), 1,
      anon_sym_DOT,
    STATE(592), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(386), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [32182] = 4,
    ACTIONS(1103), 1,
      anon_sym_DOT,
    STATE(598), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(401), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [32210] = 14,
    ACTIONS(1105), 1,
      sym_identifier,
    ACTIONS(1109), 1,
      anon_sym_LPAREN,
    ACTIONS(1111), 1,
      anon_sym_DOT,
    ACTIONS(1113), 1,
      anon_sym_AT,
    ACTIONS(1115), 1,
      anon_sym_LBRACE,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(641), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(662), 1,
      sym_dimensions,
    STATE(683), 1,
      sym_property_name,
    STATE(735), 1,
      sym_validation_functions,
    STATE(840), 1,
      sym_default_value,
    STATE(1044), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1107), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [32257] = 5,
    ACTIONS(1119), 1,
      anon_sym_DOT,
    STATE(601), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(390), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32285] = 5,
    ACTIONS(1122), 1,
      anon_sym_DOT,
    STATE(601), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(388), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(386), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32313] = 5,
    ACTIONS(1124), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(390), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(395), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [32341] = 5,
    ACTIONS(1122), 1,
      anon_sym_DOT,
    STATE(606), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(399), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(397), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32369] = 5,
    ACTIONS(1122), 1,
      anon_sym_DOT,
    STATE(602), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(403), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(401), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32397] = 5,
    ACTIONS(1122), 1,
      anon_sym_DOT,
    STATE(601), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(384), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(380), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32425] = 6,
    ACTIONS(1133), 1,
      anon_sym_PIPE,
    ACTIONS(1135), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1131), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1127), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1129), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32454] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(390), 12,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32477] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(390), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(395), 12,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [32500] = 8,
    ACTIONS(627), 1,
      aux_sym_matrix_token1,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1137), 1,
      sym__entry_delimiter,
    STATE(777), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(625), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1056), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32533] = 6,
    ACTIONS(1145), 1,
      anon_sym_PIPE,
    ACTIONS(1147), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1143), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1139), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1141), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32562] = 12,
    ACTIONS(1105), 1,
      sym_identifier,
    ACTIONS(1109), 1,
      anon_sym_LPAREN,
    ACTIONS(1113), 1,
      anon_sym_AT,
    ACTIONS(1115), 1,
      anon_sym_LBRACE,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(662), 1,
      sym_dimensions,
    STATE(683), 1,
      sym_property_name,
    STATE(735), 1,
      sym_validation_functions,
    STATE(840), 1,
      sym_default_value,
    STATE(1044), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1107), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [32603] = 6,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1027), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(9), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1149), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32632] = 6,
    ACTIONS(1151), 1,
      anon_sym_PIPE,
    ACTIONS(1153), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1033), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1029), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1031), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32661] = 8,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1157), 1,
      aux_sym_matrix_token1,
    ACTIONS(1159), 1,
      sym__entry_delimiter,
    STATE(751), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1155), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1056), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32694] = 6,
    ACTIONS(1167), 1,
      anon_sym_PIPE,
    ACTIONS(1169), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1165), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1161), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1163), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32723] = 5,
    ACTIONS(1171), 1,
      anon_sym_DOT,
    STATE(623), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(401), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(403), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [32749] = 11,
    ACTIONS(1173), 1,
      sym_identifier,
    ACTIONS(1176), 1,
      anon_sym_COMMA,
    ACTIONS(1179), 1,
      anon_sym_LPAREN,
    ACTIONS(1182), 1,
      anon_sym_TILDE,
    ACTIONS(1185), 1,
      anon_sym_RBRACK,
    STATE(632), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1187), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(618), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [32787] = 11,
    ACTIONS(1087), 1,
      sym_identifier,
    ACTIONS(1089), 1,
      anon_sym_COMMA,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1099), 1,
      anon_sym_RBRACK,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    STATE(632), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(624), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [32825] = 6,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1027), 1,
      anon_sym_PIPE_PIPE,
    STATE(168), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32853] = 6,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1027), 1,
      anon_sym_PIPE_PIPE,
    STATE(168), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32881] = 5,
    ACTIONS(1171), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(384), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [32907] = 5,
    ACTIONS(1171), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(386), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(388), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [32933] = 11,
    ACTIONS(1087), 1,
      sym_identifier,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1194), 1,
      anon_sym_COMMA,
    ACTIONS(1196), 1,
      anon_sym_RBRACK,
    STATE(632), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(618), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [32971] = 6,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1027), 1,
      anon_sym_PIPE_PIPE,
    STATE(303), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1198), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32999] = 5,
    ACTIONS(1171), 1,
      anon_sym_DOT,
    STATE(622), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(397), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(399), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [33025] = 6,
    ACTIONS(1058), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1060), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1202), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1200), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1056), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33053] = 5,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1027), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1204), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33078] = 8,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1206), 1,
      anon_sym_COMMA,
    STATE(969), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1208), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33109] = 5,
    ACTIONS(1025), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1027), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1210), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1023), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33134] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(442), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(444), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33155] = 9,
    ACTIONS(1093), 1,
      anon_sym_DOT,
    ACTIONS(1097), 1,
      anon_sym_AT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    STATE(639), 1,
      sym__args,
    STATE(681), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1212), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(1214), 3,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [33188] = 8,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1218), 1,
      anon_sym_COMMA,
    STATE(956), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1220), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33219] = 8,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1218), 1,
      anon_sym_COMMA,
    STATE(904), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1222), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33250] = 8,
    ACTIONS(1083), 1,
      anon_sym_case,
    ACTIONS(1085), 1,
      anon_sym_otherwise,
    ACTIONS(1226), 1,
      anon_sym_end,
    STATE(1222), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(679), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(793), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1224), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [33281] = 8,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1218), 1,
      anon_sym_COMMA,
    STATE(943), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1228), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33312] = 8,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1218), 1,
      anon_sym_COMMA,
    STATE(957), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1220), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33343] = 9,
    ACTIONS(1093), 1,
      anon_sym_DOT,
    ACTIONS(1097), 1,
      anon_sym_AT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    STATE(639), 1,
      sym__args,
    STATE(681), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1185), 3,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_RBRACK,
    ACTIONS(1230), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [33376] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(430), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(432), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33397] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(446), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(448), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33418] = 4,
    ACTIONS(1234), 1,
      anon_sym_DOT,
    STATE(592), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1232), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [33441] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(424), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(426), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33462] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(420), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(422), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33483] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(438), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(440), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33504] = 12,
    ACTIONS(663), 1,
      sym__single_quote_string_start,
    ACTIONS(665), 1,
      sym__double_quote_string_start,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1236), 1,
      sym_identifier,
    ACTIONS(1238), 1,
      sym_number,
    STATE(876), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    STATE(1177), 1,
      sym_string,
    STATE(1179), 1,
      sym_parfor_options,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
  [33543] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1240), 1,
      sym_identifier,
    ACTIONS(1242), 1,
      anon_sym_end,
    ACTIONS(1244), 1,
      anon_sym_function,
    STATE(772), 1,
      sym__function_definition_with_end,
    STATE(1063), 1,
      sym_function_output,
    STATE(1207), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1246), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(651), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33577] = 8,
    ACTIONS(1248), 1,
      anon_sym_SEMI,
    ACTIONS(1250), 1,
      anon_sym_end,
    ACTIONS(1252), 1,
      anon_sym_properties,
    ACTIONS(1254), 1,
      anon_sym_methods,
    ACTIONS(1256), 1,
      anon_sym_events,
    ACTIONS(1258), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(655), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33607] = 6,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1260), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33633] = 8,
    ACTIONS(1252), 1,
      anon_sym_properties,
    ACTIONS(1254), 1,
      anon_sym_methods,
    ACTIONS(1256), 1,
      anon_sym_events,
    ACTIONS(1258), 1,
      anon_sym_enumeration,
    ACTIONS(1262), 1,
      anon_sym_SEMI,
    ACTIONS(1264), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(658), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33663] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1240), 1,
      sym_identifier,
    ACTIONS(1244), 1,
      anon_sym_function,
    ACTIONS(1266), 1,
      anon_sym_end,
    STATE(772), 1,
      sym__function_definition_with_end,
    STATE(1063), 1,
      sym_function_output,
    STATE(1207), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1246), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(667), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33697] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1240), 1,
      sym_identifier,
    ACTIONS(1244), 1,
      anon_sym_function,
    ACTIONS(1266), 1,
      anon_sym_end,
    STATE(772), 1,
      sym__function_definition_with_end,
    STATE(1063), 1,
      sym_function_output,
    STATE(1207), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1246), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(668), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33731] = 9,
    ACTIONS(1111), 1,
      anon_sym_DOT,
    ACTIONS(1115), 1,
      anon_sym_LBRACE,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(641), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(706), 1,
      sym_validation_functions,
    STATE(870), 1,
      sym_default_value,
    STATE(1077), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1268), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [33763] = 8,
    ACTIONS(1250), 1,
      anon_sym_end,
    ACTIONS(1252), 1,
      anon_sym_properties,
    ACTIONS(1254), 1,
      anon_sym_methods,
    ACTIONS(1256), 1,
      anon_sym_events,
    ACTIONS(1258), 1,
      anon_sym_enumeration,
    ACTIONS(1262), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(658), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33793] = 6,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1270), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33819] = 8,
    ACTIONS(1252), 1,
      anon_sym_properties,
    ACTIONS(1254), 1,
      anon_sym_methods,
    ACTIONS(1256), 1,
      anon_sym_events,
    ACTIONS(1258), 1,
      anon_sym_enumeration,
    ACTIONS(1262), 1,
      anon_sym_SEMI,
    ACTIONS(1272), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(658), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33849] = 8,
    ACTIONS(1252), 1,
      anon_sym_properties,
    ACTIONS(1254), 1,
      anon_sym_methods,
    ACTIONS(1256), 1,
      anon_sym_events,
    ACTIONS(1258), 1,
      anon_sym_enumeration,
    ACTIONS(1274), 1,
      anon_sym_SEMI,
    ACTIONS(1276), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(653), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33879] = 10,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1278), 1,
      sym_identifier,
    ACTIONS(1280), 1,
      anon_sym_RBRACK,
    STATE(595), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(619), 2,
      sym_field_expression,
      sym_ignored_argument,
  [33913] = 8,
    ACTIONS(1282), 1,
      anon_sym_SEMI,
    ACTIONS(1285), 1,
      anon_sym_end,
    ACTIONS(1287), 1,
      anon_sym_properties,
    ACTIONS(1290), 1,
      anon_sym_methods,
    ACTIONS(1293), 1,
      anon_sym_events,
    ACTIONS(1296), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(658), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33943] = 10,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1299), 1,
      sym_identifier,
    ACTIONS(1301), 1,
      anon_sym_RBRACK,
    STATE(638), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(725), 2,
      sym_field_expression,
      sym_ignored_argument,
  [33977] = 7,
    ACTIONS(1097), 1,
      anon_sym_AT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    STATE(639), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(405), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(407), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [34005] = 9,
    ACTIONS(1111), 1,
      anon_sym_DOT,
    ACTIONS(1115), 1,
      anon_sym_LBRACE,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(641), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(704), 1,
      sym_validation_functions,
    STATE(847), 1,
      sym_default_value,
    STATE(1075), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1303), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34037] = 9,
    ACTIONS(1115), 1,
      anon_sym_LBRACE,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    ACTIONS(1305), 1,
      sym_identifier,
    STATE(677), 1,
      sym_property_name,
    STATE(704), 1,
      sym_validation_functions,
    STATE(847), 1,
      sym_default_value,
    STATE(1075), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1303), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34069] = 8,
    ACTIONS(1252), 1,
      anon_sym_properties,
    ACTIONS(1254), 1,
      anon_sym_methods,
    ACTIONS(1256), 1,
      anon_sym_events,
    ACTIONS(1258), 1,
      anon_sym_enumeration,
    ACTIONS(1307), 1,
      anon_sym_SEMI,
    ACTIONS(1309), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(649), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34099] = 8,
    ACTIONS(1252), 1,
      anon_sym_properties,
    ACTIONS(1254), 1,
      anon_sym_methods,
    ACTIONS(1256), 1,
      anon_sym_events,
    ACTIONS(1258), 1,
      anon_sym_enumeration,
    ACTIONS(1311), 1,
      anon_sym_SEMI,
    ACTIONS(1313), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(665), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34129] = 8,
    ACTIONS(1252), 1,
      anon_sym_properties,
    ACTIONS(1254), 1,
      anon_sym_methods,
    ACTIONS(1256), 1,
      anon_sym_events,
    ACTIONS(1258), 1,
      anon_sym_enumeration,
    ACTIONS(1262), 1,
      anon_sym_SEMI,
    ACTIONS(1309), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(658), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34159] = 10,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1196), 1,
      anon_sym_RBRACK,
    ACTIONS(1299), 1,
      sym_identifier,
    STATE(638), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(725), 2,
      sym_field_expression,
      sym_ignored_argument,
  [34193] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1240), 1,
      sym_identifier,
    ACTIONS(1244), 1,
      anon_sym_function,
    ACTIONS(1315), 1,
      anon_sym_end,
    STATE(772), 1,
      sym__function_definition_with_end,
    STATE(1063), 1,
      sym_function_output,
    STATE(1207), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1246), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(668), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [34227] = 10,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1320), 1,
      anon_sym_end,
    ACTIONS(1322), 1,
      anon_sym_function,
    ACTIONS(1328), 1,
      sym__multioutput_variable_start,
    STATE(772), 1,
      sym__function_definition_with_end,
    STATE(1063), 1,
      sym_function_output,
    STATE(1207), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1325), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(668), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [34261] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1331), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [34278] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1333), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [34295] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(434), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(436), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
  [34314] = 9,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1299), 1,
      sym_identifier,
    STATE(638), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(725), 2,
      sym_field_expression,
      sym_ignored_argument,
  [34345] = 6,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(870), 1,
      sym_default_value,
    STATE(1077), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1335), 3,
      anon_sym_vector,
      anon_sym_matrix,
      anon_sym_scalar,
    ACTIONS(1268), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34370] = 6,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1337), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34395] = 5,
    ACTIONS(1339), 1,
      anon_sym_DOT,
    STATE(675), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(413), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(418), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [34417] = 6,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1342), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34441] = 7,
    ACTIONS(1115), 1,
      anon_sym_LBRACE,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(706), 1,
      sym_validation_functions,
    STATE(870), 1,
      sym_default_value,
    STATE(1077), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1268), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34467] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(609), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [34483] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(679), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(600), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
    ACTIONS(1344), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34503] = 6,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1347), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34527] = 5,
    ACTIONS(1093), 1,
      anon_sym_DOT,
    STATE(675), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(409), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(411), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [34549] = 6,
    ACTIONS(568), 1,
      anon_sym_COMMA,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34573] = 7,
    ACTIONS(1115), 1,
      anon_sym_LBRACE,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(704), 1,
      sym_validation_functions,
    STATE(847), 1,
      sym_default_value,
    STATE(1075), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1303), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34599] = 6,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1349), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34623] = 6,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1351), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34647] = 6,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    ACTIONS(1357), 1,
      anon_sym_EQ,
    STATE(815), 1,
      sym__end_of_line,
    STATE(874), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1353), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34670] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(609), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(617), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [34687] = 5,
    ACTIONS(1068), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1070), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1062), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1064), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34708] = 5,
    ACTIONS(1361), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1363), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(978), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1359), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34729] = 6,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    ACTIONS(1357), 1,
      anon_sym_EQ,
    STATE(23), 1,
      sym__end_of_line,
    STATE(836), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1365), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34752] = 5,
    ACTIONS(1049), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1051), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1038), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1040), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34773] = 6,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    ACTIONS(1357), 1,
      anon_sym_EQ,
    STATE(31), 1,
      sym__end_of_line,
    STATE(859), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34796] = 5,
    ACTIONS(1371), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1373), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1009), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1369), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34817] = 6,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    ACTIONS(1357), 1,
      anon_sym_EQ,
    STATE(45), 1,
      sym__end_of_line,
    STATE(830), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1375), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34840] = 5,
    ACTIONS(1379), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1381), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(466), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1377), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34861] = 6,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    ACTIONS(1357), 1,
      anon_sym_EQ,
    STATE(61), 1,
      sym__end_of_line,
    STATE(888), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1383), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34884] = 6,
    ACTIONS(1385), 1,
      sym_identifier,
    ACTIONS(1387), 1,
      anon_sym_TILDE,
    ACTIONS(1389), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(612), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(728), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [34906] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(57), 1,
      sym__end_of_line,
    STATE(844), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1391), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34926] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(771), 1,
      sym__end_of_line,
    STATE(856), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1393), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34946] = 5,
    ACTIONS(1397), 1,
      anon_sym_LT,
    STATE(656), 1,
      sym__end_of_line,
    STATE(879), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1395), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34966] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(38), 1,
      sym__end_of_line,
    STATE(839), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1399), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34986] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(28), 1,
      sym__end_of_line,
    STATE(835), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1401), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35006] = 8,
    ACTIONS(1097), 1,
      anon_sym_AT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    ACTIONS(1403), 1,
      anon_sym_COMMA,
    ACTIONS(1405), 1,
      anon_sym_RBRACE,
    STATE(639), 1,
      sym__args,
    STATE(1011), 1,
      aux_sym_validation_functions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [35032] = 5,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(870), 1,
      sym_default_value,
    STATE(1077), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1268), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35052] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1407), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [35066] = 5,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(850), 1,
      sym_default_value,
    STATE(1047), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1409), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35086] = 4,
    ACTIONS(1413), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1411), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1415), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35104] = 4,
    ACTIONS(1419), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1417), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1421), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35122] = 4,
    ACTIONS(1425), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1427), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35140] = 6,
    ACTIONS(1385), 1,
      sym_identifier,
    ACTIONS(1387), 1,
      anon_sym_TILDE,
    ACTIONS(1429), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(612), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(726), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35162] = 7,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1431), 1,
      sym_identifier,
    STATE(778), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
  [35186] = 4,
    ACTIONS(1435), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1433), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1437), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35204] = 4,
    ACTIONS(1441), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1439), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1443), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35222] = 4,
    ACTIONS(1447), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1445), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1449), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35240] = 4,
    ACTIONS(1453), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1455), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35258] = 4,
    ACTIONS(1459), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1457), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1461), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35276] = 4,
    ACTIONS(1465), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1463), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1467), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35294] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(56), 1,
      sym__end_of_line,
    STATE(867), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35314] = 4,
    ACTIONS(1473), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1471), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1475), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35332] = 4,
    ACTIONS(1479), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1477), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1481), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35350] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(68), 1,
      sym__end_of_line,
    STATE(891), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1483), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35370] = 5,
    ACTIONS(1397), 1,
      anon_sym_LT,
    STATE(664), 1,
      sym__end_of_line,
    STATE(893), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1485), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35390] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(21), 1,
      sym__end_of_line,
    STATE(825), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1487), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35410] = 6,
    ACTIONS(1385), 1,
      sym_identifier,
    ACTIONS(1387), 1,
      anon_sym_TILDE,
    ACTIONS(1489), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(612), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(733), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35432] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1230), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(1185), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [35448] = 6,
    ACTIONS(1385), 1,
      sym_identifier,
    ACTIONS(1387), 1,
      anon_sym_TILDE,
    ACTIONS(1491), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(612), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(737), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35470] = 6,
    ACTIONS(1385), 1,
      sym_identifier,
    ACTIONS(1387), 1,
      anon_sym_TILDE,
    ACTIONS(1493), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(612), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(742), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35492] = 6,
    ACTIONS(1385), 1,
      sym_identifier,
    ACTIONS(1387), 1,
      anon_sym_TILDE,
    ACTIONS(1493), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(612), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(737), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35514] = 4,
    ACTIONS(1495), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(16), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1497), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35532] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1499), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [35546] = 6,
    ACTIONS(1501), 1,
      sym_identifier,
    ACTIONS(1503), 1,
      anon_sym_LPAREN,
    STATE(954), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(192), 2,
      sym_indirect_access,
      sym_function_call,
  [35568] = 6,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1505), 1,
      sym_identifier,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(660), 2,
      sym_indirect_access,
      sym_function_call,
  [35590] = 6,
    ACTIONS(1385), 1,
      sym_identifier,
    ACTIONS(1387), 1,
      anon_sym_TILDE,
    ACTIONS(1507), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(612), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(737), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35612] = 7,
    ACTIONS(1190), 1,
      anon_sym_LPAREN,
    ACTIONS(1509), 1,
      sym_identifier,
    STATE(703), 1,
      sym_function_call,
    STATE(951), 1,
      sym_indirect_access,
    STATE(971), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
  [35636] = 5,
    ACTIONS(1117), 1,
      anon_sym_EQ,
    STATE(847), 1,
      sym_default_value,
    STATE(1075), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1303), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35656] = 5,
    ACTIONS(1513), 1,
      anon_sym_LPAREN,
    STATE(710), 1,
      sym__end_of_line,
    STATE(832), 1,
      sym__argument_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1511), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35676] = 6,
    ACTIONS(1515), 1,
      sym_identifier,
    ACTIONS(1518), 1,
      anon_sym_TILDE,
    ACTIONS(1521), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(612), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(737), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35698] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(27), 1,
      sym__end_of_line,
    STATE(838), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1523), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35718] = 4,
    ACTIONS(1111), 1,
      anon_sym_DOT,
    STATE(641), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1525), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [35736] = 6,
    ACTIONS(1527), 1,
      sym_identifier,
    ACTIONS(1529), 1,
      anon_sym_LPAREN,
    STATE(978), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(372), 2,
      sym_indirect_access,
      sym_function_call,
  [35758] = 5,
    ACTIONS(1533), 1,
      anon_sym_LPAREN,
    STATE(697), 1,
      sym__end_of_line,
    STATE(864), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1531), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35778] = 6,
    ACTIONS(1385), 1,
      sym_identifier,
    ACTIONS(1387), 1,
      anon_sym_TILDE,
    ACTIONS(1535), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(612), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(737), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35800] = 5,
    ACTIONS(1533), 1,
      anon_sym_LPAREN,
    STATE(646), 1,
      sym__end_of_line,
    STATE(875), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1537), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35820] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(764), 1,
      sym__end_of_line,
    STATE(886), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1539), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35840] = 5,
    ACTIONS(1533), 1,
      anon_sym_LPAREN,
    STATE(887), 1,
      sym_attributes,
    STATE(1038), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1541), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35860] = 5,
    ACTIONS(1533), 1,
      anon_sym_LPAREN,
    STATE(826), 1,
      sym_attributes,
    STATE(906), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1543), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35880] = 6,
    ACTIONS(1545), 1,
      sym_identifier,
    ACTIONS(1547), 1,
      anon_sym_LPAREN,
    STATE(987), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(261), 2,
      sym_indirect_access,
      sym_function_call,
  [35902] = 6,
    ACTIONS(1549), 1,
      sym_identifier,
    ACTIONS(1551), 1,
      anon_sym_LPAREN,
    STATE(996), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(661), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_indirect_access,
      sym_function_call,
  [35924] = 5,
    ACTIONS(1355), 1,
      anon_sym_LPAREN,
    STATE(62), 1,
      sym__end_of_line,
    STATE(889), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1553), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35944] = 4,
    ACTIONS(1557), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1555), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1559), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35962] = 5,
    ACTIONS(627), 1,
      aux_sym_matrix_token1,
    ACTIONS(1137), 1,
      sym__entry_delimiter,
    STATE(779), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(625), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [35981] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1561), 1,
      sym_identifier,
    STATE(1065), 1,
      sym_function_output,
    STATE(1207), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1563), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36002] = 4,
    ACTIONS(1567), 1,
      sym_command_argument,
    STATE(780), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1565), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36019] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1569), 1,
      sym_identifier,
    STATE(1042), 1,
      sym_function_output,
    STATE(1207), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1571), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36040] = 4,
    ACTIONS(191), 1,
      ts_builtin_sym_end,
    ACTIONS(195), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1433), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36057] = 4,
    ACTIONS(1573), 1,
      ts_builtin_sym_end,
    ACTIONS(1575), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1555), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36074] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1577), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1579), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36089] = 4,
    ACTIONS(1581), 1,
      ts_builtin_sym_end,
    ACTIONS(1583), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1439), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36106] = 5,
    ACTIONS(1157), 1,
      aux_sym_matrix_token1,
    ACTIONS(1159), 1,
      sym__entry_delimiter,
    STATE(751), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1155), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [36125] = 5,
    ACTIONS(627), 1,
      aux_sym_matrix_token1,
    ACTIONS(1137), 1,
      sym__entry_delimiter,
    STATE(777), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(625), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [36144] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1427), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36159] = 4,
    ACTIONS(1585), 1,
      sym_identifier,
    STATE(762), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1588), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36176] = 4,
    ACTIONS(197), 1,
      ts_builtin_sym_end,
    ACTIONS(201), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1445), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36193] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1590), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1592), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36208] = 4,
    ACTIONS(1596), 1,
      anon_sym_AMP,
    STATE(765), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1594), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36225] = 4,
    ACTIONS(1601), 1,
      anon_sym_AMP,
    STATE(765), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1599), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36242] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1603), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36255] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1605), 1,
      sym_identifier,
    STATE(1012), 1,
      sym_function_output,
    STATE(1207), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1607), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36276] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1609), 1,
      sym_identifier,
    STATE(1045), 1,
      sym_function_output,
    STATE(1207), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36297] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1613), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36310] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1615), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1617), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36325] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1619), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1621), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36340] = 6,
    ACTIONS(1623), 1,
      anon_sym_end,
    ACTIONS(1625), 1,
      anon_sym_case,
    ACTIONS(1627), 1,
      anon_sym_otherwise,
    STATE(1222), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(837), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [36361] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1433), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1437), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36376] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1629), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36389] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1631), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36402] = 5,
    ACTIONS(623), 1,
      aux_sym_matrix_token1,
    ACTIONS(1633), 1,
      sym__entry_delimiter,
    STATE(779), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(621), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [36421] = 6,
    ACTIONS(1097), 1,
      anon_sym_AT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    STATE(639), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1635), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [36442] = 5,
    ACTIONS(1202), 1,
      aux_sym_matrix_token1,
    ACTIONS(1637), 1,
      sym__entry_delimiter,
    STATE(779), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1200), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [36461] = 4,
    ACTIONS(1642), 1,
      sym_command_argument,
    STATE(799), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1640), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36478] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1439), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1443), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36493] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1644), 1,
      anon_sym_elseif,
    ACTIONS(1646), 1,
      anon_sym_end,
    STATE(1156), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(890), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36514] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1644), 1,
      anon_sym_elseif,
    ACTIONS(1648), 1,
      anon_sym_end,
    STATE(1239), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(782), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36535] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1644), 1,
      anon_sym_elseif,
    ACTIONS(1646), 1,
      anon_sym_end,
    STATE(1156), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(822), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36556] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1644), 1,
      anon_sym_elseif,
    ACTIONS(1648), 1,
      anon_sym_end,
    STATE(1239), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(890), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36577] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1650), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1652), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36592] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1654), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1656), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36607] = 4,
    ACTIONS(1658), 1,
      sym_identifier,
    STATE(820), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36624] = 4,
    ACTIONS(1662), 1,
      ts_builtin_sym_end,
    ACTIONS(1664), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36641] = 4,
    ACTIONS(1666), 1,
      ts_builtin_sym_end,
    ACTIONS(1668), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1457), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36658] = 4,
    ACTIONS(1670), 1,
      sym_identifier,
    STATE(762), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1672), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36675] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1455), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36690] = 6,
    ACTIONS(1625), 1,
      anon_sym_case,
    ACTIONS(1627), 1,
      anon_sym_otherwise,
    ACTIONS(1674), 1,
      anon_sym_end,
    STATE(1213), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(837), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [36711] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1676), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36724] = 4,
    ACTIONS(155), 1,
      ts_builtin_sym_end,
    ACTIONS(159), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1411), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36741] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1457), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1461), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36756] = 4,
    ACTIONS(1678), 1,
      ts_builtin_sym_end,
    ACTIONS(1680), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1471), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36773] = 4,
    ACTIONS(1682), 1,
      sym_identifier,
    STATE(791), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1684), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36790] = 4,
    ACTIONS(1688), 1,
      sym_command_argument,
    STATE(799), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1686), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36807] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1463), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1467), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36822] = 4,
    ACTIONS(209), 1,
      ts_builtin_sym_end,
    ACTIONS(213), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1463), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36839] = 4,
    ACTIONS(1601), 1,
      anon_sym_AMP,
    STATE(766), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1691), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36856] = 4,
    ACTIONS(1693), 1,
      ts_builtin_sym_end,
    ACTIONS(1695), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1477), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36873] = 4,
    ACTIONS(167), 1,
      ts_builtin_sym_end,
    ACTIONS(171), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1417), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36890] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1697), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36903] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1471), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1475), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36918] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1699), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36931] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1701), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36944] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36957] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1705), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1707), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36972] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1477), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1481), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36987] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(17), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1709), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37002] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1711), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1713), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37017] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1555), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1559), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37032] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1715), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1717), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37047] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1719), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37060] = 4,
    ACTIONS(173), 1,
      ts_builtin_sym_end,
    ACTIONS(177), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37077] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1721), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37090] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1723), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1725), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37105] = 4,
    ACTIONS(1670), 1,
      sym_identifier,
    STATE(762), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1727), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37122] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1729), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37135] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1644), 1,
      anon_sym_elseif,
    ACTIONS(1731), 1,
      anon_sym_end,
    STATE(1231), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(890), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [37156] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1735), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1226), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37176] = 4,
    ACTIONS(1737), 1,
      sym__double_quote_string_end,
    STATE(871), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1739), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37192] = 3,
    STATE(41), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1741), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37206] = 3,
    STATE(932), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1743), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37220] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1745), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LF,
      anon_sym_CR,
  [37232] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1594), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [37244] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1747), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1186), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37264] = 3,
    STATE(59), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1749), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37278] = 4,
    ACTIONS(1751), 1,
      sym__single_quote_string_end,
    STATE(831), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1753), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37294] = 3,
    STATE(724), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1756), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37308] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1758), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LF,
      anon_sym_CR,
  [37320] = 4,
    ACTIONS(1760), 1,
      sym__single_quote_string_end,
    STATE(841), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1762), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37336] = 3,
    STATE(35), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1764), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37350] = 3,
    STATE(29), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1766), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37364] = 4,
    ACTIONS(1770), 1,
      anon_sym_case,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1768), 2,
      anon_sym_end,
      anon_sym_otherwise,
    STATE(837), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [37380] = 3,
    STATE(33), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1773), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37394] = 3,
    STATE(24), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1775), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37408] = 3,
    STATE(1075), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1303), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37422] = 4,
    ACTIONS(1777), 1,
      sym__single_quote_string_end,
    STATE(831), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1779), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37438] = 4,
    ACTIONS(1777), 1,
      sym__double_quote_string_end,
    STATE(871), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1739), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37454] = 3,
    STATE(168), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37468] = 3,
    STATE(49), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1781), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37482] = 4,
    ACTIONS(1783), 1,
      sym__single_quote_string_end,
    STATE(853), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1785), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37498] = 4,
    ACTIONS(1783), 1,
      sym__double_quote_string_end,
    STATE(854), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1787), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37514] = 3,
    STATE(1077), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1268), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37528] = 3,
    STATE(1139), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1789), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37542] = 3,
    STATE(303), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1198), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37556] = 3,
    STATE(1070), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1791), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37570] = 3,
    STATE(173), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1793), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37584] = 3,
    STATE(314), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1795), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37598] = 4,
    ACTIONS(1797), 1,
      sym__single_quote_string_end,
    STATE(831), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1779), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37614] = 4,
    ACTIONS(1797), 1,
      sym__double_quote_string_end,
    STATE(871), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1739), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37630] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1799), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1172), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37650] = 3,
    STATE(786), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1801), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37664] = 3,
    ACTIONS(1805), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1803), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37678] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1807), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1209), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37698] = 3,
    STATE(44), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1809), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37712] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1202), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1200), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37726] = 3,
    STATE(1140), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1811), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37740] = 4,
    ACTIONS(1813), 1,
      sym__single_quote_string_end,
    STATE(868), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1815), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37756] = 4,
    ACTIONS(1737), 1,
      sym__single_quote_string_end,
    STATE(831), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1779), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37772] = 3,
    STATE(727), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1817), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37786] = 4,
    ACTIONS(1760), 1,
      sym__double_quote_string_end,
    STATE(842), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1819), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37802] = 5,
    ACTIONS(1821), 1,
      anon_sym_SEMI,
    ACTIONS(1824), 1,
      aux_sym_matrix_token1,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1827), 2,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37820] = 3,
    STATE(51), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1829), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37834] = 4,
    ACTIONS(1831), 1,
      sym__single_quote_string_end,
    STATE(831), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1779), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37850] = 4,
    ACTIONS(1831), 1,
      sym__double_quote_string_end,
    STATE(871), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1739), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37866] = 3,
    STATE(1047), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1409), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37880] = 4,
    ACTIONS(1751), 1,
      sym__double_quote_string_end,
    STATE(871), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1833), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37896] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1836), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1168), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37916] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1838), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1164), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37936] = 3,
    STATE(787), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1840), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37950] = 3,
    STATE(650), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1842), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37964] = 6,
    ACTIONS(1097), 1,
      anon_sym_AT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    ACTIONS(1844), 1,
      anon_sym_RPAREN,
    STATE(639), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37984] = 4,
    ACTIONS(1846), 1,
      sym__single_quote_string_end,
    STATE(863), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1848), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38000] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1850), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1182), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38020] = 3,
    STATE(647), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1852), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38034] = 4,
    ACTIONS(1846), 1,
      sym__double_quote_string_end,
    STATE(824), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1854), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38050] = 3,
    STATE(168), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1192), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38064] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1856), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1191), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38084] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1858), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1196), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38104] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1860), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1248), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38124] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1862), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1212), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38144] = 3,
    STATE(757), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1864), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38158] = 3,
    STATE(1068), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1866), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38172] = 3,
    STATE(63), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1868), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38186] = 3,
    STATE(65), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1870), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38200] = 5,
    ACTIONS(1872), 1,
      anon_sym_elseif,
    ACTIONS(1875), 1,
      anon_sym_else,
    ACTIONS(1877), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(890), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [38218] = 3,
    STATE(69), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1879), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38232] = 3,
    STATE(173), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1793), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38246] = 3,
    STATE(663), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1881), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38260] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1883), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1228), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38280] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1885), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1230), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38300] = 6,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1887), 1,
      anon_sym_RPAREN,
    STATE(1027), 1,
      sym_ignored_argument,
    STATE(1237), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38320] = 4,
    ACTIONS(1813), 1,
      sym__double_quote_string_end,
    STATE(869), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1889), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38336] = 4,
    ACTIONS(187), 1,
      anon_sym_end,
    ACTIONS(1891), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(155), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38351] = 4,
    ACTIONS(1893), 1,
      anon_sym_COMMA,
    STATE(899), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1896), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [38366] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38377] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1457), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38388] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1463), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38399] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1898), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38410] = 4,
    ACTIONS(1218), 1,
      anon_sym_COMMA,
    STATE(899), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1900), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [38425] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(1906), 1,
      anon_sym_RBRACK,
    STATE(941), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38442] = 5,
    ACTIONS(1908), 1,
      sym_identifier,
    ACTIONS(1910), 1,
      anon_sym_end,
    STATE(861), 1,
      sym_enum,
    STATE(935), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38459] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1445), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38470] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1912), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38481] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1914), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38492] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1411), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38503] = 4,
    ACTIONS(1916), 1,
      anon_sym_end,
    ACTIONS(1918), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1662), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38518] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1920), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38529] = 4,
    ACTIONS(219), 1,
      anon_sym_end,
    ACTIONS(1922), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(209), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38544] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(1924), 1,
      anon_sym_RBRACE,
    STATE(944), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38561] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1926), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38572] = 4,
    ACTIONS(1928), 1,
      anon_sym_COMMA,
    STATE(916), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1931), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [38587] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1933), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38598] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1935), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38609] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1937), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38620] = 4,
    ACTIONS(193), 1,
      anon_sym_end,
    ACTIONS(1939), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(191), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38635] = 3,
    ACTIONS(1941), 1,
      aux_sym_matrix_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1827), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38648] = 4,
    ACTIONS(1943), 1,
      anon_sym_end,
    ACTIONS(1945), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1581), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38663] = 4,
    ACTIONS(336), 1,
      ts_builtin_sym_end,
    ACTIONS(1947), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(998), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [38678] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1949), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38689] = 4,
    ACTIONS(199), 1,
      anon_sym_end,
    ACTIONS(1951), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(197), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38704] = 4,
    ACTIONS(1206), 1,
      anon_sym_COMMA,
    STATE(970), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1208), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [38719] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1953), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38730] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1955), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38741] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1957), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38752] = 4,
    ACTIONS(215), 1,
      anon_sym_end,
    ACTIONS(1959), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(191), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38767] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1961), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38778] = 5,
    ACTIONS(1908), 1,
      sym_identifier,
    ACTIONS(1963), 1,
      anon_sym_end,
    STATE(861), 1,
      sym_enum,
    STATE(1002), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38795] = 4,
    ACTIONS(1967), 1,
      anon_sym_DOT,
    STATE(972), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1965), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [38810] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1969), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38821] = 5,
    ACTIONS(1908), 1,
      sym_identifier,
    ACTIONS(1963), 1,
      anon_sym_end,
    STATE(861), 1,
      sym_enum,
    STATE(1005), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38838] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1971), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38849] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1417), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38860] = 5,
    ACTIONS(1973), 1,
      anon_sym_LPAREN,
    ACTIONS(1975), 1,
      anon_sym_AT,
    ACTIONS(1977), 1,
      anon_sym_LBRACE,
    STATE(200), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38877] = 4,
    ACTIONS(157), 1,
      anon_sym_end,
    ACTIONS(1979), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(155), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38892] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38903] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(1981), 1,
      anon_sym_RBRACK,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38920] = 4,
    ACTIONS(1983), 1,
      anon_sym_end,
    ACTIONS(1985), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1693), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38935] = 4,
    ACTIONS(1218), 1,
      anon_sym_COMMA,
    STATE(899), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1987), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [38950] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(1989), 1,
      anon_sym_RBRACE,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38967] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1991), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38978] = 4,
    ACTIONS(203), 1,
      anon_sym_end,
    ACTIONS(1993), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(167), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38993] = 4,
    ACTIONS(1995), 1,
      anon_sym_end,
    ACTIONS(1997), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1581), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39008] = 4,
    ACTIONS(205), 1,
      anon_sym_end,
    ACTIONS(1999), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(173), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39023] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2001), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39034] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2003), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39045] = 5,
    ACTIONS(1097), 1,
      anon_sym_AT,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    STATE(639), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39062] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1471), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39073] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1477), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39084] = 5,
    ACTIONS(1973), 1,
      anon_sym_LPAREN,
    ACTIONS(1977), 1,
      anon_sym_LBRACE,
    ACTIONS(2005), 1,
      anon_sym_AT,
    STATE(198), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39101] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2007), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39112] = 4,
    ACTIONS(1218), 1,
      anon_sym_COMMA,
    STATE(899), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2009), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39127] = 4,
    ACTIONS(1218), 1,
      anon_sym_COMMA,
    STATE(899), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2009), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39142] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2011), 1,
      anon_sym_RBRACK,
    STATE(961), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39159] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2013), 1,
      anon_sym_RBRACE,
    STATE(1009), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39176] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2015), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39187] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2017), 1,
      anon_sym_RBRACK,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39204] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1439), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39215] = 4,
    ACTIONS(2019), 1,
      anon_sym_end,
    ACTIONS(2021), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1662), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39230] = 4,
    ACTIONS(1947), 1,
      anon_sym_function,
    ACTIONS(2023), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(998), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [39245] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2025), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39256] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2027), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39267] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2029), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39278] = 4,
    ACTIONS(2031), 1,
      anon_sym_end,
    ACTIONS(2033), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1693), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39293] = 4,
    ACTIONS(2035), 1,
      anon_sym_COMMA,
    STATE(916), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2037), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39308] = 4,
    ACTIONS(2039), 1,
      anon_sym_COMMA,
    STATE(916), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2037), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39323] = 5,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    ACTIONS(2041), 1,
      anon_sym_AT,
    STATE(631), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39340] = 4,
    ACTIONS(2045), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2043), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [39355] = 4,
    ACTIONS(217), 1,
      anon_sym_end,
    ACTIONS(2047), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(197), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39370] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2049), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39381] = 5,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39398] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2051), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39409] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2053), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39420] = 5,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    ACTIONS(980), 1,
      anon_sym_AT,
    STATE(414), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39437] = 4,
    ACTIONS(211), 1,
      anon_sym_end,
    ACTIONS(2055), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(209), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39452] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2057), 1,
      anon_sym_RBRACK,
    STATE(982), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39469] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2059), 1,
      anon_sym_RBRACE,
    STATE(983), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39486] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2061), 1,
      anon_sym_RBRACK,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39503] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2063), 1,
      anon_sym_RBRACE,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39520] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2065), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39531] = 5,
    ACTIONS(2067), 1,
      anon_sym_LPAREN,
    ACTIONS(2069), 1,
      anon_sym_AT,
    ACTIONS(2071), 1,
      anon_sym_LBRACE,
    STATE(354), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39548] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2073), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39559] = 5,
    ACTIONS(2067), 1,
      anon_sym_LPAREN,
    ACTIONS(2071), 1,
      anon_sym_LBRACE,
    ACTIONS(2075), 1,
      anon_sym_AT,
    STATE(362), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39576] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2077), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39587] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2079), 1,
      anon_sym_RBRACK,
    STATE(993), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39604] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2081), 1,
      anon_sym_RBRACE,
    STATE(994), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39621] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2083), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39632] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1555), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39643] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2085), 1,
      anon_sym_RBRACK,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39660] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2087), 1,
      anon_sym_RBRACE,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39677] = 5,
    ACTIONS(2089), 1,
      anon_sym_LPAREN,
    ACTIONS(2091), 1,
      anon_sym_AT,
    ACTIONS(2093), 1,
      anon_sym_LBRACE,
    STATE(95), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39694] = 5,
    ACTIONS(2089), 1,
      anon_sym_LPAREN,
    ACTIONS(2093), 1,
      anon_sym_LBRACE,
    ACTIONS(2095), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39711] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2097), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39722] = 4,
    ACTIONS(2099), 1,
      ts_builtin_sym_end,
    ACTIONS(2101), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(998), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [39737] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2104), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39748] = 4,
    ACTIONS(169), 1,
      anon_sym_end,
    ACTIONS(2106), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(167), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39763] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2108), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39774] = 5,
    ACTIONS(1908), 1,
      sym_identifier,
    ACTIONS(2110), 1,
      anon_sym_end,
    STATE(861), 1,
      sym_enum,
    STATE(1005), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39791] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2112), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39802] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2114), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39813] = 5,
    ACTIONS(2116), 1,
      sym_identifier,
    ACTIONS(2119), 1,
      anon_sym_end,
    STATE(861), 1,
      sym_enum,
    STATE(1005), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39830] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2121), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39841] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1433), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39852] = 4,
    ACTIONS(175), 1,
      anon_sym_end,
    ACTIONS(2123), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(173), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39867] = 5,
    ACTIONS(1902), 1,
      anon_sym_SEMI,
    ACTIONS(1904), 1,
      aux_sym_matrix_token1,
    ACTIONS(2125), 1,
      anon_sym_RBRACE,
    STATE(866), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39884] = 4,
    ACTIONS(2127), 1,
      anon_sym_COMMA,
    ACTIONS(2129), 1,
      anon_sym_RPAREN,
    STATE(1060), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39898] = 4,
    ACTIONS(1403), 1,
      anon_sym_COMMA,
    ACTIONS(2131), 1,
      anon_sym_RBRACE,
    STATE(1050), 1,
      aux_sym_validation_functions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39912] = 3,
    ACTIONS(2133), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2135), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [39924] = 3,
    ACTIONS(2137), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1666), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39936] = 3,
    ACTIONS(2139), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(209), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39948] = 3,
    ACTIONS(2141), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1581), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39960] = 3,
    ACTIONS(2143), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2145), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [39972] = 4,
    ACTIONS(2147), 1,
      anon_sym_COMMA,
    ACTIONS(2149), 1,
      anon_sym_RPAREN,
    STATE(1057), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39986] = 3,
    ACTIONS(2151), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(167), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39998] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1270), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40008] = 3,
    ACTIONS(2153), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(173), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40020] = 4,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(2155), 1,
      sym_number,
    STATE(1093), 1,
      sym_spread_operator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40034] = 4,
    ACTIONS(2157), 1,
      anon_sym_COMMA,
    ACTIONS(2159), 1,
      anon_sym_RPAREN,
    STATE(1023), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40048] = 4,
    ACTIONS(2157), 1,
      anon_sym_COMMA,
    ACTIONS(2161), 1,
      anon_sym_RPAREN,
    STATE(1058), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40062] = 4,
    ACTIONS(1095), 1,
      anon_sym_TILDE,
    ACTIONS(2163), 1,
      sym_identifier,
    STATE(1110), 1,
      sym_ignored_argument,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40076] = 4,
    ACTIONS(2165), 1,
      anon_sym_COMMA,
    ACTIONS(2167), 1,
      anon_sym_RPAREN,
    STATE(1055), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40090] = 4,
    ACTIONS(2169), 1,
      anon_sym_end,
    ACTIONS(2171), 1,
      anon_sym_catch,
    STATE(1245), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40104] = 4,
    ACTIONS(2165), 1,
      anon_sym_COMMA,
    ACTIONS(2173), 1,
      anon_sym_RPAREN,
    STATE(1025), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40118] = 3,
    ACTIONS(2175), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(155), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40130] = 3,
    ACTIONS(2177), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1678), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40142] = 3,
    ACTIONS(2181), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2179), 2,
      anon_sym_elseif,
      anon_sym_end,
  [40154] = 4,
    ACTIONS(2147), 1,
      anon_sym_COMMA,
    ACTIONS(2183), 1,
      anon_sym_RPAREN,
    STATE(1034), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40168] = 4,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    STATE(642), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40182] = 4,
    ACTIONS(1101), 1,
      anon_sym_LBRACE,
    ACTIONS(1216), 1,
      anon_sym_LPAREN,
    STATE(643), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40196] = 4,
    ACTIONS(2147), 1,
      anon_sym_COMMA,
    ACTIONS(2185), 1,
      anon_sym_RPAREN,
    STATE(1057), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40210] = 4,
    ACTIONS(2187), 1,
      anon_sym_COMMA,
    ACTIONS(2189), 1,
      anon_sym_RPAREN,
    STATE(1078), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40224] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
  [40234] = 4,
    ACTIONS(657), 1,
      anon_sym_COLON,
    ACTIONS(2193), 1,
      sym_number,
    STATE(1010), 1,
      sym_spread_operator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40248] = 4,
    ACTIONS(2195), 1,
      sym_identifier,
    ACTIONS(2197), 1,
      anon_sym_end,
    STATE(1074), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40262] = 3,
    ACTIONS(2199), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1693), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40274] = 4,
    ACTIONS(2171), 1,
      anon_sym_catch,
    ACTIONS(2201), 1,
      anon_sym_end,
    STATE(1157), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40288] = 3,
    ACTIONS(2203), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(197), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40300] = 3,
    ACTIONS(2205), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2207), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40312] = 4,
    ACTIONS(2209), 1,
      anon_sym_COMMA,
    ACTIONS(2212), 1,
      anon_sym_RPAREN,
    STATE(1043), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40326] = 3,
    ACTIONS(2216), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2214), 2,
      anon_sym_end,
      sym_identifier,
  [40338] = 3,
    ACTIONS(2218), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2220), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40350] = 4,
    ACTIONS(1973), 1,
      anon_sym_LPAREN,
    ACTIONS(1977), 1,
      anon_sym_LBRACE,
    STATE(202), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40364] = 3,
    ACTIONS(2224), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2222), 2,
      anon_sym_end,
      sym_identifier,
  [40376] = 4,
    ACTIONS(2187), 1,
      anon_sym_COMMA,
    ACTIONS(2226), 1,
      anon_sym_RPAREN,
    STATE(1035), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40390] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2228), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40400] = 4,
    ACTIONS(1635), 1,
      anon_sym_RBRACE,
    ACTIONS(2230), 1,
      anon_sym_COMMA,
    STATE(1050), 1,
      aux_sym_validation_functions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40414] = 3,
    ACTIONS(2233), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(191), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40426] = 4,
    ACTIONS(2235), 1,
      sym_identifier,
    ACTIONS(2237), 1,
      anon_sym_LPAREN,
    STATE(10), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40440] = 4,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(438), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40454] = 4,
    ACTIONS(851), 1,
      anon_sym_LPAREN,
    ACTIONS(859), 1,
      anon_sym_LBRACE,
    STATE(444), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40468] = 4,
    ACTIONS(2239), 1,
      anon_sym_COMMA,
    ACTIONS(2242), 1,
      anon_sym_RPAREN,
    STATE(1055), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40482] = 3,
    ACTIONS(111), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2244), 2,
      anon_sym_elseif,
      anon_sym_end,
  [40494] = 4,
    ACTIONS(2246), 1,
      anon_sym_COMMA,
    ACTIONS(2249), 1,
      anon_sym_RPAREN,
    STATE(1057), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40508] = 4,
    ACTIONS(2251), 1,
      anon_sym_COMMA,
    ACTIONS(2254), 1,
      anon_sym_RPAREN,
    STATE(1058), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40522] = 4,
    ACTIONS(1973), 1,
      anon_sym_LPAREN,
    ACTIONS(1977), 1,
      anon_sym_LBRACE,
    STATE(195), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40536] = 4,
    ACTIONS(2127), 1,
      anon_sym_COMMA,
    ACTIONS(2256), 1,
      anon_sym_RPAREN,
    STATE(1043), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40550] = 4,
    ACTIONS(2067), 1,
      anon_sym_LPAREN,
    ACTIONS(2071), 1,
      anon_sym_LBRACE,
    STATE(367), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40564] = 4,
    ACTIONS(2067), 1,
      anon_sym_LPAREN,
    ACTIONS(2071), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40578] = 3,
    ACTIONS(2258), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2260), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40590] = 3,
    ACTIONS(2262), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1573), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40602] = 3,
    ACTIONS(2264), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2266), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40614] = 4,
    ACTIONS(2089), 1,
      anon_sym_LPAREN,
    ACTIONS(2093), 1,
      anon_sym_LBRACE,
    STATE(90), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40628] = 4,
    ACTIONS(2089), 1,
      anon_sym_LPAREN,
    ACTIONS(2093), 1,
      anon_sym_LBRACE,
    STATE(89), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40642] = 4,
    ACTIONS(2195), 1,
      sym_identifier,
    ACTIONS(2268), 1,
      anon_sym_end,
    STATE(1069), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40656] = 4,
    ACTIONS(2195), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_end,
    STATE(1073), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40670] = 3,
    ACTIONS(2274), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2272), 2,
      anon_sym_end,
      sym_identifier,
  [40682] = 3,
    ACTIONS(2278), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2276), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [40694] = 4,
    ACTIONS(2147), 1,
      anon_sym_COMMA,
    ACTIONS(2280), 1,
      anon_sym_RPAREN,
    STATE(1017), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40708] = 4,
    ACTIONS(2282), 1,
      sym_identifier,
    ACTIONS(2285), 1,
      anon_sym_end,
    STATE(1073), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40722] = 4,
    ACTIONS(2195), 1,
      sym_identifier,
    ACTIONS(2268), 1,
      anon_sym_end,
    STATE(1073), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40736] = 3,
    ACTIONS(2289), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2287), 2,
      anon_sym_end,
      sym_identifier,
  [40748] = 3,
    ACTIONS(2291), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1662), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40760] = 3,
    ACTIONS(2295), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2293), 2,
      anon_sym_end,
      sym_identifier,
  [40772] = 4,
    ACTIONS(2297), 1,
      anon_sym_COMMA,
    ACTIONS(2300), 1,
      anon_sym_RPAREN,
    STATE(1078), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40786] = 4,
    ACTIONS(2302), 1,
      sym_identifier,
    ACTIONS(2304), 1,
      anon_sym_LPAREN,
    STATE(1210), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40800] = 3,
    ACTIONS(2235), 1,
      sym_identifier,
    STATE(10), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40811] = 3,
    ACTIONS(2306), 1,
      sym_identifier,
    ACTIONS(2308), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40822] = 3,
    ACTIONS(326), 1,
      anon_sym_end,
    ACTIONS(2310), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40833] = 3,
    ACTIONS(235), 1,
      anon_sym_end,
    ACTIONS(2312), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40844] = 3,
    ACTIONS(328), 1,
      anon_sym_end,
    ACTIONS(2314), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40855] = 3,
    ACTIONS(243), 1,
      anon_sym_end,
    ACTIONS(2316), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40866] = 3,
    ACTIONS(330), 1,
      anon_sym_end,
    ACTIONS(2318), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40877] = 3,
    ACTIONS(2320), 1,
      anon_sym_end,
    ACTIONS(2322), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40888] = 3,
    ACTIONS(334), 1,
      anon_sym_end,
    ACTIONS(2324), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40899] = 3,
    ACTIONS(2326), 1,
      anon_sym_end,
    ACTIONS(2328), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40910] = 3,
    ACTIONS(225), 1,
      anon_sym_end,
    ACTIONS(2330), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40921] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(191), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40930] = 3,
    ACTIONS(2332), 1,
      anon_sym_end,
    ACTIONS(2334), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40941] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2212), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [40950] = 3,
    ACTIONS(2306), 1,
      sym_identifier,
    ACTIONS(2336), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40961] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(173), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40970] = 3,
    ACTIONS(2338), 1,
      anon_sym_end,
    ACTIONS(2340), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40981] = 3,
    ACTIONS(2342), 1,
      sym_identifier,
    ACTIONS(2344), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40992] = 3,
    ACTIONS(2346), 1,
      sym_identifier,
    ACTIONS(2348), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41003] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1581), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41012] = 3,
    ACTIONS(2350), 1,
      sym_identifier,
    STATE(1072), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41023] = 3,
    ACTIONS(2352), 1,
      sym_identifier,
    ACTIONS(2354), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41034] = 3,
    ACTIONS(237), 1,
      anon_sym_end,
    ACTIONS(2356), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41045] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2249), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41054] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2358), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [41063] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1203), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41074] = 3,
    ACTIONS(2346), 1,
      sym_identifier,
    ACTIONS(2362), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41085] = 3,
    ACTIONS(2364), 1,
      anon_sym_end,
    ACTIONS(2366), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41096] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2254), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41105] = 3,
    ACTIONS(233), 1,
      anon_sym_end,
    ACTIONS(2368), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41116] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2242), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41125] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1059), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41136] = 3,
    ACTIONS(2372), 1,
      sym_identifier,
    ACTIONS(2374), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41147] = 3,
    ACTIONS(223), 1,
      anon_sym_end,
    ACTIONS(2376), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41158] = 3,
    ACTIONS(229), 1,
      anon_sym_end,
    ACTIONS(2378), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41169] = 3,
    ACTIONS(2380), 1,
      anon_sym_end,
    ACTIONS(2382), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41180] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1678), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41189] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1662), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41198] = 3,
    ACTIONS(2352), 1,
      sym_identifier,
    ACTIONS(2384), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41209] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1046), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41220] = 3,
    ACTIONS(2350), 1,
      sym_identifier,
    STATE(1103), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41231] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2386), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41240] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1573), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41249] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2388), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41258] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1693), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41267] = 3,
    ACTIONS(2390), 1,
      sym_identifier,
    ACTIONS(2392), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41278] = 3,
    ACTIONS(2394), 1,
      sym_identifier,
    ACTIONS(2396), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41289] = 3,
    ACTIONS(2398), 1,
      sym_identifier,
    ACTIONS(2400), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41300] = 3,
    ACTIONS(2342), 1,
      sym_identifier,
    ACTIONS(2402), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41311] = 3,
    ACTIONS(2390), 1,
      sym_identifier,
    ACTIONS(2404), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41322] = 3,
    ACTIONS(2394), 1,
      sym_identifier,
    ACTIONS(2406), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41333] = 3,
    ACTIONS(2398), 1,
      sym_identifier,
    ACTIONS(2408), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41344] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(209), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41353] = 3,
    ACTIONS(2350), 1,
      sym_identifier,
    STATE(1031), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41364] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1032), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41375] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1033), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41386] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2410), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41395] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2412), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [41404] = 3,
    ACTIONS(2414), 1,
      sym_identifier,
    ACTIONS(2416), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41415] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2285), 2,
      anon_sym_end,
      sym_identifier,
  [41424] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2119), 2,
      anon_sym_end,
      sym_identifier,
  [41433] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2418), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41442] = 3,
    ACTIONS(2420), 1,
      sym_identifier,
    STATE(802), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41453] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1666), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41462] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1053), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41473] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1054), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41484] = 3,
    ACTIONS(2420), 1,
      sym_identifier,
    STATE(828), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41495] = 3,
    ACTIONS(231), 1,
      anon_sym_end,
    ACTIONS(2422), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41506] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1061), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41517] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1062), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41528] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1066), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41539] = 3,
    ACTIONS(2370), 1,
      sym_identifier,
    STATE(1067), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41550] = 3,
    ACTIONS(2424), 1,
      sym_identifier,
    ACTIONS(2426), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41561] = 2,
    ACTIONS(2428), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41569] = 2,
    ACTIONS(2430), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41577] = 2,
    ACTIONS(2432), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41585] = 2,
    ACTIONS(1731), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41593] = 2,
    ACTIONS(2434), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41601] = 2,
    ACTIONS(2436), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41609] = 2,
    ACTIONS(2438), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41617] = 2,
    ACTIONS(2440), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41625] = 2,
    ACTIONS(2442), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41633] = 2,
    ACTIONS(2444), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41641] = 2,
    ACTIONS(2446), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41649] = 2,
    ACTIONS(2448), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41657] = 2,
    ACTIONS(2450), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41665] = 2,
    ACTIONS(2452), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41673] = 2,
    ACTIONS(2454), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41681] = 2,
    ACTIONS(2456), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41689] = 2,
    ACTIONS(2454), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41697] = 2,
    ACTIONS(2458), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41705] = 2,
    ACTIONS(2460), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41713] = 2,
    ACTIONS(2462), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41721] = 2,
    ACTIONS(2464), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41729] = 2,
    ACTIONS(2466), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41737] = 2,
    ACTIONS(2468), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41745] = 2,
    ACTIONS(2470), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41753] = 2,
    ACTIONS(1844), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41761] = 2,
    ACTIONS(2472), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41769] = 2,
    ACTIONS(2474), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41777] = 2,
    ACTIONS(2346), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41785] = 2,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41793] = 2,
    ACTIONS(2478), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41801] = 2,
    ACTIONS(2480), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41809] = 2,
    ACTIONS(2482), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41817] = 2,
    ACTIONS(2480), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41825] = 2,
    ACTIONS(2484), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41833] = 2,
    ACTIONS(2486), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41841] = 2,
    ACTIONS(2488), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41849] = 2,
    ACTIONS(2490), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41857] = 2,
    ACTIONS(2492), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41865] = 2,
    ACTIONS(2494), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41873] = 2,
    ACTIONS(2496), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41881] = 2,
    ACTIONS(2498), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41889] = 2,
    ACTIONS(2500), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41897] = 2,
    ACTIONS(2502), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41905] = 2,
    ACTIONS(2504), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41913] = 2,
    ACTIONS(2506), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41921] = 2,
    ACTIONS(2508), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41929] = 2,
    ACTIONS(2169), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41937] = 2,
    ACTIONS(2510), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41945] = 2,
    ACTIONS(2512), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41953] = 2,
    ACTIONS(2514), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41961] = 2,
    ACTIONS(2516), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41969] = 2,
    ACTIONS(1648), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41977] = 2,
    ACTIONS(2518), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41985] = 2,
    ACTIONS(2520), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41993] = 2,
    ACTIONS(2522), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42001] = 2,
    ACTIONS(2524), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42009] = 2,
    ACTIONS(2526), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42017] = 2,
    ACTIONS(2528), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42025] = 2,
    ACTIONS(2530), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42033] = 2,
    ACTIONS(2532), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42041] = 2,
    ACTIONS(2534), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42049] = 2,
    ACTIONS(2536), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42057] = 2,
    ACTIONS(2538), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42065] = 2,
    ACTIONS(2540), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42073] = 2,
    ACTIONS(2536), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42081] = 2,
    ACTIONS(2542), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42089] = 2,
    ACTIONS(2544), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42097] = 2,
    ACTIONS(2546), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42105] = 2,
    ACTIONS(2548), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42113] = 2,
    ACTIONS(1674), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42121] = 2,
    ACTIONS(2542), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42129] = 2,
    ACTIONS(2550), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42137] = 2,
    ACTIONS(2552), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42145] = 2,
    ACTIONS(2554), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42153] = 2,
    ACTIONS(2556), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42161] = 2,
    ACTIONS(2558), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42169] = 2,
    ACTIONS(2560), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42177] = 2,
    ACTIONS(2562), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42185] = 2,
    ACTIONS(2564), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42193] = 2,
    ACTIONS(2566), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42201] = 2,
    ACTIONS(2568), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42209] = 2,
    ACTIONS(2570), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42217] = 2,
    ACTIONS(2572), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42225] = 2,
    ACTIONS(2574), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42233] = 2,
    ACTIONS(2576), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42241] = 2,
    ACTIONS(2578), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42249] = 2,
    ACTIONS(1646), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42257] = 2,
    ACTIONS(2352), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42265] = 2,
    ACTIONS(2580), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42273] = 2,
    ACTIONS(2570), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42281] = 2,
    ACTIONS(1623), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42289] = 2,
    ACTIONS(2582), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42297] = 2,
    ACTIONS(2201), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42305] = 2,
    ACTIONS(2584), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42313] = 2,
    ACTIONS(2586), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42321] = 2,
    ACTIONS(2588), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(76)] = 0,
  [SMALL_STATE(77)] = 85,
  [SMALL_STATE(78)] = 174,
  [SMALL_STATE(79)] = 263,
  [SMALL_STATE(80)] = 348,
  [SMALL_STATE(81)] = 437,
  [SMALL_STATE(82)] = 511,
  [SMALL_STATE(83)] = 585,
  [SMALL_STATE(84)] = 659,
  [SMALL_STATE(85)] = 733,
  [SMALL_STATE(86)] = 807,
  [SMALL_STATE(87)] = 885,
  [SMALL_STATE(88)] = 959,
  [SMALL_STATE(89)] = 1033,
  [SMALL_STATE(90)] = 1102,
  [SMALL_STATE(91)] = 1171,
  [SMALL_STATE(92)] = 1254,
  [SMALL_STATE(93)] = 1333,
  [SMALL_STATE(94)] = 1402,
  [SMALL_STATE(95)] = 1485,
  [SMALL_STATE(96)] = 1554,
  [SMALL_STATE(97)] = 1623,
  [SMALL_STATE(98)] = 1702,
  [SMALL_STATE(99)] = 1771,
  [SMALL_STATE(100)] = 1840,
  [SMALL_STATE(101)] = 1923,
  [SMALL_STATE(102)] = 1992,
  [SMALL_STATE(103)] = 2060,
  [SMALL_STATE(104)] = 2128,
  [SMALL_STATE(105)] = 2202,
  [SMALL_STATE(106)] = 2272,
  [SMALL_STATE(107)] = 2344,
  [SMALL_STATE(108)] = 2412,
  [SMALL_STATE(109)] = 2482,
  [SMALL_STATE(110)] = 2552,
  [SMALL_STATE(111)] = 2620,
  [SMALL_STATE(112)] = 2690,
  [SMALL_STATE(113)] = 2760,
  [SMALL_STATE(114)] = 2828,
  [SMALL_STATE(115)] = 2896,
  [SMALL_STATE(116)] = 2964,
  [SMALL_STATE(117)] = 3032,
  [SMALL_STATE(118)] = 3100,
  [SMALL_STATE(119)] = 3168,
  [SMALL_STATE(120)] = 3236,
  [SMALL_STATE(121)] = 3308,
  [SMALL_STATE(122)] = 3378,
  [SMALL_STATE(123)] = 3448,
  [SMALL_STATE(124)] = 3524,
  [SMALL_STATE(125)] = 3598,
  [SMALL_STATE(126)] = 3668,
  [SMALL_STATE(127)] = 3736,
  [SMALL_STATE(128)] = 3804,
  [SMALL_STATE(129)] = 3876,
  [SMALL_STATE(130)] = 3950,
  [SMALL_STATE(131)] = 4024,
  [SMALL_STATE(132)] = 4098,
  [SMALL_STATE(133)] = 4170,
  [SMALL_STATE(134)] = 4240,
  [SMALL_STATE(135)] = 4312,
  [SMALL_STATE(136)] = 4386,
  [SMALL_STATE(137)] = 4460,
  [SMALL_STATE(138)] = 4530,
  [SMALL_STATE(139)] = 4604,
  [SMALL_STATE(140)] = 4674,
  [SMALL_STATE(141)] = 4744,
  [SMALL_STATE(142)] = 4818,
  [SMALL_STATE(143)] = 4892,
  [SMALL_STATE(144)] = 4964,
  [SMALL_STATE(145)] = 5034,
  [SMALL_STATE(146)] = 5108,
  [SMALL_STATE(147)] = 5182,
  [SMALL_STATE(148)] = 5252,
  [SMALL_STATE(149)] = 5323,
  [SMALL_STATE(150)] = 5392,
  [SMALL_STATE(151)] = 5459,
  [SMALL_STATE(152)] = 5530,
  [SMALL_STATE(153)] = 5589,
  [SMALL_STATE(154)] = 5648,
  [SMALL_STATE(155)] = 5707,
  [SMALL_STATE(156)] = 5766,
  [SMALL_STATE(157)] = 5825,
  [SMALL_STATE(158)] = 5879,
  [SMALL_STATE(159)] = 5936,
  [SMALL_STATE(160)] = 6041,
  [SMALL_STATE(161)] = 6095,
  [SMALL_STATE(162)] = 6192,
  [SMALL_STATE(163)] = 6291,
  [SMALL_STATE(164)] = 6390,
  [SMALL_STATE(165)] = 6489,
  [SMALL_STATE(166)] = 6541,
  [SMALL_STATE(167)] = 6641,
  [SMALL_STATE(168)] = 6741,
  [SMALL_STATE(169)] = 6793,
  [SMALL_STATE(170)] = 6845,
  [SMALL_STATE(171)] = 6897,
  [SMALL_STATE(172)] = 6997,
  [SMALL_STATE(173)] = 7097,
  [SMALL_STATE(174)] = 7149,
  [SMALL_STATE(175)] = 7249,
  [SMALL_STATE(176)] = 7349,
  [SMALL_STATE(177)] = 7449,
  [SMALL_STATE(178)] = 7549,
  [SMALL_STATE(179)] = 7649,
  [SMALL_STATE(180)] = 7749,
  [SMALL_STATE(181)] = 7849,
  [SMALL_STATE(182)] = 7949,
  [SMALL_STATE(183)] = 8049,
  [SMALL_STATE(184)] = 8149,
  [SMALL_STATE(185)] = 8249,
  [SMALL_STATE(186)] = 8349,
  [SMALL_STATE(187)] = 8449,
  [SMALL_STATE(188)] = 8549,
  [SMALL_STATE(189)] = 8649,
  [SMALL_STATE(190)] = 8708,
  [SMALL_STATE(191)] = 8771,
  [SMALL_STATE(192)] = 8830,
  [SMALL_STATE(193)] = 8883,
  [SMALL_STATE(194)] = 8946,
  [SMALL_STATE(195)] = 9009,
  [SMALL_STATE(196)] = 9053,
  [SMALL_STATE(197)] = 9147,
  [SMALL_STATE(198)] = 9241,
  [SMALL_STATE(199)] = 9285,
  [SMALL_STATE(200)] = 9379,
  [SMALL_STATE(201)] = 9423,
  [SMALL_STATE(202)] = 9517,
  [SMALL_STATE(203)] = 9561,
  [SMALL_STATE(204)] = 9605,
  [SMALL_STATE(205)] = 9649,
  [SMALL_STATE(206)] = 9693,
  [SMALL_STATE(207)] = 9746,
  [SMALL_STATE(208)] = 9809,
  [SMALL_STATE(209)] = 9872,
  [SMALL_STATE(210)] = 9935,
  [SMALL_STATE(211)] = 9992,
  [SMALL_STATE(212)] = 10049,
  [SMALL_STATE(213)] = 10108,
  [SMALL_STATE(214)] = 10165,
  [SMALL_STATE(215)] = 10218,
  [SMALL_STATE(216)] = 10309,
  [SMALL_STATE(217)] = 10402,
  [SMALL_STATE(218)] = 10461,
  [SMALL_STATE(219)] = 10552,
  [SMALL_STATE(220)] = 10645,
  [SMALL_STATE(221)] = 10736,
  [SMALL_STATE(222)] = 10799,
  [SMALL_STATE(223)] = 10883,
  [SMALL_STATE(224)] = 10971,
  [SMALL_STATE(225)] = 11059,
  [SMALL_STATE(226)] = 11147,
  [SMALL_STATE(227)] = 11235,
  [SMALL_STATE(228)] = 11319,
  [SMALL_STATE(229)] = 11403,
  [SMALL_STATE(230)] = 11487,
  [SMALL_STATE(231)] = 11571,
  [SMALL_STATE(232)] = 11655,
  [SMALL_STATE(233)] = 11743,
  [SMALL_STATE(234)] = 11831,
  [SMALL_STATE(235)] = 11919,
  [SMALL_STATE(236)] = 12007,
  [SMALL_STATE(237)] = 12095,
  [SMALL_STATE(238)] = 12183,
  [SMALL_STATE(239)] = 12271,
  [SMALL_STATE(240)] = 12359,
  [SMALL_STATE(241)] = 12447,
  [SMALL_STATE(242)] = 12535,
  [SMALL_STATE(243)] = 12619,
  [SMALL_STATE(244)] = 12703,
  [SMALL_STATE(245)] = 12791,
  [SMALL_STATE(246)] = 12875,
  [SMALL_STATE(247)] = 12959,
  [SMALL_STATE(248)] = 13043,
  [SMALL_STATE(249)] = 13131,
  [SMALL_STATE(250)] = 13219,
  [SMALL_STATE(251)] = 13307,
  [SMALL_STATE(252)] = 13395,
  [SMALL_STATE(253)] = 13483,
  [SMALL_STATE(254)] = 13567,
  [SMALL_STATE(255)] = 13651,
  [SMALL_STATE(256)] = 13735,
  [SMALL_STATE(257)] = 13819,
  [SMALL_STATE(258)] = 13907,
  [SMALL_STATE(259)] = 13995,
  [SMALL_STATE(260)] = 14043,
  [SMALL_STATE(261)] = 14131,
  [SMALL_STATE(262)] = 14183,
  [SMALL_STATE(263)] = 14271,
  [SMALL_STATE(264)] = 14337,
  [SMALL_STATE(265)] = 14425,
  [SMALL_STATE(266)] = 14513,
  [SMALL_STATE(267)] = 14601,
  [SMALL_STATE(268)] = 14689,
  [SMALL_STATE(269)] = 14731,
  [SMALL_STATE(270)] = 14819,
  [SMALL_STATE(271)] = 14907,
  [SMALL_STATE(272)] = 14995,
  [SMALL_STATE(273)] = 15083,
  [SMALL_STATE(274)] = 15171,
  [SMALL_STATE(275)] = 15259,
  [SMALL_STATE(276)] = 15347,
  [SMALL_STATE(277)] = 15435,
  [SMALL_STATE(278)] = 15501,
  [SMALL_STATE(279)] = 15567,
  [SMALL_STATE(280)] = 15633,
  [SMALL_STATE(281)] = 15679,
  [SMALL_STATE(282)] = 15767,
  [SMALL_STATE(283)] = 15855,
  [SMALL_STATE(284)] = 15943,
  [SMALL_STATE(285)] = 16031,
  [SMALL_STATE(286)] = 16119,
  [SMALL_STATE(287)] = 16207,
  [SMALL_STATE(288)] = 16295,
  [SMALL_STATE(289)] = 16383,
  [SMALL_STATE(290)] = 16471,
  [SMALL_STATE(291)] = 16559,
  [SMALL_STATE(292)] = 16647,
  [SMALL_STATE(293)] = 16735,
  [SMALL_STATE(294)] = 16823,
  [SMALL_STATE(295)] = 16911,
  [SMALL_STATE(296)] = 16999,
  [SMALL_STATE(297)] = 17087,
  [SMALL_STATE(298)] = 17175,
  [SMALL_STATE(299)] = 17263,
  [SMALL_STATE(300)] = 17351,
  [SMALL_STATE(301)] = 17439,
  [SMALL_STATE(302)] = 17527,
  [SMALL_STATE(303)] = 17615,
  [SMALL_STATE(304)] = 17663,
  [SMALL_STATE(305)] = 17751,
  [SMALL_STATE(306)] = 17839,
  [SMALL_STATE(307)] = 17927,
  [SMALL_STATE(308)] = 18011,
  [SMALL_STATE(309)] = 18095,
  [SMALL_STATE(310)] = 18179,
  [SMALL_STATE(311)] = 18263,
  [SMALL_STATE(312)] = 18347,
  [SMALL_STATE(313)] = 18435,
  [SMALL_STATE(314)] = 18523,
  [SMALL_STATE(315)] = 18571,
  [SMALL_STATE(316)] = 18659,
  [SMALL_STATE(317)] = 18747,
  [SMALL_STATE(318)] = 18835,
  [SMALL_STATE(319)] = 18883,
  [SMALL_STATE(320)] = 18971,
  [SMALL_STATE(321)] = 19059,
  [SMALL_STATE(322)] = 19147,
  [SMALL_STATE(323)] = 19195,
  [SMALL_STATE(324)] = 19283,
  [SMALL_STATE(325)] = 19331,
  [SMALL_STATE(326)] = 19419,
  [SMALL_STATE(327)] = 19507,
  [SMALL_STATE(328)] = 19595,
  [SMALL_STATE(329)] = 19683,
  [SMALL_STATE(330)] = 19771,
  [SMALL_STATE(331)] = 19859,
  [SMALL_STATE(332)] = 19947,
  [SMALL_STATE(333)] = 20035,
  [SMALL_STATE(334)] = 20123,
  [SMALL_STATE(335)] = 20169,
  [SMALL_STATE(336)] = 20257,
  [SMALL_STATE(337)] = 20345,
  [SMALL_STATE(338)] = 20433,
  [SMALL_STATE(339)] = 20521,
  [SMALL_STATE(340)] = 20609,
  [SMALL_STATE(341)] = 20697,
  [SMALL_STATE(342)] = 20785,
  [SMALL_STATE(343)] = 20873,
  [SMALL_STATE(344)] = 20961,
  [SMALL_STATE(345)] = 21049,
  [SMALL_STATE(346)] = 21137,
  [SMALL_STATE(347)] = 21194,
  [SMALL_STATE(348)] = 21251,
  [SMALL_STATE(349)] = 21314,
  [SMALL_STATE(350)] = 21359,
  [SMALL_STATE(351)] = 21404,
  [SMALL_STATE(352)] = 21447,
  [SMALL_STATE(353)] = 21504,
  [SMALL_STATE(354)] = 21549,
  [SMALL_STATE(355)] = 21592,
  [SMALL_STATE(356)] = 21637,
  [SMALL_STATE(357)] = 21702,
  [SMALL_STATE(358)] = 21765,
  [SMALL_STATE(359)] = 21822,
  [SMALL_STATE(360)] = 21885,
  [SMALL_STATE(361)] = 21938,
  [SMALL_STATE(362)] = 21995,
  [SMALL_STATE(363)] = 22038,
  [SMALL_STATE(364)] = 22081,
  [SMALL_STATE(365)] = 22126,
  [SMALL_STATE(366)] = 22169,
  [SMALL_STATE(367)] = 22232,
  [SMALL_STATE(368)] = 22275,
  [SMALL_STATE(369)] = 22318,
  [SMALL_STATE(370)] = 22371,
  [SMALL_STATE(371)] = 22413,
  [SMALL_STATE(372)] = 22455,
  [SMALL_STATE(373)] = 22505,
  [SMALL_STATE(374)] = 22547,
  [SMALL_STATE(375)] = 22611,
  [SMALL_STATE(376)] = 22673,
  [SMALL_STATE(377)] = 22713,
  [SMALL_STATE(378)] = 22755,
  [SMALL_STATE(379)] = 22797,
  [SMALL_STATE(380)] = 22842,
  [SMALL_STATE(381)] = 22887,
  [SMALL_STATE(382)] = 22932,
  [SMALL_STATE(383)] = 22971,
  [SMALL_STATE(384)] = 23016,
  [SMALL_STATE(385)] = 23061,
  [SMALL_STATE(386)] = 23106,
  [SMALL_STATE(387)] = 23151,
  [SMALL_STATE(388)] = 23192,
  [SMALL_STATE(389)] = 23233,
  [SMALL_STATE(390)] = 23278,
  [SMALL_STATE(391)] = 23319,
  [SMALL_STATE(392)] = 23382,
  [SMALL_STATE(393)] = 23425,
  [SMALL_STATE(394)] = 23486,
  [SMALL_STATE(395)] = 23527,
  [SMALL_STATE(396)] = 23568,
  [SMALL_STATE(397)] = 23609,
  [SMALL_STATE(398)] = 23654,
  [SMALL_STATE(399)] = 23711,
  [SMALL_STATE(400)] = 23756,
  [SMALL_STATE(401)] = 23801,
  [SMALL_STATE(402)] = 23844,
  [SMALL_STATE(403)] = 23887,
  [SMALL_STATE(404)] = 23950,
  [SMALL_STATE(405)] = 24001,
  [SMALL_STATE(406)] = 24058,
  [SMALL_STATE(407)] = 24099,
  [SMALL_STATE(408)] = 24156,
  [SMALL_STATE(409)] = 24197,
  [SMALL_STATE(410)] = 24242,
  [SMALL_STATE(411)] = 24293,
  [SMALL_STATE(412)] = 24332,
  [SMALL_STATE(413)] = 24379,
  [SMALL_STATE(414)] = 24418,
  [SMALL_STATE(415)] = 24459,
  [SMALL_STATE(416)] = 24498,
  [SMALL_STATE(417)] = 24539,
  [SMALL_STATE(418)] = 24578,
  [SMALL_STATE(419)] = 24623,
  [SMALL_STATE(420)] = 24664,
  [SMALL_STATE(421)] = 24705,
  [SMALL_STATE(422)] = 24744,
  [SMALL_STATE(423)] = 24789,
  [SMALL_STATE(424)] = 24828,
  [SMALL_STATE(425)] = 24873,
  [SMALL_STATE(426)] = 24916,
  [SMALL_STATE(427)] = 24959,
  [SMALL_STATE(428)] = 24998,
  [SMALL_STATE(429)] = 25039,
  [SMALL_STATE(430)] = 25084,
  [SMALL_STATE(431)] = 25129,
  [SMALL_STATE(432)] = 25172,
  [SMALL_STATE(433)] = 25235,
  [SMALL_STATE(434)] = 25298,
  [SMALL_STATE(435)] = 25343,
  [SMALL_STATE(436)] = 25384,
  [SMALL_STATE(437)] = 25425,
  [SMALL_STATE(438)] = 25466,
  [SMALL_STATE(439)] = 25507,
  [SMALL_STATE(440)] = 25570,
  [SMALL_STATE(441)] = 25609,
  [SMALL_STATE(442)] = 25650,
  [SMALL_STATE(443)] = 25689,
  [SMALL_STATE(444)] = 25728,
  [SMALL_STATE(445)] = 25769,
  [SMALL_STATE(446)] = 25814,
  [SMALL_STATE(447)] = 25855,
  [SMALL_STATE(448)] = 25894,
  [SMALL_STATE(449)] = 25934,
  [SMALL_STATE(450)] = 25992,
  [SMALL_STATE(451)] = 26032,
  [SMALL_STATE(452)] = 26077,
  [SMALL_STATE(453)] = 26118,
  [SMALL_STATE(454)] = 26163,
  [SMALL_STATE(455)] = 26210,
  [SMALL_STATE(456)] = 26255,
  [SMALL_STATE(457)] = 26298,
  [SMALL_STATE(458)] = 26339,
  [SMALL_STATE(459)] = 26380,
  [SMALL_STATE(460)] = 26419,
  [SMALL_STATE(461)] = 26462,
  [SMALL_STATE(462)] = 26507,
  [SMALL_STATE(463)] = 26550,
  [SMALL_STATE(464)] = 26593,
  [SMALL_STATE(465)] = 26638,
  [SMALL_STATE(466)] = 26677,
  [SMALL_STATE(467)] = 26722,
  [SMALL_STATE(468)] = 26761,
  [SMALL_STATE(469)] = 26800,
  [SMALL_STATE(470)] = 26843,
  [SMALL_STATE(471)] = 26884,
  [SMALL_STATE(472)] = 26923,
  [SMALL_STATE(473)] = 26968,
  [SMALL_STATE(474)] = 27009,
  [SMALL_STATE(475)] = 27050,
  [SMALL_STATE(476)] = 27095,
  [SMALL_STATE(477)] = 27138,
  [SMALL_STATE(478)] = 27181,
  [SMALL_STATE(479)] = 27220,
  [SMALL_STATE(480)] = 27259,
  [SMALL_STATE(481)] = 27298,
  [SMALL_STATE(482)] = 27343,
  [SMALL_STATE(483)] = 27382,
  [SMALL_STATE(484)] = 27421,
  [SMALL_STATE(485)] = 27462,
  [SMALL_STATE(486)] = 27507,
  [SMALL_STATE(487)] = 27552,
  [SMALL_STATE(488)] = 27593,
  [SMALL_STATE(489)] = 27636,
  [SMALL_STATE(490)] = 27675,
  [SMALL_STATE(491)] = 27716,
  [SMALL_STATE(492)] = 27759,
  [SMALL_STATE(493)] = 27802,
  [SMALL_STATE(494)] = 27843,
  [SMALL_STATE(495)] = 27884,
  [SMALL_STATE(496)] = 27929,
  [SMALL_STATE(497)] = 27972,
  [SMALL_STATE(498)] = 28011,
  [SMALL_STATE(499)] = 28052,
  [SMALL_STATE(500)] = 28093,
  [SMALL_STATE(501)] = 28134,
  [SMALL_STATE(502)] = 28177,
  [SMALL_STATE(503)] = 28222,
  [SMALL_STATE(504)] = 28265,
  [SMALL_STATE(505)] = 28308,
  [SMALL_STATE(506)] = 28350,
  [SMALL_STATE(507)] = 28388,
  [SMALL_STATE(508)] = 28428,
  [SMALL_STATE(509)] = 28466,
  [SMALL_STATE(510)] = 28508,
  [SMALL_STATE(511)] = 28551,
  [SMALL_STATE(512)] = 28596,
  [SMALL_STATE(513)] = 28641,
  [SMALL_STATE(514)] = 28682,
  [SMALL_STATE(515)] = 28725,
  [SMALL_STATE(516)] = 28762,
  [SMALL_STATE(517)] = 28801,
  [SMALL_STATE(518)] = 28840,
  [SMALL_STATE(519)] = 28877,
  [SMALL_STATE(520)] = 28916,
  [SMALL_STATE(521)] = 28957,
  [SMALL_STATE(522)] = 28994,
  [SMALL_STATE(523)] = 29031,
  [SMALL_STATE(524)] = 29068,
  [SMALL_STATE(525)] = 29105,
  [SMALL_STATE(526)] = 29142,
  [SMALL_STATE(527)] = 29179,
  [SMALL_STATE(528)] = 29216,
  [SMALL_STATE(529)] = 29253,
  [SMALL_STATE(530)] = 29294,
  [SMALL_STATE(531)] = 29333,
  [SMALL_STATE(532)] = 29372,
  [SMALL_STATE(533)] = 29417,
  [SMALL_STATE(534)] = 29456,
  [SMALL_STATE(535)] = 29493,
  [SMALL_STATE(536)] = 29530,
  [SMALL_STATE(537)] = 29571,
  [SMALL_STATE(538)] = 29616,
  [SMALL_STATE(539)] = 29661,
  [SMALL_STATE(540)] = 29706,
  [SMALL_STATE(541)] = 29749,
  [SMALL_STATE(542)] = 29790,
  [SMALL_STATE(543)] = 29833,
  [SMALL_STATE(544)] = 29878,
  [SMALL_STATE(545)] = 29923,
  [SMALL_STATE(546)] = 29968,
  [SMALL_STATE(547)] = 30007,
  [SMALL_STATE(548)] = 30052,
  [SMALL_STATE(549)] = 30091,
  [SMALL_STATE(550)] = 30130,
  [SMALL_STATE(551)] = 30175,
  [SMALL_STATE(552)] = 30220,
  [SMALL_STATE(553)] = 30263,
  [SMALL_STATE(554)] = 30302,
  [SMALL_STATE(555)] = 30345,
  [SMALL_STATE(556)] = 30391,
  [SMALL_STATE(557)] = 30433,
  [SMALL_STATE(558)] = 30475,
  [SMALL_STATE(559)] = 30521,
  [SMALL_STATE(560)] = 30561,
  [SMALL_STATE(561)] = 30605,
  [SMALL_STATE(562)] = 30643,
  [SMALL_STATE(563)] = 30687,
  [SMALL_STATE(564)] = 30731,
  [SMALL_STATE(565)] = 30776,
  [SMALL_STATE(566)] = 30821,
  [SMALL_STATE(567)] = 30866,
  [SMALL_STATE(568)] = 30911,
  [SMALL_STATE(569)] = 30956,
  [SMALL_STATE(570)] = 30999,
  [SMALL_STATE(571)] = 31044,
  [SMALL_STATE(572)] = 31089,
  [SMALL_STATE(573)] = 31134,
  [SMALL_STATE(574)] = 31179,
  [SMALL_STATE(575)] = 31224,
  [SMALL_STATE(576)] = 31269,
  [SMALL_STATE(577)] = 31314,
  [SMALL_STATE(578)] = 31355,
  [SMALL_STATE(579)] = 31400,
  [SMALL_STATE(580)] = 31445,
  [SMALL_STATE(581)] = 31490,
  [SMALL_STATE(582)] = 31532,
  [SMALL_STATE(583)] = 31570,
  [SMALL_STATE(584)] = 31612,
  [SMALL_STATE(585)] = 31654,
  [SMALL_STATE(586)] = 31696,
  [SMALL_STATE(587)] = 31738,
  [SMALL_STATE(588)] = 31778,
  [SMALL_STATE(589)] = 31820,
  [SMALL_STATE(590)] = 31859,
  [SMALL_STATE(591)] = 31898,
  [SMALL_STATE(592)] = 31937,
  [SMALL_STATE(593)] = 31971,
  [SMALL_STATE(594)] = 32000,
  [SMALL_STATE(595)] = 32045,
  [SMALL_STATE(596)] = 32098,
  [SMALL_STATE(597)] = 32126,
  [SMALL_STATE(598)] = 32154,
  [SMALL_STATE(599)] = 32182,
  [SMALL_STATE(600)] = 32210,
  [SMALL_STATE(601)] = 32257,
  [SMALL_STATE(602)] = 32285,
  [SMALL_STATE(603)] = 32313,
  [SMALL_STATE(604)] = 32341,
  [SMALL_STATE(605)] = 32369,
  [SMALL_STATE(606)] = 32397,
  [SMALL_STATE(607)] = 32425,
  [SMALL_STATE(608)] = 32454,
  [SMALL_STATE(609)] = 32477,
  [SMALL_STATE(610)] = 32500,
  [SMALL_STATE(611)] = 32533,
  [SMALL_STATE(612)] = 32562,
  [SMALL_STATE(613)] = 32603,
  [SMALL_STATE(614)] = 32632,
  [SMALL_STATE(615)] = 32661,
  [SMALL_STATE(616)] = 32694,
  [SMALL_STATE(617)] = 32723,
  [SMALL_STATE(618)] = 32749,
  [SMALL_STATE(619)] = 32787,
  [SMALL_STATE(620)] = 32825,
  [SMALL_STATE(621)] = 32853,
  [SMALL_STATE(622)] = 32881,
  [SMALL_STATE(623)] = 32907,
  [SMALL_STATE(624)] = 32933,
  [SMALL_STATE(625)] = 32971,
  [SMALL_STATE(626)] = 32999,
  [SMALL_STATE(627)] = 33025,
  [SMALL_STATE(628)] = 33053,
  [SMALL_STATE(629)] = 33078,
  [SMALL_STATE(630)] = 33109,
  [SMALL_STATE(631)] = 33134,
  [SMALL_STATE(632)] = 33155,
  [SMALL_STATE(633)] = 33188,
  [SMALL_STATE(634)] = 33219,
  [SMALL_STATE(635)] = 33250,
  [SMALL_STATE(636)] = 33281,
  [SMALL_STATE(637)] = 33312,
  [SMALL_STATE(638)] = 33343,
  [SMALL_STATE(639)] = 33376,
  [SMALL_STATE(640)] = 33397,
  [SMALL_STATE(641)] = 33418,
  [SMALL_STATE(642)] = 33441,
  [SMALL_STATE(643)] = 33462,
  [SMALL_STATE(644)] = 33483,
  [SMALL_STATE(645)] = 33504,
  [SMALL_STATE(646)] = 33543,
  [SMALL_STATE(647)] = 33577,
  [SMALL_STATE(648)] = 33607,
  [SMALL_STATE(649)] = 33633,
  [SMALL_STATE(650)] = 33663,
  [SMALL_STATE(651)] = 33697,
  [SMALL_STATE(652)] = 33731,
  [SMALL_STATE(653)] = 33763,
  [SMALL_STATE(654)] = 33793,
  [SMALL_STATE(655)] = 33819,
  [SMALL_STATE(656)] = 33849,
  [SMALL_STATE(657)] = 33879,
  [SMALL_STATE(658)] = 33913,
  [SMALL_STATE(659)] = 33943,
  [SMALL_STATE(660)] = 33977,
  [SMALL_STATE(661)] = 34005,
  [SMALL_STATE(662)] = 34037,
  [SMALL_STATE(663)] = 34069,
  [SMALL_STATE(664)] = 34099,
  [SMALL_STATE(665)] = 34129,
  [SMALL_STATE(666)] = 34159,
  [SMALL_STATE(667)] = 34193,
  [SMALL_STATE(668)] = 34227,
  [SMALL_STATE(669)] = 34261,
  [SMALL_STATE(670)] = 34278,
  [SMALL_STATE(671)] = 34295,
  [SMALL_STATE(672)] = 34314,
  [SMALL_STATE(673)] = 34345,
  [SMALL_STATE(674)] = 34370,
  [SMALL_STATE(675)] = 34395,
  [SMALL_STATE(676)] = 34417,
  [SMALL_STATE(677)] = 34441,
  [SMALL_STATE(678)] = 34467,
  [SMALL_STATE(679)] = 34483,
  [SMALL_STATE(680)] = 34503,
  [SMALL_STATE(681)] = 34527,
  [SMALL_STATE(682)] = 34549,
  [SMALL_STATE(683)] = 34573,
  [SMALL_STATE(684)] = 34599,
  [SMALL_STATE(685)] = 34623,
  [SMALL_STATE(686)] = 34647,
  [SMALL_STATE(687)] = 34670,
  [SMALL_STATE(688)] = 34687,
  [SMALL_STATE(689)] = 34708,
  [SMALL_STATE(690)] = 34729,
  [SMALL_STATE(691)] = 34752,
  [SMALL_STATE(692)] = 34773,
  [SMALL_STATE(693)] = 34796,
  [SMALL_STATE(694)] = 34817,
  [SMALL_STATE(695)] = 34840,
  [SMALL_STATE(696)] = 34861,
  [SMALL_STATE(697)] = 34884,
  [SMALL_STATE(698)] = 34906,
  [SMALL_STATE(699)] = 34926,
  [SMALL_STATE(700)] = 34946,
  [SMALL_STATE(701)] = 34966,
  [SMALL_STATE(702)] = 34986,
  [SMALL_STATE(703)] = 35006,
  [SMALL_STATE(704)] = 35032,
  [SMALL_STATE(705)] = 35052,
  [SMALL_STATE(706)] = 35066,
  [SMALL_STATE(707)] = 35086,
  [SMALL_STATE(708)] = 35104,
  [SMALL_STATE(709)] = 35122,
  [SMALL_STATE(710)] = 35140,
  [SMALL_STATE(711)] = 35162,
  [SMALL_STATE(712)] = 35186,
  [SMALL_STATE(713)] = 35204,
  [SMALL_STATE(714)] = 35222,
  [SMALL_STATE(715)] = 35240,
  [SMALL_STATE(716)] = 35258,
  [SMALL_STATE(717)] = 35276,
  [SMALL_STATE(718)] = 35294,
  [SMALL_STATE(719)] = 35314,
  [SMALL_STATE(720)] = 35332,
  [SMALL_STATE(721)] = 35350,
  [SMALL_STATE(722)] = 35370,
  [SMALL_STATE(723)] = 35390,
  [SMALL_STATE(724)] = 35410,
  [SMALL_STATE(725)] = 35432,
  [SMALL_STATE(726)] = 35448,
  [SMALL_STATE(727)] = 35470,
  [SMALL_STATE(728)] = 35492,
  [SMALL_STATE(729)] = 35514,
  [SMALL_STATE(730)] = 35532,
  [SMALL_STATE(731)] = 35546,
  [SMALL_STATE(732)] = 35568,
  [SMALL_STATE(733)] = 35590,
  [SMALL_STATE(734)] = 35612,
  [SMALL_STATE(735)] = 35636,
  [SMALL_STATE(736)] = 35656,
  [SMALL_STATE(737)] = 35676,
  [SMALL_STATE(738)] = 35698,
  [SMALL_STATE(739)] = 35718,
  [SMALL_STATE(740)] = 35736,
  [SMALL_STATE(741)] = 35758,
  [SMALL_STATE(742)] = 35778,
  [SMALL_STATE(743)] = 35800,
  [SMALL_STATE(744)] = 35820,
  [SMALL_STATE(745)] = 35840,
  [SMALL_STATE(746)] = 35860,
  [SMALL_STATE(747)] = 35880,
  [SMALL_STATE(748)] = 35902,
  [SMALL_STATE(749)] = 35924,
  [SMALL_STATE(750)] = 35944,
  [SMALL_STATE(751)] = 35962,
  [SMALL_STATE(752)] = 35981,
  [SMALL_STATE(753)] = 36002,
  [SMALL_STATE(754)] = 36019,
  [SMALL_STATE(755)] = 36040,
  [SMALL_STATE(756)] = 36057,
  [SMALL_STATE(757)] = 36074,
  [SMALL_STATE(758)] = 36089,
  [SMALL_STATE(759)] = 36106,
  [SMALL_STATE(760)] = 36125,
  [SMALL_STATE(761)] = 36144,
  [SMALL_STATE(762)] = 36159,
  [SMALL_STATE(763)] = 36176,
  [SMALL_STATE(764)] = 36193,
  [SMALL_STATE(765)] = 36208,
  [SMALL_STATE(766)] = 36225,
  [SMALL_STATE(767)] = 36242,
  [SMALL_STATE(768)] = 36255,
  [SMALL_STATE(769)] = 36276,
  [SMALL_STATE(770)] = 36297,
  [SMALL_STATE(771)] = 36310,
  [SMALL_STATE(772)] = 36325,
  [SMALL_STATE(773)] = 36340,
  [SMALL_STATE(774)] = 36361,
  [SMALL_STATE(775)] = 36376,
  [SMALL_STATE(776)] = 36389,
  [SMALL_STATE(777)] = 36402,
  [SMALL_STATE(778)] = 36421,
  [SMALL_STATE(779)] = 36442,
  [SMALL_STATE(780)] = 36461,
  [SMALL_STATE(781)] = 36478,
  [SMALL_STATE(782)] = 36493,
  [SMALL_STATE(783)] = 36514,
  [SMALL_STATE(784)] = 36535,
  [SMALL_STATE(785)] = 36556,
  [SMALL_STATE(786)] = 36577,
  [SMALL_STATE(787)] = 36592,
  [SMALL_STATE(788)] = 36607,
  [SMALL_STATE(789)] = 36624,
  [SMALL_STATE(790)] = 36641,
  [SMALL_STATE(791)] = 36658,
  [SMALL_STATE(792)] = 36675,
  [SMALL_STATE(793)] = 36690,
  [SMALL_STATE(794)] = 36711,
  [SMALL_STATE(795)] = 36724,
  [SMALL_STATE(796)] = 36741,
  [SMALL_STATE(797)] = 36756,
  [SMALL_STATE(798)] = 36773,
  [SMALL_STATE(799)] = 36790,
  [SMALL_STATE(800)] = 36807,
  [SMALL_STATE(801)] = 36822,
  [SMALL_STATE(802)] = 36839,
  [SMALL_STATE(803)] = 36856,
  [SMALL_STATE(804)] = 36873,
  [SMALL_STATE(805)] = 36890,
  [SMALL_STATE(806)] = 36903,
  [SMALL_STATE(807)] = 36918,
  [SMALL_STATE(808)] = 36931,
  [SMALL_STATE(809)] = 36944,
  [SMALL_STATE(810)] = 36957,
  [SMALL_STATE(811)] = 36972,
  [SMALL_STATE(812)] = 36987,
  [SMALL_STATE(813)] = 37002,
  [SMALL_STATE(814)] = 37017,
  [SMALL_STATE(815)] = 37032,
  [SMALL_STATE(816)] = 37047,
  [SMALL_STATE(817)] = 37060,
  [SMALL_STATE(818)] = 37077,
  [SMALL_STATE(819)] = 37090,
  [SMALL_STATE(820)] = 37105,
  [SMALL_STATE(821)] = 37122,
  [SMALL_STATE(822)] = 37135,
  [SMALL_STATE(823)] = 37156,
  [SMALL_STATE(824)] = 37176,
  [SMALL_STATE(825)] = 37192,
  [SMALL_STATE(826)] = 37206,
  [SMALL_STATE(827)] = 37220,
  [SMALL_STATE(828)] = 37232,
  [SMALL_STATE(829)] = 37244,
  [SMALL_STATE(830)] = 37264,
  [SMALL_STATE(831)] = 37278,
  [SMALL_STATE(832)] = 37294,
  [SMALL_STATE(833)] = 37308,
  [SMALL_STATE(834)] = 37320,
  [SMALL_STATE(835)] = 37336,
  [SMALL_STATE(836)] = 37350,
  [SMALL_STATE(837)] = 37364,
  [SMALL_STATE(838)] = 37380,
  [SMALL_STATE(839)] = 37394,
  [SMALL_STATE(840)] = 37408,
  [SMALL_STATE(841)] = 37422,
  [SMALL_STATE(842)] = 37438,
  [SMALL_STATE(843)] = 37454,
  [SMALL_STATE(844)] = 37468,
  [SMALL_STATE(845)] = 37482,
  [SMALL_STATE(846)] = 37498,
  [SMALL_STATE(847)] = 37514,
  [SMALL_STATE(848)] = 37528,
  [SMALL_STATE(849)] = 37542,
  [SMALL_STATE(850)] = 37556,
  [SMALL_STATE(851)] = 37570,
  [SMALL_STATE(852)] = 37584,
  [SMALL_STATE(853)] = 37598,
  [SMALL_STATE(854)] = 37614,
  [SMALL_STATE(855)] = 37630,
  [SMALL_STATE(856)] = 37650,
  [SMALL_STATE(857)] = 37664,
  [SMALL_STATE(858)] = 37678,
  [SMALL_STATE(859)] = 37698,
  [SMALL_STATE(860)] = 37712,
  [SMALL_STATE(861)] = 37726,
  [SMALL_STATE(862)] = 37740,
  [SMALL_STATE(863)] = 37756,
  [SMALL_STATE(864)] = 37772,
  [SMALL_STATE(865)] = 37786,
  [SMALL_STATE(866)] = 37802,
  [SMALL_STATE(867)] = 37820,
  [SMALL_STATE(868)] = 37834,
  [SMALL_STATE(869)] = 37850,
  [SMALL_STATE(870)] = 37866,
  [SMALL_STATE(871)] = 37880,
  [SMALL_STATE(872)] = 37896,
  [SMALL_STATE(873)] = 37916,
  [SMALL_STATE(874)] = 37936,
  [SMALL_STATE(875)] = 37950,
  [SMALL_STATE(876)] = 37964,
  [SMALL_STATE(877)] = 37984,
  [SMALL_STATE(878)] = 38000,
  [SMALL_STATE(879)] = 38020,
  [SMALL_STATE(880)] = 38034,
  [SMALL_STATE(881)] = 38050,
  [SMALL_STATE(882)] = 38064,
  [SMALL_STATE(883)] = 38084,
  [SMALL_STATE(884)] = 38104,
  [SMALL_STATE(885)] = 38124,
  [SMALL_STATE(886)] = 38144,
  [SMALL_STATE(887)] = 38158,
  [SMALL_STATE(888)] = 38172,
  [SMALL_STATE(889)] = 38186,
  [SMALL_STATE(890)] = 38200,
  [SMALL_STATE(891)] = 38218,
  [SMALL_STATE(892)] = 38232,
  [SMALL_STATE(893)] = 38246,
  [SMALL_STATE(894)] = 38260,
  [SMALL_STATE(895)] = 38280,
  [SMALL_STATE(896)] = 38300,
  [SMALL_STATE(897)] = 38320,
  [SMALL_STATE(898)] = 38336,
  [SMALL_STATE(899)] = 38351,
  [SMALL_STATE(900)] = 38366,
  [SMALL_STATE(901)] = 38377,
  [SMALL_STATE(902)] = 38388,
  [SMALL_STATE(903)] = 38399,
  [SMALL_STATE(904)] = 38410,
  [SMALL_STATE(905)] = 38425,
  [SMALL_STATE(906)] = 38442,
  [SMALL_STATE(907)] = 38459,
  [SMALL_STATE(908)] = 38470,
  [SMALL_STATE(909)] = 38481,
  [SMALL_STATE(910)] = 38492,
  [SMALL_STATE(911)] = 38503,
  [SMALL_STATE(912)] = 38518,
  [SMALL_STATE(913)] = 38529,
  [SMALL_STATE(914)] = 38544,
  [SMALL_STATE(915)] = 38561,
  [SMALL_STATE(916)] = 38572,
  [SMALL_STATE(917)] = 38587,
  [SMALL_STATE(918)] = 38598,
  [SMALL_STATE(919)] = 38609,
  [SMALL_STATE(920)] = 38620,
  [SMALL_STATE(921)] = 38635,
  [SMALL_STATE(922)] = 38648,
  [SMALL_STATE(923)] = 38663,
  [SMALL_STATE(924)] = 38678,
  [SMALL_STATE(925)] = 38689,
  [SMALL_STATE(926)] = 38704,
  [SMALL_STATE(927)] = 38719,
  [SMALL_STATE(928)] = 38730,
  [SMALL_STATE(929)] = 38741,
  [SMALL_STATE(930)] = 38752,
  [SMALL_STATE(931)] = 38767,
  [SMALL_STATE(932)] = 38778,
  [SMALL_STATE(933)] = 38795,
  [SMALL_STATE(934)] = 38810,
  [SMALL_STATE(935)] = 38821,
  [SMALL_STATE(936)] = 38838,
  [SMALL_STATE(937)] = 38849,
  [SMALL_STATE(938)] = 38860,
  [SMALL_STATE(939)] = 38877,
  [SMALL_STATE(940)] = 38892,
  [SMALL_STATE(941)] = 38903,
  [SMALL_STATE(942)] = 38920,
  [SMALL_STATE(943)] = 38935,
  [SMALL_STATE(944)] = 38950,
  [SMALL_STATE(945)] = 38967,
  [SMALL_STATE(946)] = 38978,
  [SMALL_STATE(947)] = 38993,
  [SMALL_STATE(948)] = 39008,
  [SMALL_STATE(949)] = 39023,
  [SMALL_STATE(950)] = 39034,
  [SMALL_STATE(951)] = 39045,
  [SMALL_STATE(952)] = 39062,
  [SMALL_STATE(953)] = 39073,
  [SMALL_STATE(954)] = 39084,
  [SMALL_STATE(955)] = 39101,
  [SMALL_STATE(956)] = 39112,
  [SMALL_STATE(957)] = 39127,
  [SMALL_STATE(958)] = 39142,
  [SMALL_STATE(959)] = 39159,
  [SMALL_STATE(960)] = 39176,
  [SMALL_STATE(961)] = 39187,
  [SMALL_STATE(962)] = 39204,
  [SMALL_STATE(963)] = 39215,
  [SMALL_STATE(964)] = 39230,
  [SMALL_STATE(965)] = 39245,
  [SMALL_STATE(966)] = 39256,
  [SMALL_STATE(967)] = 39267,
  [SMALL_STATE(968)] = 39278,
  [SMALL_STATE(969)] = 39293,
  [SMALL_STATE(970)] = 39308,
  [SMALL_STATE(971)] = 39323,
  [SMALL_STATE(972)] = 39340,
  [SMALL_STATE(973)] = 39355,
  [SMALL_STATE(974)] = 39370,
  [SMALL_STATE(975)] = 39381,
  [SMALL_STATE(976)] = 39398,
  [SMALL_STATE(977)] = 39409,
  [SMALL_STATE(978)] = 39420,
  [SMALL_STATE(979)] = 39437,
  [SMALL_STATE(980)] = 39452,
  [SMALL_STATE(981)] = 39469,
  [SMALL_STATE(982)] = 39486,
  [SMALL_STATE(983)] = 39503,
  [SMALL_STATE(984)] = 39520,
  [SMALL_STATE(985)] = 39531,
  [SMALL_STATE(986)] = 39548,
  [SMALL_STATE(987)] = 39559,
  [SMALL_STATE(988)] = 39576,
  [SMALL_STATE(989)] = 39587,
  [SMALL_STATE(990)] = 39604,
  [SMALL_STATE(991)] = 39621,
  [SMALL_STATE(992)] = 39632,
  [SMALL_STATE(993)] = 39643,
  [SMALL_STATE(994)] = 39660,
  [SMALL_STATE(995)] = 39677,
  [SMALL_STATE(996)] = 39694,
  [SMALL_STATE(997)] = 39711,
  [SMALL_STATE(998)] = 39722,
  [SMALL_STATE(999)] = 39737,
  [SMALL_STATE(1000)] = 39748,
  [SMALL_STATE(1001)] = 39763,
  [SMALL_STATE(1002)] = 39774,
  [SMALL_STATE(1003)] = 39791,
  [SMALL_STATE(1004)] = 39802,
  [SMALL_STATE(1005)] = 39813,
  [SMALL_STATE(1006)] = 39830,
  [SMALL_STATE(1007)] = 39841,
  [SMALL_STATE(1008)] = 39852,
  [SMALL_STATE(1009)] = 39867,
  [SMALL_STATE(1010)] = 39884,
  [SMALL_STATE(1011)] = 39898,
  [SMALL_STATE(1012)] = 39912,
  [SMALL_STATE(1013)] = 39924,
  [SMALL_STATE(1014)] = 39936,
  [SMALL_STATE(1015)] = 39948,
  [SMALL_STATE(1016)] = 39960,
  [SMALL_STATE(1017)] = 39972,
  [SMALL_STATE(1018)] = 39986,
  [SMALL_STATE(1019)] = 39998,
  [SMALL_STATE(1020)] = 40008,
  [SMALL_STATE(1021)] = 40020,
  [SMALL_STATE(1022)] = 40034,
  [SMALL_STATE(1023)] = 40048,
  [SMALL_STATE(1024)] = 40062,
  [SMALL_STATE(1025)] = 40076,
  [SMALL_STATE(1026)] = 40090,
  [SMALL_STATE(1027)] = 40104,
  [SMALL_STATE(1028)] = 40118,
  [SMALL_STATE(1029)] = 40130,
  [SMALL_STATE(1030)] = 40142,
  [SMALL_STATE(1031)] = 40154,
  [SMALL_STATE(1032)] = 40168,
  [SMALL_STATE(1033)] = 40182,
  [SMALL_STATE(1034)] = 40196,
  [SMALL_STATE(1035)] = 40210,
  [SMALL_STATE(1036)] = 40224,
  [SMALL_STATE(1037)] = 40234,
  [SMALL_STATE(1038)] = 40248,
  [SMALL_STATE(1039)] = 40262,
  [SMALL_STATE(1040)] = 40274,
  [SMALL_STATE(1041)] = 40288,
  [SMALL_STATE(1042)] = 40300,
  [SMALL_STATE(1043)] = 40312,
  [SMALL_STATE(1044)] = 40326,
  [SMALL_STATE(1045)] = 40338,
  [SMALL_STATE(1046)] = 40350,
  [SMALL_STATE(1047)] = 40364,
  [SMALL_STATE(1048)] = 40376,
  [SMALL_STATE(1049)] = 40390,
  [SMALL_STATE(1050)] = 40400,
  [SMALL_STATE(1051)] = 40414,
  [SMALL_STATE(1052)] = 40426,
  [SMALL_STATE(1053)] = 40440,
  [SMALL_STATE(1054)] = 40454,
  [SMALL_STATE(1055)] = 40468,
  [SMALL_STATE(1056)] = 40482,
  [SMALL_STATE(1057)] = 40494,
  [SMALL_STATE(1058)] = 40508,
  [SMALL_STATE(1059)] = 40522,
  [SMALL_STATE(1060)] = 40536,
  [SMALL_STATE(1061)] = 40550,
  [SMALL_STATE(1062)] = 40564,
  [SMALL_STATE(1063)] = 40578,
  [SMALL_STATE(1064)] = 40590,
  [SMALL_STATE(1065)] = 40602,
  [SMALL_STATE(1066)] = 40614,
  [SMALL_STATE(1067)] = 40628,
  [SMALL_STATE(1068)] = 40642,
  [SMALL_STATE(1069)] = 40656,
  [SMALL_STATE(1070)] = 40670,
  [SMALL_STATE(1071)] = 40682,
  [SMALL_STATE(1072)] = 40694,
  [SMALL_STATE(1073)] = 40708,
  [SMALL_STATE(1074)] = 40722,
  [SMALL_STATE(1075)] = 40736,
  [SMALL_STATE(1076)] = 40748,
  [SMALL_STATE(1077)] = 40760,
  [SMALL_STATE(1078)] = 40772,
  [SMALL_STATE(1079)] = 40786,
  [SMALL_STATE(1080)] = 40800,
  [SMALL_STATE(1081)] = 40811,
  [SMALL_STATE(1082)] = 40822,
  [SMALL_STATE(1083)] = 40833,
  [SMALL_STATE(1084)] = 40844,
  [SMALL_STATE(1085)] = 40855,
  [SMALL_STATE(1086)] = 40866,
  [SMALL_STATE(1087)] = 40877,
  [SMALL_STATE(1088)] = 40888,
  [SMALL_STATE(1089)] = 40899,
  [SMALL_STATE(1090)] = 40910,
  [SMALL_STATE(1091)] = 40921,
  [SMALL_STATE(1092)] = 40930,
  [SMALL_STATE(1093)] = 40941,
  [SMALL_STATE(1094)] = 40950,
  [SMALL_STATE(1095)] = 40961,
  [SMALL_STATE(1096)] = 40970,
  [SMALL_STATE(1097)] = 40981,
  [SMALL_STATE(1098)] = 40992,
  [SMALL_STATE(1099)] = 41003,
  [SMALL_STATE(1100)] = 41012,
  [SMALL_STATE(1101)] = 41023,
  [SMALL_STATE(1102)] = 41034,
  [SMALL_STATE(1103)] = 41045,
  [SMALL_STATE(1104)] = 41054,
  [SMALL_STATE(1105)] = 41063,
  [SMALL_STATE(1106)] = 41074,
  [SMALL_STATE(1107)] = 41085,
  [SMALL_STATE(1108)] = 41096,
  [SMALL_STATE(1109)] = 41105,
  [SMALL_STATE(1110)] = 41116,
  [SMALL_STATE(1111)] = 41125,
  [SMALL_STATE(1112)] = 41136,
  [SMALL_STATE(1113)] = 41147,
  [SMALL_STATE(1114)] = 41158,
  [SMALL_STATE(1115)] = 41169,
  [SMALL_STATE(1116)] = 41180,
  [SMALL_STATE(1117)] = 41189,
  [SMALL_STATE(1118)] = 41198,
  [SMALL_STATE(1119)] = 41209,
  [SMALL_STATE(1120)] = 41220,
  [SMALL_STATE(1121)] = 41231,
  [SMALL_STATE(1122)] = 41240,
  [SMALL_STATE(1123)] = 41249,
  [SMALL_STATE(1124)] = 41258,
  [SMALL_STATE(1125)] = 41267,
  [SMALL_STATE(1126)] = 41278,
  [SMALL_STATE(1127)] = 41289,
  [SMALL_STATE(1128)] = 41300,
  [SMALL_STATE(1129)] = 41311,
  [SMALL_STATE(1130)] = 41322,
  [SMALL_STATE(1131)] = 41333,
  [SMALL_STATE(1132)] = 41344,
  [SMALL_STATE(1133)] = 41353,
  [SMALL_STATE(1134)] = 41364,
  [SMALL_STATE(1135)] = 41375,
  [SMALL_STATE(1136)] = 41386,
  [SMALL_STATE(1137)] = 41395,
  [SMALL_STATE(1138)] = 41404,
  [SMALL_STATE(1139)] = 41415,
  [SMALL_STATE(1140)] = 41424,
  [SMALL_STATE(1141)] = 41433,
  [SMALL_STATE(1142)] = 41442,
  [SMALL_STATE(1143)] = 41453,
  [SMALL_STATE(1144)] = 41462,
  [SMALL_STATE(1145)] = 41473,
  [SMALL_STATE(1146)] = 41484,
  [SMALL_STATE(1147)] = 41495,
  [SMALL_STATE(1148)] = 41506,
  [SMALL_STATE(1149)] = 41517,
  [SMALL_STATE(1150)] = 41528,
  [SMALL_STATE(1151)] = 41539,
  [SMALL_STATE(1152)] = 41550,
  [SMALL_STATE(1153)] = 41561,
  [SMALL_STATE(1154)] = 41569,
  [SMALL_STATE(1155)] = 41577,
  [SMALL_STATE(1156)] = 41585,
  [SMALL_STATE(1157)] = 41593,
  [SMALL_STATE(1158)] = 41601,
  [SMALL_STATE(1159)] = 41609,
  [SMALL_STATE(1160)] = 41617,
  [SMALL_STATE(1161)] = 41625,
  [SMALL_STATE(1162)] = 41633,
  [SMALL_STATE(1163)] = 41641,
  [SMALL_STATE(1164)] = 41649,
  [SMALL_STATE(1165)] = 41657,
  [SMALL_STATE(1166)] = 41665,
  [SMALL_STATE(1167)] = 41673,
  [SMALL_STATE(1168)] = 41681,
  [SMALL_STATE(1169)] = 41689,
  [SMALL_STATE(1170)] = 41697,
  [SMALL_STATE(1171)] = 41705,
  [SMALL_STATE(1172)] = 41713,
  [SMALL_STATE(1173)] = 41721,
  [SMALL_STATE(1174)] = 41729,
  [SMALL_STATE(1175)] = 41737,
  [SMALL_STATE(1176)] = 41745,
  [SMALL_STATE(1177)] = 41753,
  [SMALL_STATE(1178)] = 41761,
  [SMALL_STATE(1179)] = 41769,
  [SMALL_STATE(1180)] = 41777,
  [SMALL_STATE(1181)] = 41785,
  [SMALL_STATE(1182)] = 41793,
  [SMALL_STATE(1183)] = 41801,
  [SMALL_STATE(1184)] = 41809,
  [SMALL_STATE(1185)] = 41817,
  [SMALL_STATE(1186)] = 41825,
  [SMALL_STATE(1187)] = 41833,
  [SMALL_STATE(1188)] = 41841,
  [SMALL_STATE(1189)] = 41849,
  [SMALL_STATE(1190)] = 41857,
  [SMALL_STATE(1191)] = 41865,
  [SMALL_STATE(1192)] = 41873,
  [SMALL_STATE(1193)] = 41881,
  [SMALL_STATE(1194)] = 41889,
  [SMALL_STATE(1195)] = 41897,
  [SMALL_STATE(1196)] = 41905,
  [SMALL_STATE(1197)] = 41913,
  [SMALL_STATE(1198)] = 41921,
  [SMALL_STATE(1199)] = 41929,
  [SMALL_STATE(1200)] = 41937,
  [SMALL_STATE(1201)] = 41945,
  [SMALL_STATE(1202)] = 41953,
  [SMALL_STATE(1203)] = 41961,
  [SMALL_STATE(1204)] = 41969,
  [SMALL_STATE(1205)] = 41977,
  [SMALL_STATE(1206)] = 41985,
  [SMALL_STATE(1207)] = 41993,
  [SMALL_STATE(1208)] = 42001,
  [SMALL_STATE(1209)] = 42009,
  [SMALL_STATE(1210)] = 42017,
  [SMALL_STATE(1211)] = 42025,
  [SMALL_STATE(1212)] = 42033,
  [SMALL_STATE(1213)] = 42041,
  [SMALL_STATE(1214)] = 42049,
  [SMALL_STATE(1215)] = 42057,
  [SMALL_STATE(1216)] = 42065,
  [SMALL_STATE(1217)] = 42073,
  [SMALL_STATE(1218)] = 42081,
  [SMALL_STATE(1219)] = 42089,
  [SMALL_STATE(1220)] = 42097,
  [SMALL_STATE(1221)] = 42105,
  [SMALL_STATE(1222)] = 42113,
  [SMALL_STATE(1223)] = 42121,
  [SMALL_STATE(1224)] = 42129,
  [SMALL_STATE(1225)] = 42137,
  [SMALL_STATE(1226)] = 42145,
  [SMALL_STATE(1227)] = 42153,
  [SMALL_STATE(1228)] = 42161,
  [SMALL_STATE(1229)] = 42169,
  [SMALL_STATE(1230)] = 42177,
  [SMALL_STATE(1231)] = 42185,
  [SMALL_STATE(1232)] = 42193,
  [SMALL_STATE(1233)] = 42201,
  [SMALL_STATE(1234)] = 42209,
  [SMALL_STATE(1235)] = 42217,
  [SMALL_STATE(1236)] = 42225,
  [SMALL_STATE(1237)] = 42233,
  [SMALL_STATE(1238)] = 42241,
  [SMALL_STATE(1239)] = 42249,
  [SMALL_STATE(1240)] = 42257,
  [SMALL_STATE(1241)] = 42265,
  [SMALL_STATE(1242)] = 42273,
  [SMALL_STATE(1243)] = 42281,
  [SMALL_STATE(1244)] = 42289,
  [SMALL_STATE(1245)] = 42297,
  [SMALL_STATE(1246)] = 42305,
  [SMALL_STATE(1247)] = 42313,
  [SMALL_STATE(1248)] = 42321,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1080),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1052),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(274),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(331),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(754),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1079),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(268),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(220),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1198),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1138),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(271),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(272),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(273),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(881),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(752),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(434),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [93] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 2, 0, 7),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(908),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_clause, 3, 0, 7),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(966),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 1, 0, 0),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(928),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(929),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 1, 0, 0),
  [131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, 0, 0),
  [135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(960),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(977),
  [145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 20),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1041),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 20),
  [155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 8),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(817),
  [159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 8),
  [161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 8),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 3, 0, 8),
  [167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 14),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 14),
  [173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 8),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(758),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 8),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 14),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1018),
  [185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 14),
  [187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1020),
  [189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 14),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 14),
  [197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 20),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(801),
  [201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 20),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1015),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(804),
  [209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 20),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(803),
  [213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 20),
  [215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1076),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1014),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1039),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(910),
  [223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(940),
  [225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(720),
  [227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 1, 0, 0),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(902),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(962),
  [237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(953),
  [239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(937),
  [243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [245] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(208),
  [248] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(345),
  [251] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(262),
  [254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(220),
  [257] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1198),
  [260] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1138),
  [263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(180),
  [266] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(181),
  [269] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(881),
  [272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0),
  [274] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(270),
  [277] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1080),
  [280] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1052),
  [283] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(274),
  [286] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(331),
  [289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(788),
  [292] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(798),
  [295] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(752),
  [298] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1079),
  [301] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(6),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(434),
  [307] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(268),
  [310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(753),
  [313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(834),
  [316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(865),
  [319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(657),
  [322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(707),
  [324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(714),
  [334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 1, 0, 0),
  [340] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_block, 1, 0, 0), SHIFT(752),
  [343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0),
  [345] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(849),
  [348] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(843),
  [351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1150),
  [359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [367] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 0, 0),
  [374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 0, 0),
  [376] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [380] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [386] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [392] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1200),
  [395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 10),
  [407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 10),
  [409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 2, 0, 4),
  [411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 2, 0, 4),
  [413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [415] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(748),
  [418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 17),
  [422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 17),
  [424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 16),
  [426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 16),
  [428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1151),
  [430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 3),
  [432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 3),
  [434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 2, 0, 0),
  [440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 2, 0, 0),
  [442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 6),
  [444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 6),
  [446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 3, 0, 0),
  [448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 3, 0, 0),
  [450] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 2, 0, 0),
  [452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 2, 0, 0),
  [454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, -1, 0),
  [460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not_operator, 2, 0, 0),
  [466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not_operator, 2, 0, 0),
  [470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 2, 0, 0),
  [472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 2, 0, 0),
  [474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 3, 0, 0),
  [488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 3, 0, 0),
  [490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 3, 0, 0),
  [492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 3, 0, 0),
  [494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 3, 0, 11),
  [500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(222),
  [502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 3, 0, 11),
  [506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(253),
  [508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 3, 0, 0),
  [512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 3, 0, 0),
  [516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 4, 0, 0),
  [518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 4, 0, 0),
  [520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 4, 0, 0),
  [522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 4, 0, 0),
  [524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 5, 0, 0),
  [526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 5, 0, 0),
  [533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 1, 0),
  [535] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_operator, 3, 0, 11),
  [540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_operator, 3, 0, 11),
  [542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [544] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 13),
  [546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 13),
  [550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 18),
  [552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 18),
  [554] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, -1, 0),
  [559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 1, 0),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [563] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1181),
  [566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_iterator, 3, 0, 0),
  [568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_iterator, 3, 0, 0),
  [570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [572] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 1, 0, 0),
  [574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(342),
  [578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1232),
  [584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 1, 0, 0),
  [590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(502),
  [594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [602] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(160),
  [605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(329),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1192),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1126),
  [617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [621] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 3, 0, 0),
  [623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 3, 0, 0),
  [625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 2, 0, 0),
  [627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 2, 0, 0),
  [629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 4, 0, 0),
  [631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 4, 0, 0),
  [633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 5),
  [635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 5),
  [637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(448),
  [663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 0),
  [673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 0),
  [675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [679] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(170),
  [682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 5),
  [688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 5),
  [690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1119),
  [736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(413),
  [738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(348),
  [746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(483),
  [758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(327),
  [762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(103),
  [794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(403),
  [812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [842] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [844] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(736),
  [847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(275),
  [863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [881] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(731),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(346),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(359),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(433),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(324),
  [921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(439),
  [933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(432),
  [935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1149),
  [937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1206),
  [939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [942] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1206),
  [945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 23),
  [951] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 23),
  [953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 5, 0, 23),
  [955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 5, 0, 23),
  [957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_value, 1, 0, 0),
  [959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1195),
  [965] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1195),
  [968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(243),
  [972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(225),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [988] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(747),
  [991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(226),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [1001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(228),
  [1005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(231),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [1009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [1011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1190),
  [1013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(289),
  [1015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [1017] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(740),
  [1020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1190),
  [1023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(238),
  [1025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(241),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [1033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1035] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(283),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [1042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(311),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [1046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [1049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [1056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(250),
  [1058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(251),
  [1060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [1062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(304),
  [1064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [1068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [1076] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1240),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(635),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(976),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [1085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(632),
  [1089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [1091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [1093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [1095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [1103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1240),
  [1105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [1107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1044),
  [1109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [1111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [1113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1159),
  [1115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [1117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [1119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1163),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [1124] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1180),
  [1127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [1141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 1, 0, 0),
  [1157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 1, 0, 0),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [1173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(632),
  [1176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(672),
  [1179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(237),
  [1182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(687),
  [1185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0),
  [1187] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(448),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [1196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [1198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(303),
  [1200] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1204] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment, 3, 0, 11),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [1208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 1, 0, 9),
  [1210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_value, 2, 0, 0),
  [1212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 1, 0, 0),
  [1214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 1, 0, 0),
  [1216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [1220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 15),
  [1222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 5, 0, 9),
  [1224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(679),
  [1226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [1228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [1230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0),
  [1232] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 2, -1, 0),
  [1234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [1236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(876),
  [1238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [1240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [1242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [1244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(769),
  [1246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [1248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [1250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [1252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [1254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [1256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [1258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [1260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 4, 0, 0),
  [1262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [1264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [1266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(808),
  [1268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [1270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 21),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [1274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [1276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [1278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(595),
  [1280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [1282] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(658),
  [1285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [1287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(741),
  [1290] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(743),
  [1293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(745),
  [1296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(746),
  [1299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(638),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1188),
  [1303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1075),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [1315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(816),
  [1317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(686),
  [1320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0),
  [1322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(769),
  [1325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1165),
  [1328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(657),
  [1331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 4, -1, 0),
  [1333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 3, -1, 0),
  [1335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [1337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 0),
  [1339] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(732),
  [1342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [1344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(679),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [1353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(815),
  [1355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(855),
  [1357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(45),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [1383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [1385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [1389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [1391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [1393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [1395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(656),
  [1397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1142),
  [1399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [1401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [1407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 3, 0, 0),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1047),
  [1411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [1415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [1417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 14),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [1421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 5, 0, 14),
  [1423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [1427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [1429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(378),
  [1431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [1433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 14),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [1437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 14),
  [1439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [1443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [1445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 20),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [1449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 20),
  [1451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 14),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [1455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 14),
  [1457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [1461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [1463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 20),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [1467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 20),
  [1469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [1471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 14),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [1475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 14),
  [1477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 20),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [1481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 20),
  [1483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [1487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [1489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [1491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [1493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(805),
  [1495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(812),
  [1497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [1499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 4, 0, 0),
  [1501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(660),
  [1507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [1509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [1511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [1513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [1515] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(600),
  [1518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(678),
  [1521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0),
  [1523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [1525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 1, -1, 0),
  [1527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [1529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [1533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1133),
  [1535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [1537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(646),
  [1539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [1541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(906),
  [1545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(86),
  [1551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [1555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 20),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [1559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 9, 0, 20),
  [1561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [1565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 1, 0, 0),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [1569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(692),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [1573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 20),
  [1575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 20),
  [1577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 8),
  [1579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 4, 0, 8),
  [1581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 8),
  [1583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 8),
  [1585] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(762),
  [1588] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0),
  [1590] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 8),
  [1592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 3, 0, 8),
  [1594] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0),
  [1596] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0), SHIFT_REPEAT(1146),
  [1599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 3, 0, 0),
  [1601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1146),
  [1603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 3, 0, 0),
  [1605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(690),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [1609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [1611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [1613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 3, 0, 0),
  [1615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 14),
  [1617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 4, 0, 14),
  [1619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 1, 0, 5),
  [1621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 1, 0, 5),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [1625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [1629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 3, 0, 0),
  [1631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 3, 0, 0),
  [1633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [1635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0),
  [1637] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), SHIFT_REPEAT(215),
  [1640] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 2, 0, 0),
  [1642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [1644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [1650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 5, 0, 14),
  [1652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 5, 0, 14),
  [1654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 3),
  [1656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 3, 0, 3),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(820),
  [1660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 1, 0, 0),
  [1662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 14),
  [1664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 14),
  [1666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 8),
  [1668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 8),
  [1670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [1672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 2, 0, 0),
  [1674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [1676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 5, 0, 0),
  [1678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 14),
  [1680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 14),
  [1682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [1684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 1, 0, 0),
  [1686] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0),
  [1688] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0), SHIFT_REPEAT(799),
  [1691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 2, 0, 0),
  [1693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 20),
  [1695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 20),
  [1697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 4, 0, 0),
  [1699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 5, 0, 0),
  [1701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 4, 0, 0),
  [1703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 5, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 8),
  [1707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 8),
  [1709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [1711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 14),
  [1713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 9, 0, 14),
  [1715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 2, 0, 3),
  [1717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 2, 0, 3),
  [1719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 5, 0, 0),
  [1721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 4, 0, 0),
  [1723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 10, 0, 20),
  [1725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 10, 0, 20),
  [1727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 2, 0, 0),
  [1729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 4, 0, 0),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [1739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [1741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [1743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [1745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 4, 0, 0),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(59),
  [1751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [1753] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(831),
  [1756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [1758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 3, 0, 0),
  [1760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [1762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [1764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [1766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [1768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0),
  [1770] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(269),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(33),
  [1775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(24),
  [1777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [1779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [1781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [1783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [1787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [1789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1139),
  [1791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1070),
  [1793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [1795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [1797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [1799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [1801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(786),
  [1803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 1, 0, 0),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [1809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [1811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [1815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [1817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [1821] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(159),
  [1824] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(159),
  [1827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(51),
  [1831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [1833] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(871),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [1842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [1844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parfor_options, 1, 0, 0),
  [1846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(647),
  [1854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [1856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [1866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1068),
  [1868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(65),
  [1872] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(264),
  [1875] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [1877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [1879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(69),
  [1881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [1893] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 2, 0, 0), SHIFT_REPEAT(1225),
  [1896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 2, 0, 0),
  [1898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 8),
  [1900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 9),
  [1902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [1904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(421),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(857),
  [1910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [1912] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 2, 0, 0),
  [1914] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 14),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [1918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [1920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, 0, 0),
  [1922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [1924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(423),
  [1926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 0),
  [1928] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 22), SHIFT_REPEAT(199),
  [1931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 22),
  [1933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 0),
  [1935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 7),
  [1937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 6, 0, 7),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [1941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [1949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 7),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [1953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 8),
  [1955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 4, 0, 0),
  [1957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 7),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [1961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 4, 0, 7),
  [1963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [1965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 1, -1, 0),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [1969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 2, 0, 0),
  [1971] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 14),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [1981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(411),
  [1983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [1987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(447),
  [1991] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 7),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [1995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1013),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [2001] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, 0, 8),
  [2003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 4, 0, 0),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [2007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 7),
  [2009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 7, 0, 15),
  [2011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [2013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [2015] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 0),
  [2017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(534),
  [2019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(797),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [2023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [2025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 3, 0, 21),
  [2027] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 3, 0, 0),
  [2029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 0),
  [2031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1064),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [2037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 15),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [2043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 2, -1, 0),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [2049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 3, 0, 0),
  [2051] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 7),
  [2053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 0),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [2057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(465),
  [2059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(471),
  [2061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(479),
  [2063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(482),
  [2065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 4, 0, 0),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [2073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 5, 0, 0),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [2077] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 7),
  [2079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [2081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [2083] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 5, 0, 0),
  [2085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [2087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [2097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 7),
  [2099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [2101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(768),
  [2104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 5, 0, 7),
  [2106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [2108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 3, 0, 19),
  [2110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(807),
  [2112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 7),
  [2114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 4, 0, 24),
  [2116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(857),
  [2119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0),
  [2121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 7, 0, 14),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [2125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(535),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [2129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(702),
  [2135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [2143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_output, 2, 0, 0),
  [2145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_output, 2, 0, 0),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [2149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [2151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [2153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [2159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [2167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 2, 0, 0),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [2171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [2173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 1, 0, 0),
  [2175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [2177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [2179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [2185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [2187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [2189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [2191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 4, 0, 7),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [2197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [2199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [2201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [2203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [2205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [2209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0), SHIFT_REPEAT(1021),
  [2212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0),
  [2214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 2, 0, 3),
  [2216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 2, 0, 3),
  [2218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [2222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 5, 0, 3),
  [2224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 5, 0, 3),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [2228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_operator, 1, 0, 0),
  [2230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(711),
  [2233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [2235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1162),
  [2237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [2239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1024),
  [2242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0),
  [2244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [2246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0), SHIFT_REPEAT(1120),
  [2249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0),
  [2251] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0), SHIFT_REPEAT(219),
  [2254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0),
  [2256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [2258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(744),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [2262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [2264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [2268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [2270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [2272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 6, 0, 3),
  [2274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 6, 0, 3),
  [2276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 0),
  [2278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [2280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [2282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(848),
  [2285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0),
  [2287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 3, 0, 3),
  [2289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 3, 0, 3),
  [2291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [2293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 4, 0, 3),
  [2295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 4, 0, 3),
  [2297] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 22), SHIFT_REPEAT(1236),
  [2300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 22),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [2304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [2308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [2310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [2312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [2314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [2316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [2318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [2320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [2322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [2326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(719),
  [2328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [2330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [2332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [2334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [2336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [2338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [2340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [2342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [2346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [2348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [2350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [2356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [2358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 3, -1, 0),
  [2360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [2362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [2364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(992),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [2368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [2370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [2372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [2374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [2380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [2386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 14),
  [2388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 8),
  [2390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [2392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [2394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [2396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [2398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [2400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [2402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [2404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [2406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [2408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [2410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 10, 0, 20),
  [2412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 4, -1, 0),
  [2414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [2416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [2418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 21),
  [2420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [2422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [2424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [2426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [2428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [2430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [2434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [2438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [2440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [2444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [2446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [2452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [2454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [2456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [2458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 3, 0, 0),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [2464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [2466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [2468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [2470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [2472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [2476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [2478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [2480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [2482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [2484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [2486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [2488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 5, 0, 0),
  [2490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [2492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [2494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [2496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [2500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 3, 0, 0),
  [2502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [2506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [2508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [2510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [2512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 3, 0, 0),
  [2514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [2516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [2518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 2, 0, 0),
  [2520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [2522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [2524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [2526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [2528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [2530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 4, 0, 0),
  [2532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [2534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [2536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [2538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 4, 0, 0),
  [2540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [2542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [2544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [2546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [2548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 3, 0, 0),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [2552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [2556] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [2560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [2562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [2564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [2566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [2568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [2570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [2572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 4, 0, 0),
  [2574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [2576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [2578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [2580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [2582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [2584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [2586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [2588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_comment = 0,
  ts_external_token_line_continuation = 1,
  ts_external_token_command_name = 2,
  ts_external_token_command_argument = 3,
  ts_external_token__single_quote_string_start = 4,
  ts_external_token__single_quote_string_end = 5,
  ts_external_token__double_quote_string_start = 6,
  ts_external_token__double_quote_string_end = 7,
  ts_external_token_formatting_sequence = 8,
  ts_external_token_escape_sequence = 9,
  ts_external_token_string_content = 10,
  ts_external_token__entry_delimiter = 11,
  ts_external_token__multioutput_variable_start = 12,
  ts_external_token_error_sentinel = 13,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_comment] = sym_comment,
  [ts_external_token_line_continuation] = sym_line_continuation,
  [ts_external_token_command_name] = sym_command_name,
  [ts_external_token_command_argument] = sym_command_argument,
  [ts_external_token__single_quote_string_start] = sym__single_quote_string_start,
  [ts_external_token__single_quote_string_end] = sym__single_quote_string_end,
  [ts_external_token__double_quote_string_start] = sym__double_quote_string_start,
  [ts_external_token__double_quote_string_end] = sym__double_quote_string_end,
  [ts_external_token_formatting_sequence] = sym_formatting_sequence,
  [ts_external_token_escape_sequence] = sym_escape_sequence,
  [ts_external_token_string_content] = sym_string_content,
  [ts_external_token__entry_delimiter] = sym__entry_delimiter,
  [ts_external_token__multioutput_variable_start] = sym__multioutput_variable_start,
  [ts_external_token_error_sentinel] = sym_error_sentinel,
};

static const bool ts_external_scanner_states[11][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token_command_argument] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
    [ts_external_token__entry_delimiter] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token_error_sentinel] = true,
  },
  [2] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__multioutput_variable_start] = true,
  },
  [3] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
  },
  [4] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__entry_delimiter] = true,
  },
  [5] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
  },
  [6] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__entry_delimiter] = true,
  },
  [7] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__multioutput_variable_start] = true,
  },
  [8] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_argument] = true,
  },
  [9] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
  [10] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_matlab_external_scanner_create(void);
void tree_sitter_matlab_external_scanner_destroy(void *);
bool tree_sitter_matlab_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_matlab_external_scanner_serialize(void *, char *);
void tree_sitter_matlab_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_matlab(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_matlab_external_scanner_create,
      tree_sitter_matlab_external_scanner_destroy,
      tree_sitter_matlab_external_scanner_scan,
      tree_sitter_matlab_external_scanner_serialize,
      tree_sitter_matlab_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
